# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

accessKey: Optional[str]
"""
The Access Key for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_ACCESS_KEY`
environment variable
"""

assumeRole: Optional[str]
"""
An `assume_role` block (documented below). Only one `assume_role` block may be in the configuration.
"""

customerHeaders: Optional[str]
"""
CUSTOMER HEADERS for Byteplus Provider. The customer_headers field uses commas (,) to separate multiple headers, and
colons (:) to separate each header key from its corresponding value.
"""

disableSsl: Optional[bool]
"""
Disable SSL for Byteplus Provider
"""

endpoints: Optional[str]
"""
An `endpoints` block (documented below). Only one `endpoints` block may be in the configuration.
"""

proxyUrl: Optional[str]
"""
PROXY URL for Byteplus Provider
"""

region: Optional[str]
"""
The Region for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_REGION` environment
variable
"""

secretKey: Optional[str]
"""
he Secret Key for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_SECRET_KEY`
environment variable
"""

