# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstanceResult',
    'AwaitableGetInstanceResult',
    'get_instance',
    'get_instance_output',
]

@pulumi.output_type
class GetInstanceResult:
    """
    A collection of values returned by getInstance.
    """
    def __init__(__self__, account_id=None, bandwidth=None, capacity=None, capacity_info=None, charge_status=None, charge_type=None, created_time=None, description=None, enable_restripe=None, expire_time=None, file_system_id=None, file_system_name=None, file_system_type=None, free_time=None, id=None, project_name=None, protocol_type=None, read_bandwidth=None, security_group_id=None, status=None, stop_service_time=None, store_type=None, store_type_cn=None, store_type_en=None, subnet_id=None, tags=None, updated_time=None, version_number=None, vpc_id=None, write_bandwidth=None, zone_id=None, zone_name=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if bandwidth and not isinstance(bandwidth, int):
            raise TypeError("Expected argument 'bandwidth' to be a int")
        pulumi.set(__self__, "bandwidth", bandwidth)
        if capacity and not isinstance(capacity, int):
            raise TypeError("Expected argument 'capacity' to be a int")
        pulumi.set(__self__, "capacity", capacity)
        if capacity_info and not isinstance(capacity_info, dict):
            raise TypeError("Expected argument 'capacity_info' to be a dict")
        pulumi.set(__self__, "capacity_info", capacity_info)
        if charge_status and not isinstance(charge_status, str):
            raise TypeError("Expected argument 'charge_status' to be a str")
        pulumi.set(__self__, "charge_status", charge_status)
        if charge_type and not isinstance(charge_type, str):
            raise TypeError("Expected argument 'charge_type' to be a str")
        pulumi.set(__self__, "charge_type", charge_type)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if enable_restripe and not isinstance(enable_restripe, bool):
            raise TypeError("Expected argument 'enable_restripe' to be a bool")
        pulumi.set(__self__, "enable_restripe", enable_restripe)
        if expire_time and not isinstance(expire_time, str):
            raise TypeError("Expected argument 'expire_time' to be a str")
        pulumi.set(__self__, "expire_time", expire_time)
        if file_system_id and not isinstance(file_system_id, str):
            raise TypeError("Expected argument 'file_system_id' to be a str")
        pulumi.set(__self__, "file_system_id", file_system_id)
        if file_system_name and not isinstance(file_system_name, str):
            raise TypeError("Expected argument 'file_system_name' to be a str")
        pulumi.set(__self__, "file_system_name", file_system_name)
        if file_system_type and not isinstance(file_system_type, str):
            raise TypeError("Expected argument 'file_system_type' to be a str")
        pulumi.set(__self__, "file_system_type", file_system_type)
        if free_time and not isinstance(free_time, str):
            raise TypeError("Expected argument 'free_time' to be a str")
        pulumi.set(__self__, "free_time", free_time)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if protocol_type and not isinstance(protocol_type, str):
            raise TypeError("Expected argument 'protocol_type' to be a str")
        pulumi.set(__self__, "protocol_type", protocol_type)
        if read_bandwidth and not isinstance(read_bandwidth, int):
            raise TypeError("Expected argument 'read_bandwidth' to be a int")
        pulumi.set(__self__, "read_bandwidth", read_bandwidth)
        if security_group_id and not isinstance(security_group_id, str):
            raise TypeError("Expected argument 'security_group_id' to be a str")
        pulumi.set(__self__, "security_group_id", security_group_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if stop_service_time and not isinstance(stop_service_time, str):
            raise TypeError("Expected argument 'stop_service_time' to be a str")
        pulumi.set(__self__, "stop_service_time", stop_service_time)
        if store_type and not isinstance(store_type, str):
            raise TypeError("Expected argument 'store_type' to be a str")
        pulumi.set(__self__, "store_type", store_type)
        if store_type_cn and not isinstance(store_type_cn, str):
            raise TypeError("Expected argument 'store_type_cn' to be a str")
        pulumi.set(__self__, "store_type_cn", store_type_cn)
        if store_type_en and not isinstance(store_type_en, str):
            raise TypeError("Expected argument 'store_type_en' to be a str")
        pulumi.set(__self__, "store_type_en", store_type_en)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if version_number and not isinstance(version_number, str):
            raise TypeError("Expected argument 'version_number' to be a str")
        pulumi.set(__self__, "version_number", version_number)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)
        if write_bandwidth and not isinstance(write_bandwidth, int):
            raise TypeError("Expected argument 'write_bandwidth' to be a int")
        pulumi.set(__self__, "write_bandwidth", write_bandwidth)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)
        if zone_name and not isinstance(zone_name, str):
            raise TypeError("Expected argument 'zone_name' to be a str")
        pulumi.set(__self__, "zone_name", zone_name)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.str:
        """
        账户ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter
    def bandwidth(self) -> builtins.int:
        """
        vePFS 文件系统吞吐上限。
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter
    def capacity(self) -> builtins.int:
        """
        文件系统容量，单位为 TiB。
        """
        return pulumi.get(self, "capacity")

    @property
    @pulumi.getter(name="capacityInfo")
    def capacity_info(self) -> 'outputs.GetInstanceCapacityInfoResult':
        """
        容量信息。
        """
        return pulumi.get(self, "capacity_info")

    @property
    @pulumi.getter(name="chargeStatus")
    def charge_status(self) -> builtins.str:
        """
        计费状态，默认为 Normal，表示正常计费。
        """
        return pulumi.get(self, "charge_status")

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> builtins.str:
        """
        计费类型。取值说明如下：PayAsYouGo：按量计费。
        """
        return pulumi.get(self, "charge_type")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        文件系统描述信息。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enableRestripe")
    def enable_restripe(self) -> builtins.bool:
        """
        扩容后是否开启数据均衡，取值说明如下：true：扩容后立即开启数据均衡。false：扩容后不开启数据均衡。注意：仅 100MB/s/TiB 规格的文件系统支持数据均衡功能。由于数据均衡过程会消耗存储节点的网络和磁盘带宽，导致文件系统的性能下降，建议您评估业务需求，谨慎开启。数据均衡的时间主要受存量数据量的影响，如果您的存量数据较多，均衡的时间可能会较长，根据扩容容量大小和文件系统状态，此过程可能需要花费数小时至 2 天的时间，建议您在业务低峰期开启并耐心等待。
        """
        return pulumi.get(self, "enable_restripe")

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> builtins.str:
        """
        过期时间。
        """
        return pulumi.get(self, "expire_time")

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> builtins.str:
        """
        文件系统 ID。
        """
        return pulumi.get(self, "file_system_id")

    @property
    @pulumi.getter(name="fileSystemName")
    def file_system_name(self) -> builtins.str:
        """
        文件系统名称。命名规范如下：只能以中文或英文开头。只能包含中文、字母、数字、半角句号（.）、下划线（_）或中划线（-）。长度需要在 1~128 个字符内。
        """
        return pulumi.get(self, "file_system_name")

    @property
    @pulumi.getter(name="fileSystemType")
    def file_system_type(self) -> builtins.str:
        """
        文件系统类型，默认为 VePFS。
        """
        return pulumi.get(self, "file_system_type")

    @property
    @pulumi.getter(name="freeTime")
    def free_time(self) -> builtins.str:
        """
        文件系统释放时间。
        """
        return pulumi.get(self, "free_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        文件系统所属项目，默认为 default。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="protocolType")
    def protocol_type(self) -> builtins.str:
        """
        协议类型，默认为 VePFS。
        """
        return pulumi.get(self, "protocol_type")

    @property
    @pulumi.getter(name="readBandwidth")
    def read_bandwidth(self) -> builtins.int:
        """
        读带宽值, 单位MB/s。
        """
        return pulumi.get(self, "read_bandwidth")

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> builtins.str:
        """
        生成的辅助网卡所在的安全组ID。
        """
        return pulumi.get(self, "security_group_id")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        文件系统状态。取值说明如下：Running：实例运行中。Creating：实例创建中。CreateError：实例创建失败。Updating：实例更新中。UpdateError：实例更新失败。Expanding：实例扩容中。ExpandError：实例扩容失败。Deleting：实例删除中。DeleteError：实例删除失败。Stopped：实例已关停。Error：实例处于错误状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="stopServiceTime")
    def stop_service_time(self) -> builtins.str:
        """
        文件系统关停时间。
        """
        return pulumi.get(self, "stop_service_time")

    @property
    @pulumi.getter(name="storeType")
    def store_type(self) -> builtins.str:
        """
        文件系统规格，取值说明如下：Advance*100：100MB/s/TiB。Performance：性能版。Intelligent*Computing：智算版。
        """
        return pulumi.get(self, "store_type")

    @property
    @pulumi.getter(name="storeTypeCn")
    def store_type_cn(self) -> builtins.str:
        """
        文件系统规格中文名称，支持如下：100MB/s/TiB。性能版。智算版。
        """
        return pulumi.get(self, "store_type_cn")

    @property
    @pulumi.getter(name="storeTypeEn")
    def store_type_en(self) -> builtins.str:
        """
        存储类型英文名。
        """
        return pulumi.get(self, "store_type_en")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> builtins.str:
        """
        子网 ID。子网必须属于所选的可用区。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetInstanceTagResult']:
        """
        标签列表。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        文件系统更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="versionNumber")
    def version_number(self) -> builtins.str:
        """
        文件系统版本号。
        """
        return pulumi.get(self, "version_number")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        私有网络 ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="writeBandwidth")
    def write_bandwidth(self) -> builtins.int:
        """
        写带宽值, 单位MB/s。
        """
        return pulumi.get(self, "write_bandwidth")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> builtins.str:
        """
        可用区 ID。
        """
        return pulumi.get(self, "zone_id")

    @property
    @pulumi.getter(name="zoneName")
    def zone_name(self) -> builtins.str:
        """
        可用区名称。
        """
        return pulumi.get(self, "zone_name")


class AwaitableGetInstanceResult(GetInstanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceResult(
            account_id=self.account_id,
            bandwidth=self.bandwidth,
            capacity=self.capacity,
            capacity_info=self.capacity_info,
            charge_status=self.charge_status,
            charge_type=self.charge_type,
            created_time=self.created_time,
            description=self.description,
            enable_restripe=self.enable_restripe,
            expire_time=self.expire_time,
            file_system_id=self.file_system_id,
            file_system_name=self.file_system_name,
            file_system_type=self.file_system_type,
            free_time=self.free_time,
            id=self.id,
            project_name=self.project_name,
            protocol_type=self.protocol_type,
            read_bandwidth=self.read_bandwidth,
            security_group_id=self.security_group_id,
            status=self.status,
            stop_service_time=self.stop_service_time,
            store_type=self.store_type,
            store_type_cn=self.store_type_cn,
            store_type_en=self.store_type_en,
            subnet_id=self.subnet_id,
            tags=self.tags,
            updated_time=self.updated_time,
            version_number=self.version_number,
            vpc_id=self.vpc_id,
            write_bandwidth=self.write_bandwidth,
            zone_id=self.zone_id,
            zone_name=self.zone_name)


def get_instance(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceResult:
    """
    Data Source schema for Byteplus::VEPFS::Instance


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vepfs/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult).value

    return AwaitableGetInstanceResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        bandwidth=pulumi.get(__ret__, 'bandwidth'),
        capacity=pulumi.get(__ret__, 'capacity'),
        capacity_info=pulumi.get(__ret__, 'capacity_info'),
        charge_status=pulumi.get(__ret__, 'charge_status'),
        charge_type=pulumi.get(__ret__, 'charge_type'),
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        enable_restripe=pulumi.get(__ret__, 'enable_restripe'),
        expire_time=pulumi.get(__ret__, 'expire_time'),
        file_system_id=pulumi.get(__ret__, 'file_system_id'),
        file_system_name=pulumi.get(__ret__, 'file_system_name'),
        file_system_type=pulumi.get(__ret__, 'file_system_type'),
        free_time=pulumi.get(__ret__, 'free_time'),
        id=pulumi.get(__ret__, 'id'),
        project_name=pulumi.get(__ret__, 'project_name'),
        protocol_type=pulumi.get(__ret__, 'protocol_type'),
        read_bandwidth=pulumi.get(__ret__, 'read_bandwidth'),
        security_group_id=pulumi.get(__ret__, 'security_group_id'),
        status=pulumi.get(__ret__, 'status'),
        stop_service_time=pulumi.get(__ret__, 'stop_service_time'),
        store_type=pulumi.get(__ret__, 'store_type'),
        store_type_cn=pulumi.get(__ret__, 'store_type_cn'),
        store_type_en=pulumi.get(__ret__, 'store_type_en'),
        subnet_id=pulumi.get(__ret__, 'subnet_id'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        version_number=pulumi.get(__ret__, 'version_number'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'),
        write_bandwidth=pulumi.get(__ret__, 'write_bandwidth'),
        zone_id=pulumi.get(__ret__, 'zone_id'),
        zone_name=pulumi.get(__ret__, 'zone_name'))
def get_instance_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstanceResult]:
    """
    Data Source schema for Byteplus::VEPFS::Instance


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vepfs/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult)
    return __ret__.apply(lambda __response__: GetInstanceResult(
        account_id=pulumi.get(__response__, 'account_id'),
        bandwidth=pulumi.get(__response__, 'bandwidth'),
        capacity=pulumi.get(__response__, 'capacity'),
        capacity_info=pulumi.get(__response__, 'capacity_info'),
        charge_status=pulumi.get(__response__, 'charge_status'),
        charge_type=pulumi.get(__response__, 'charge_type'),
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        enable_restripe=pulumi.get(__response__, 'enable_restripe'),
        expire_time=pulumi.get(__response__, 'expire_time'),
        file_system_id=pulumi.get(__response__, 'file_system_id'),
        file_system_name=pulumi.get(__response__, 'file_system_name'),
        file_system_type=pulumi.get(__response__, 'file_system_type'),
        free_time=pulumi.get(__response__, 'free_time'),
        id=pulumi.get(__response__, 'id'),
        project_name=pulumi.get(__response__, 'project_name'),
        protocol_type=pulumi.get(__response__, 'protocol_type'),
        read_bandwidth=pulumi.get(__response__, 'read_bandwidth'),
        security_group_id=pulumi.get(__response__, 'security_group_id'),
        status=pulumi.get(__response__, 'status'),
        stop_service_time=pulumi.get(__response__, 'stop_service_time'),
        store_type=pulumi.get(__response__, 'store_type'),
        store_type_cn=pulumi.get(__response__, 'store_type_cn'),
        store_type_en=pulumi.get(__response__, 'store_type_en'),
        subnet_id=pulumi.get(__response__, 'subnet_id'),
        tags=pulumi.get(__response__, 'tags'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        version_number=pulumi.get(__response__, 'version_number'),
        vpc_id=pulumi.get(__response__, 'vpc_id'),
        write_bandwidth=pulumi.get(__response__, 'write_bandwidth'),
        zone_id=pulumi.get(__response__, 'zone_id'),
        zone_name=pulumi.get(__response__, 'zone_name')))
