# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ShareConfigArgs', 'ShareConfig']

@pulumi.input_type
class ShareConfigArgs:
    def __init__(__self__, *,
                 allow_ip_access_rule: Optional[pulumi.Input['ShareConfigAllowIpAccessRuleArgs']] = None,
                 allow_referer_access_rule: Optional[pulumi.Input['ShareConfigAllowRefererAccessRuleArgs']] = None,
                 common_matchs: Optional[pulumi.Input['ShareConfigCommonMatchsArgs']] = None,
                 config_name: Optional[pulumi.Input[builtins.str]] = None,
                 config_type: Optional[pulumi.Input[builtins.str]] = None,
                 deny_ip_access_rule: Optional[pulumi.Input['ShareConfigDenyIpAccessRuleArgs']] = None,
                 deny_referer_access_rule: Optional[pulumi.Input['ShareConfigDenyRefererAccessRuleArgs']] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ShareConfig resource.
        :param pulumi.Input['ShareConfigAllowIpAccessRuleArgs'] allow_ip_access_rule: 表示一个 IP 白名单的配置，对应 ConfigType 是 allow*ip*access*rule。
        :param pulumi.Input['ShareConfigAllowRefererAccessRuleArgs'] allow_referer_access_rule: 表示一个 Referer 白名单的配置，对应 ConfigType 是 allow*referer*access*rule。
        :param pulumi.Input['ShareConfigCommonMatchsArgs'] common_matchs: 表示一个通用列表的配置，对应 ConfigType 是 common*match*list。
        :param pulumi.Input[builtins.str] config_name: 表示全局配置的名称。名称有以下要求：名称可以包含汉字、字母、数字、下划线（_），长度在 3-45 个字符之间。一个汉字占 3 个字符。名称不能与主账号下某个已有的全局配置的名称相同。
        :param pulumi.Input[builtins.str] config_type: 表示该全局配置的类型。该参数有以下取值：deny*ip*access*rule：表示 IP 黑名单。allow*ip*access*rule：表示 IP 白名单。deny*referer*access*rule：表示 Referer 黑名单。allow*referer*access*rule：表示 Referer 白名单。common*match*list：表示通用列表。
        :param pulumi.Input['ShareConfigDenyIpAccessRuleArgs'] deny_ip_access_rule: 表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access*rule。
        :param pulumi.Input['ShareConfigDenyRefererAccessRuleArgs'] deny_referer_access_rule: 表示一个 Referer 黑名单的配置，对应 ConfigType 是 deny*referer*access*rule。
        :param pulumi.Input[builtins.str] project: 表示该全局配置所归属的项目名称。
        """
        if allow_ip_access_rule is not None:
            pulumi.set(__self__, "allow_ip_access_rule", allow_ip_access_rule)
        if allow_referer_access_rule is not None:
            pulumi.set(__self__, "allow_referer_access_rule", allow_referer_access_rule)
        if common_matchs is not None:
            pulumi.set(__self__, "common_matchs", common_matchs)
        if config_name is not None:
            pulumi.set(__self__, "config_name", config_name)
        if config_type is not None:
            pulumi.set(__self__, "config_type", config_type)
        if deny_ip_access_rule is not None:
            pulumi.set(__self__, "deny_ip_access_rule", deny_ip_access_rule)
        if deny_referer_access_rule is not None:
            pulumi.set(__self__, "deny_referer_access_rule", deny_referer_access_rule)
        if project is not None:
            pulumi.set(__self__, "project", project)

    @property
    @pulumi.getter(name="allowIpAccessRule")
    def allow_ip_access_rule(self) -> Optional[pulumi.Input['ShareConfigAllowIpAccessRuleArgs']]:
        """
        表示一个 IP 白名单的配置，对应 ConfigType 是 allow*ip*access*rule。
        """
        return pulumi.get(self, "allow_ip_access_rule")

    @allow_ip_access_rule.setter
    def allow_ip_access_rule(self, value: Optional[pulumi.Input['ShareConfigAllowIpAccessRuleArgs']]):
        pulumi.set(self, "allow_ip_access_rule", value)

    @property
    @pulumi.getter(name="allowRefererAccessRule")
    def allow_referer_access_rule(self) -> Optional[pulumi.Input['ShareConfigAllowRefererAccessRuleArgs']]:
        """
        表示一个 Referer 白名单的配置，对应 ConfigType 是 allow*referer*access*rule。
        """
        return pulumi.get(self, "allow_referer_access_rule")

    @allow_referer_access_rule.setter
    def allow_referer_access_rule(self, value: Optional[pulumi.Input['ShareConfigAllowRefererAccessRuleArgs']]):
        pulumi.set(self, "allow_referer_access_rule", value)

    @property
    @pulumi.getter(name="commonMatchs")
    def common_matchs(self) -> Optional[pulumi.Input['ShareConfigCommonMatchsArgs']]:
        """
        表示一个通用列表的配置，对应 ConfigType 是 common*match*list。
        """
        return pulumi.get(self, "common_matchs")

    @common_matchs.setter
    def common_matchs(self, value: Optional[pulumi.Input['ShareConfigCommonMatchsArgs']]):
        pulumi.set(self, "common_matchs", value)

    @property
    @pulumi.getter(name="configName")
    def config_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        表示全局配置的名称。名称有以下要求：名称可以包含汉字、字母、数字、下划线（_），长度在 3-45 个字符之间。一个汉字占 3 个字符。名称不能与主账号下某个已有的全局配置的名称相同。
        """
        return pulumi.get(self, "config_name")

    @config_name.setter
    def config_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "config_name", value)

    @property
    @pulumi.getter(name="configType")
    def config_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        表示该全局配置的类型。该参数有以下取值：deny*ip*access*rule：表示 IP 黑名单。allow*ip*access*rule：表示 IP 白名单。deny*referer*access*rule：表示 Referer 黑名单。allow*referer*access*rule：表示 Referer 白名单。common*match*list：表示通用列表。
        """
        return pulumi.get(self, "config_type")

    @config_type.setter
    def config_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "config_type", value)

    @property
    @pulumi.getter(name="denyIpAccessRule")
    def deny_ip_access_rule(self) -> Optional[pulumi.Input['ShareConfigDenyIpAccessRuleArgs']]:
        """
        表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access*rule。
        """
        return pulumi.get(self, "deny_ip_access_rule")

    @deny_ip_access_rule.setter
    def deny_ip_access_rule(self, value: Optional[pulumi.Input['ShareConfigDenyIpAccessRuleArgs']]):
        pulumi.set(self, "deny_ip_access_rule", value)

    @property
    @pulumi.getter(name="denyRefererAccessRule")
    def deny_referer_access_rule(self) -> Optional[pulumi.Input['ShareConfigDenyRefererAccessRuleArgs']]:
        """
        表示一个 Referer 黑名单的配置，对应 ConfigType 是 deny*referer*access*rule。
        """
        return pulumi.get(self, "deny_referer_access_rule")

    @deny_referer_access_rule.setter
    def deny_referer_access_rule(self, value: Optional[pulumi.Input['ShareConfigDenyRefererAccessRuleArgs']]):
        pulumi.set(self, "deny_referer_access_rule", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        表示该全局配置所归属的项目名称。
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project", value)


@pulumi.input_type
class _ShareConfigState:
    def __init__(__self__, *,
                 allow_ip_access_rule: Optional[pulumi.Input['ShareConfigAllowIpAccessRuleArgs']] = None,
                 allow_referer_access_rule: Optional[pulumi.Input['ShareConfigAllowRefererAccessRuleArgs']] = None,
                 common_matchs: Optional[pulumi.Input['ShareConfigCommonMatchsArgs']] = None,
                 config_name: Optional[pulumi.Input[builtins.str]] = None,
                 config_type: Optional[pulumi.Input[builtins.str]] = None,
                 deny_ip_access_rule: Optional[pulumi.Input['ShareConfigDenyIpAccessRuleArgs']] = None,
                 deny_referer_access_rule: Optional[pulumi.Input['ShareConfigDenyRefererAccessRuleArgs']] = None,
                 domain_count: Optional[pulumi.Input[builtins.int]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 rule_content: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering ShareConfig resources.
        :param pulumi.Input['ShareConfigAllowIpAccessRuleArgs'] allow_ip_access_rule: 表示一个 IP 白名单的配置，对应 ConfigType 是 allow*ip*access*rule。
        :param pulumi.Input['ShareConfigAllowRefererAccessRuleArgs'] allow_referer_access_rule: 表示一个 Referer 白名单的配置，对应 ConfigType 是 allow*referer*access*rule。
        :param pulumi.Input['ShareConfigCommonMatchsArgs'] common_matchs: 表示一个通用列表的配置，对应 ConfigType 是 common*match*list。
        :param pulumi.Input[builtins.str] config_name: 表示全局配置的名称。名称有以下要求：名称可以包含汉字、字母、数字、下划线（_），长度在 3-45 个字符之间。一个汉字占 3 个字符。名称不能与主账号下某个已有的全局配置的名称相同。
        :param pulumi.Input[builtins.str] config_type: 表示该全局配置的类型。该参数有以下取值：deny*ip*access*rule：表示 IP 黑名单。allow*ip*access*rule：表示 IP 白名单。deny*referer*access*rule：表示 Referer 黑名单。allow*referer*access*rule：表示 Referer 白名单。common*match*list：表示通用列表。
        :param pulumi.Input['ShareConfigDenyIpAccessRuleArgs'] deny_ip_access_rule: 表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access*rule。
        :param pulumi.Input['ShareConfigDenyRefererAccessRuleArgs'] deny_referer_access_rule: 表示一个 Referer 黑名单的配置，对应 ConfigType 是 deny*referer*access*rule。
        :param pulumi.Input[builtins.int] domain_count: 表示与该全局配置关联的加速域名的数量。
        :param pulumi.Input[builtins.str] project: 表示该全局配置所归属的项目名称。
        :param pulumi.Input[builtins.str] rule_content: 表示该自定义错误页面的 HTML 代码。
        :param pulumi.Input[builtins.int] updated_time: 表示该全局配置的最近修改时间，单位是 Unix 时间戳。
        """
        if allow_ip_access_rule is not None:
            pulumi.set(__self__, "allow_ip_access_rule", allow_ip_access_rule)
        if allow_referer_access_rule is not None:
            pulumi.set(__self__, "allow_referer_access_rule", allow_referer_access_rule)
        if common_matchs is not None:
            pulumi.set(__self__, "common_matchs", common_matchs)
        if config_name is not None:
            pulumi.set(__self__, "config_name", config_name)
        if config_type is not None:
            pulumi.set(__self__, "config_type", config_type)
        if deny_ip_access_rule is not None:
            pulumi.set(__self__, "deny_ip_access_rule", deny_ip_access_rule)
        if deny_referer_access_rule is not None:
            pulumi.set(__self__, "deny_referer_access_rule", deny_referer_access_rule)
        if domain_count is not None:
            pulumi.set(__self__, "domain_count", domain_count)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if rule_content is not None:
            pulumi.set(__self__, "rule_content", rule_content)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="allowIpAccessRule")
    def allow_ip_access_rule(self) -> Optional[pulumi.Input['ShareConfigAllowIpAccessRuleArgs']]:
        """
        表示一个 IP 白名单的配置，对应 ConfigType 是 allow*ip*access*rule。
        """
        return pulumi.get(self, "allow_ip_access_rule")

    @allow_ip_access_rule.setter
    def allow_ip_access_rule(self, value: Optional[pulumi.Input['ShareConfigAllowIpAccessRuleArgs']]):
        pulumi.set(self, "allow_ip_access_rule", value)

    @property
    @pulumi.getter(name="allowRefererAccessRule")
    def allow_referer_access_rule(self) -> Optional[pulumi.Input['ShareConfigAllowRefererAccessRuleArgs']]:
        """
        表示一个 Referer 白名单的配置，对应 ConfigType 是 allow*referer*access*rule。
        """
        return pulumi.get(self, "allow_referer_access_rule")

    @allow_referer_access_rule.setter
    def allow_referer_access_rule(self, value: Optional[pulumi.Input['ShareConfigAllowRefererAccessRuleArgs']]):
        pulumi.set(self, "allow_referer_access_rule", value)

    @property
    @pulumi.getter(name="commonMatchs")
    def common_matchs(self) -> Optional[pulumi.Input['ShareConfigCommonMatchsArgs']]:
        """
        表示一个通用列表的配置，对应 ConfigType 是 common*match*list。
        """
        return pulumi.get(self, "common_matchs")

    @common_matchs.setter
    def common_matchs(self, value: Optional[pulumi.Input['ShareConfigCommonMatchsArgs']]):
        pulumi.set(self, "common_matchs", value)

    @property
    @pulumi.getter(name="configName")
    def config_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        表示全局配置的名称。名称有以下要求：名称可以包含汉字、字母、数字、下划线（_），长度在 3-45 个字符之间。一个汉字占 3 个字符。名称不能与主账号下某个已有的全局配置的名称相同。
        """
        return pulumi.get(self, "config_name")

    @config_name.setter
    def config_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "config_name", value)

    @property
    @pulumi.getter(name="configType")
    def config_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        表示该全局配置的类型。该参数有以下取值：deny*ip*access*rule：表示 IP 黑名单。allow*ip*access*rule：表示 IP 白名单。deny*referer*access*rule：表示 Referer 黑名单。allow*referer*access*rule：表示 Referer 白名单。common*match*list：表示通用列表。
        """
        return pulumi.get(self, "config_type")

    @config_type.setter
    def config_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "config_type", value)

    @property
    @pulumi.getter(name="denyIpAccessRule")
    def deny_ip_access_rule(self) -> Optional[pulumi.Input['ShareConfigDenyIpAccessRuleArgs']]:
        """
        表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access*rule。
        """
        return pulumi.get(self, "deny_ip_access_rule")

    @deny_ip_access_rule.setter
    def deny_ip_access_rule(self, value: Optional[pulumi.Input['ShareConfigDenyIpAccessRuleArgs']]):
        pulumi.set(self, "deny_ip_access_rule", value)

    @property
    @pulumi.getter(name="denyRefererAccessRule")
    def deny_referer_access_rule(self) -> Optional[pulumi.Input['ShareConfigDenyRefererAccessRuleArgs']]:
        """
        表示一个 Referer 黑名单的配置，对应 ConfigType 是 deny*referer*access*rule。
        """
        return pulumi.get(self, "deny_referer_access_rule")

    @deny_referer_access_rule.setter
    def deny_referer_access_rule(self, value: Optional[pulumi.Input['ShareConfigDenyRefererAccessRuleArgs']]):
        pulumi.set(self, "deny_referer_access_rule", value)

    @property
    @pulumi.getter(name="domainCount")
    def domain_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        表示与该全局配置关联的加速域名的数量。
        """
        return pulumi.get(self, "domain_count")

    @domain_count.setter
    def domain_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "domain_count", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        表示该全局配置所归属的项目名称。
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="ruleContent")
    def rule_content(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        表示该自定义错误页面的 HTML 代码。
        """
        return pulumi.get(self, "rule_content")

    @rule_content.setter
    def rule_content(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_content", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        表示该全局配置的最近修改时间，单位是 Unix 时间戳。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:cdn/shareConfig:ShareConfig")
class ShareConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_ip_access_rule: Optional[pulumi.Input[Union['ShareConfigAllowIpAccessRuleArgs', 'ShareConfigAllowIpAccessRuleArgsDict']]] = None,
                 allow_referer_access_rule: Optional[pulumi.Input[Union['ShareConfigAllowRefererAccessRuleArgs', 'ShareConfigAllowRefererAccessRuleArgsDict']]] = None,
                 common_matchs: Optional[pulumi.Input[Union['ShareConfigCommonMatchsArgs', 'ShareConfigCommonMatchsArgsDict']]] = None,
                 config_name: Optional[pulumi.Input[builtins.str]] = None,
                 config_type: Optional[pulumi.Input[builtins.str]] = None,
                 deny_ip_access_rule: Optional[pulumi.Input[Union['ShareConfigDenyIpAccessRuleArgs', 'ShareConfigDenyIpAccessRuleArgsDict']]] = None,
                 deny_referer_access_rule: Optional[pulumi.Input[Union['ShareConfigDenyRefererAccessRuleArgs', 'ShareConfigDenyRefererAccessRuleArgsDict']]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        全局配置扩展了域名的配置能力，具有以下优点：提升了黑白名单的容量。例如，IP 黑名单可以包含高达 30,000 个条目。提升了域名配置的效率。一个全局配置可与多个域名关联。提供了通用列表类型，可以在额外的域名配置中被使用。一个全局配置的修改可立刻应用于其关联的所有域名。

        ## Import

        ```sh
        $ pulumi import bytepluscc:cdn/shareConfig:ShareConfig example "config_name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ShareConfigAllowIpAccessRuleArgs', 'ShareConfigAllowIpAccessRuleArgsDict']] allow_ip_access_rule: 表示一个 IP 白名单的配置，对应 ConfigType 是 allow*ip*access*rule。
        :param pulumi.Input[Union['ShareConfigAllowRefererAccessRuleArgs', 'ShareConfigAllowRefererAccessRuleArgsDict']] allow_referer_access_rule: 表示一个 Referer 白名单的配置，对应 ConfigType 是 allow*referer*access*rule。
        :param pulumi.Input[Union['ShareConfigCommonMatchsArgs', 'ShareConfigCommonMatchsArgsDict']] common_matchs: 表示一个通用列表的配置，对应 ConfigType 是 common*match*list。
        :param pulumi.Input[builtins.str] config_name: 表示全局配置的名称。名称有以下要求：名称可以包含汉字、字母、数字、下划线（_），长度在 3-45 个字符之间。一个汉字占 3 个字符。名称不能与主账号下某个已有的全局配置的名称相同。
        :param pulumi.Input[builtins.str] config_type: 表示该全局配置的类型。该参数有以下取值：deny*ip*access*rule：表示 IP 黑名单。allow*ip*access*rule：表示 IP 白名单。deny*referer*access*rule：表示 Referer 黑名单。allow*referer*access*rule：表示 Referer 白名单。common*match*list：表示通用列表。
        :param pulumi.Input[Union['ShareConfigDenyIpAccessRuleArgs', 'ShareConfigDenyIpAccessRuleArgsDict']] deny_ip_access_rule: 表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access*rule。
        :param pulumi.Input[Union['ShareConfigDenyRefererAccessRuleArgs', 'ShareConfigDenyRefererAccessRuleArgsDict']] deny_referer_access_rule: 表示一个 Referer 黑名单的配置，对应 ConfigType 是 deny*referer*access*rule。
        :param pulumi.Input[builtins.str] project: 表示该全局配置所归属的项目名称。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ShareConfigArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        全局配置扩展了域名的配置能力，具有以下优点：提升了黑白名单的容量。例如，IP 黑名单可以包含高达 30,000 个条目。提升了域名配置的效率。一个全局配置可与多个域名关联。提供了通用列表类型，可以在额外的域名配置中被使用。一个全局配置的修改可立刻应用于其关联的所有域名。

        ## Import

        ```sh
        $ pulumi import bytepluscc:cdn/shareConfig:ShareConfig example "config_name"
        ```

        :param str resource_name: The name of the resource.
        :param ShareConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ShareConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_ip_access_rule: Optional[pulumi.Input[Union['ShareConfigAllowIpAccessRuleArgs', 'ShareConfigAllowIpAccessRuleArgsDict']]] = None,
                 allow_referer_access_rule: Optional[pulumi.Input[Union['ShareConfigAllowRefererAccessRuleArgs', 'ShareConfigAllowRefererAccessRuleArgsDict']]] = None,
                 common_matchs: Optional[pulumi.Input[Union['ShareConfigCommonMatchsArgs', 'ShareConfigCommonMatchsArgsDict']]] = None,
                 config_name: Optional[pulumi.Input[builtins.str]] = None,
                 config_type: Optional[pulumi.Input[builtins.str]] = None,
                 deny_ip_access_rule: Optional[pulumi.Input[Union['ShareConfigDenyIpAccessRuleArgs', 'ShareConfigDenyIpAccessRuleArgsDict']]] = None,
                 deny_referer_access_rule: Optional[pulumi.Input[Union['ShareConfigDenyRefererAccessRuleArgs', 'ShareConfigDenyRefererAccessRuleArgsDict']]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ShareConfigArgs.__new__(ShareConfigArgs)

            __props__.__dict__["allow_ip_access_rule"] = allow_ip_access_rule
            __props__.__dict__["allow_referer_access_rule"] = allow_referer_access_rule
            __props__.__dict__["common_matchs"] = common_matchs
            __props__.__dict__["config_name"] = config_name
            __props__.__dict__["config_type"] = config_type
            __props__.__dict__["deny_ip_access_rule"] = deny_ip_access_rule
            __props__.__dict__["deny_referer_access_rule"] = deny_referer_access_rule
            __props__.__dict__["project"] = project
            __props__.__dict__["domain_count"] = None
            __props__.__dict__["rule_content"] = None
            __props__.__dict__["updated_time"] = None
        super(ShareConfig, __self__).__init__(
            'bytepluscc:cdn/shareConfig:ShareConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allow_ip_access_rule: Optional[pulumi.Input[Union['ShareConfigAllowIpAccessRuleArgs', 'ShareConfigAllowIpAccessRuleArgsDict']]] = None,
            allow_referer_access_rule: Optional[pulumi.Input[Union['ShareConfigAllowRefererAccessRuleArgs', 'ShareConfigAllowRefererAccessRuleArgsDict']]] = None,
            common_matchs: Optional[pulumi.Input[Union['ShareConfigCommonMatchsArgs', 'ShareConfigCommonMatchsArgsDict']]] = None,
            config_name: Optional[pulumi.Input[builtins.str]] = None,
            config_type: Optional[pulumi.Input[builtins.str]] = None,
            deny_ip_access_rule: Optional[pulumi.Input[Union['ShareConfigDenyIpAccessRuleArgs', 'ShareConfigDenyIpAccessRuleArgsDict']]] = None,
            deny_referer_access_rule: Optional[pulumi.Input[Union['ShareConfigDenyRefererAccessRuleArgs', 'ShareConfigDenyRefererAccessRuleArgsDict']]] = None,
            domain_count: Optional[pulumi.Input[builtins.int]] = None,
            project: Optional[pulumi.Input[builtins.str]] = None,
            rule_content: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.int]] = None) -> 'ShareConfig':
        """
        Get an existing ShareConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ShareConfigAllowIpAccessRuleArgs', 'ShareConfigAllowIpAccessRuleArgsDict']] allow_ip_access_rule: 表示一个 IP 白名单的配置，对应 ConfigType 是 allow*ip*access*rule。
        :param pulumi.Input[Union['ShareConfigAllowRefererAccessRuleArgs', 'ShareConfigAllowRefererAccessRuleArgsDict']] allow_referer_access_rule: 表示一个 Referer 白名单的配置，对应 ConfigType 是 allow*referer*access*rule。
        :param pulumi.Input[Union['ShareConfigCommonMatchsArgs', 'ShareConfigCommonMatchsArgsDict']] common_matchs: 表示一个通用列表的配置，对应 ConfigType 是 common*match*list。
        :param pulumi.Input[builtins.str] config_name: 表示全局配置的名称。名称有以下要求：名称可以包含汉字、字母、数字、下划线（_），长度在 3-45 个字符之间。一个汉字占 3 个字符。名称不能与主账号下某个已有的全局配置的名称相同。
        :param pulumi.Input[builtins.str] config_type: 表示该全局配置的类型。该参数有以下取值：deny*ip*access*rule：表示 IP 黑名单。allow*ip*access*rule：表示 IP 白名单。deny*referer*access*rule：表示 Referer 黑名单。allow*referer*access*rule：表示 Referer 白名单。common*match*list：表示通用列表。
        :param pulumi.Input[Union['ShareConfigDenyIpAccessRuleArgs', 'ShareConfigDenyIpAccessRuleArgsDict']] deny_ip_access_rule: 表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access*rule。
        :param pulumi.Input[Union['ShareConfigDenyRefererAccessRuleArgs', 'ShareConfigDenyRefererAccessRuleArgsDict']] deny_referer_access_rule: 表示一个 Referer 黑名单的配置，对应 ConfigType 是 deny*referer*access*rule。
        :param pulumi.Input[builtins.int] domain_count: 表示与该全局配置关联的加速域名的数量。
        :param pulumi.Input[builtins.str] project: 表示该全局配置所归属的项目名称。
        :param pulumi.Input[builtins.str] rule_content: 表示该自定义错误页面的 HTML 代码。
        :param pulumi.Input[builtins.int] updated_time: 表示该全局配置的最近修改时间，单位是 Unix 时间戳。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ShareConfigState.__new__(_ShareConfigState)

        __props__.__dict__["allow_ip_access_rule"] = allow_ip_access_rule
        __props__.__dict__["allow_referer_access_rule"] = allow_referer_access_rule
        __props__.__dict__["common_matchs"] = common_matchs
        __props__.__dict__["config_name"] = config_name
        __props__.__dict__["config_type"] = config_type
        __props__.__dict__["deny_ip_access_rule"] = deny_ip_access_rule
        __props__.__dict__["deny_referer_access_rule"] = deny_referer_access_rule
        __props__.__dict__["domain_count"] = domain_count
        __props__.__dict__["project"] = project
        __props__.__dict__["rule_content"] = rule_content
        __props__.__dict__["updated_time"] = updated_time
        return ShareConfig(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowIpAccessRule")
    def allow_ip_access_rule(self) -> pulumi.Output['outputs.ShareConfigAllowIpAccessRule']:
        """
        表示一个 IP 白名单的配置，对应 ConfigType 是 allow*ip*access*rule。
        """
        return pulumi.get(self, "allow_ip_access_rule")

    @property
    @pulumi.getter(name="allowRefererAccessRule")
    def allow_referer_access_rule(self) -> pulumi.Output['outputs.ShareConfigAllowRefererAccessRule']:
        """
        表示一个 Referer 白名单的配置，对应 ConfigType 是 allow*referer*access*rule。
        """
        return pulumi.get(self, "allow_referer_access_rule")

    @property
    @pulumi.getter(name="commonMatchs")
    def common_matchs(self) -> pulumi.Output['outputs.ShareConfigCommonMatchs']:
        """
        表示一个通用列表的配置，对应 ConfigType 是 common*match*list。
        """
        return pulumi.get(self, "common_matchs")

    @property
    @pulumi.getter(name="configName")
    def config_name(self) -> pulumi.Output[builtins.str]:
        """
        表示全局配置的名称。名称有以下要求：名称可以包含汉字、字母、数字、下划线（_），长度在 3-45 个字符之间。一个汉字占 3 个字符。名称不能与主账号下某个已有的全局配置的名称相同。
        """
        return pulumi.get(self, "config_name")

    @property
    @pulumi.getter(name="configType")
    def config_type(self) -> pulumi.Output[builtins.str]:
        """
        表示该全局配置的类型。该参数有以下取值：deny*ip*access*rule：表示 IP 黑名单。allow*ip*access*rule：表示 IP 白名单。deny*referer*access*rule：表示 Referer 黑名单。allow*referer*access*rule：表示 Referer 白名单。common*match*list：表示通用列表。
        """
        return pulumi.get(self, "config_type")

    @property
    @pulumi.getter(name="denyIpAccessRule")
    def deny_ip_access_rule(self) -> pulumi.Output['outputs.ShareConfigDenyIpAccessRule']:
        """
        表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access*rule。
        """
        return pulumi.get(self, "deny_ip_access_rule")

    @property
    @pulumi.getter(name="denyRefererAccessRule")
    def deny_referer_access_rule(self) -> pulumi.Output['outputs.ShareConfigDenyRefererAccessRule']:
        """
        表示一个 Referer 黑名单的配置，对应 ConfigType 是 deny*referer*access*rule。
        """
        return pulumi.get(self, "deny_referer_access_rule")

    @property
    @pulumi.getter(name="domainCount")
    def domain_count(self) -> pulumi.Output[builtins.int]:
        """
        表示与该全局配置关联的加速域名的数量。
        """
        return pulumi.get(self, "domain_count")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[builtins.str]:
        """
        表示该全局配置所归属的项目名称。
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="ruleContent")
    def rule_content(self) -> pulumi.Output[builtins.str]:
        """
        表示该自定义错误页面的 HTML 代码。
        """
        return pulumi.get(self, "rule_content")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.int]:
        """
        表示该全局配置的最近修改时间，单位是 Unix 时间戳。
        """
        return pulumi.get(self, "updated_time")

