# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DbAccountArgs', 'DbAccount']

@pulumi.input_type
class DbAccountArgs:
    def __init__(__self__, *,
                 account_name: pulumi.Input[builtins.str],
                 account_password: pulumi.Input[builtins.str],
                 account_type: pulumi.Input[builtins.str],
                 instance_id: pulumi.Input[builtins.str],
                 account_desc: Optional[pulumi.Input[builtins.str]] = None,
                 account_privileges: Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountAccountPrivilegeArgs']]]] = None,
                 host: Optional[pulumi.Input[builtins.str]] = None,
                 table_column_privileges: Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountTableColumnPrivilegeArgs']]]] = None):
        """
        The set of arguments for constructing a DbAccount resource.
        :param pulumi.Input[builtins.str] account_name: 数据库账号名称。命名规则如下：长度为 2~32 个字符。以字母开头，以字母或数字结尾。由字母、数字、下划线（_）和中划线（-）组成。账号名称在实例内必须是唯一的。不能使用某些预留字，被禁用的预留字请参见禁用词列表。说明在高权限账号名称中可使用关键字 root 和 admin。
        :param pulumi.Input[builtins.str] account_password: 数据库账号的密码。规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        :param pulumi.Input[builtins.str] account_type: 账号类型，取值范围：Super：高权限账号。Normal：普通账号。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] account_desc: 账号信息描述信息，长度不超过 256 个字符。
        :param pulumi.Input[builtins.str] host: 指定的数据库账号可以访问数据库的 IP 地址。
        """
        pulumi.set(__self__, "account_name", account_name)
        pulumi.set(__self__, "account_password", account_password)
        pulumi.set(__self__, "account_type", account_type)
        pulumi.set(__self__, "instance_id", instance_id)
        if account_desc is not None:
            pulumi.set(__self__, "account_desc", account_desc)
        if account_privileges is not None:
            pulumi.set(__self__, "account_privileges", account_privileges)
        if host is not None:
            pulumi.set(__self__, "host", host)
        if table_column_privileges is not None:
            pulumi.set(__self__, "table_column_privileges", table_column_privileges)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Input[builtins.str]:
        """
        数据库账号名称。命名规则如下：长度为 2~32 个字符。以字母开头，以字母或数字结尾。由字母、数字、下划线（_）和中划线（-）组成。账号名称在实例内必须是唯一的。不能使用某些预留字，被禁用的预留字请参见禁用词列表。说明在高权限账号名称中可使用关键字 root 和 admin。
        """
        return pulumi.get(self, "account_name")

    @account_name.setter
    def account_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "account_name", value)

    @property
    @pulumi.getter(name="accountPassword")
    def account_password(self) -> pulumi.Input[builtins.str]:
        """
        数据库账号的密码。规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        """
        return pulumi.get(self, "account_password")

    @account_password.setter
    def account_password(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "account_password", value)

    @property
    @pulumi.getter(name="accountType")
    def account_type(self) -> pulumi.Input[builtins.str]:
        """
        账号类型，取值范围：Super：高权限账号。Normal：普通账号。
        """
        return pulumi.get(self, "account_type")

    @account_type.setter
    def account_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "account_type", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="accountDesc")
    def account_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账号信息描述信息，长度不超过 256 个字符。
        """
        return pulumi.get(self, "account_desc")

    @account_desc.setter
    def account_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_desc", value)

    @property
    @pulumi.getter(name="accountPrivileges")
    def account_privileges(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountAccountPrivilegeArgs']]]]:
        return pulumi.get(self, "account_privileges")

    @account_privileges.setter
    def account_privileges(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountAccountPrivilegeArgs']]]]):
        pulumi.set(self, "account_privileges", value)

    @property
    @pulumi.getter
    def host(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        指定的数据库账号可以访问数据库的 IP 地址。
        """
        return pulumi.get(self, "host")

    @host.setter
    def host(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "host", value)

    @property
    @pulumi.getter(name="tableColumnPrivileges")
    def table_column_privileges(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountTableColumnPrivilegeArgs']]]]:
        return pulumi.get(self, "table_column_privileges")

    @table_column_privileges.setter
    def table_column_privileges(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountTableColumnPrivilegeArgs']]]]):
        pulumi.set(self, "table_column_privileges", value)


@pulumi.input_type
class _DbAccountState:
    def __init__(__self__, *,
                 account_desc: Optional[pulumi.Input[builtins.str]] = None,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 account_password: Optional[pulumi.Input[builtins.str]] = None,
                 account_privileges: Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountAccountPrivilegeArgs']]]] = None,
                 account_privileges_sqls: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 account_status: Optional[pulumi.Input[builtins.str]] = None,
                 account_type: Optional[pulumi.Input[builtins.str]] = None,
                 has_table_column_privilege_db_names: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 host: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 table_column_privileges: Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountTableColumnPrivilegeArgs']]]] = None):
        """
        Input properties used for looking up and filtering DbAccount resources.
        :param pulumi.Input[builtins.str] account_desc: 账号信息描述信息，长度不超过 256 个字符。
        :param pulumi.Input[builtins.str] account_name: 数据库账号名称。命名规则如下：长度为 2~32 个字符。以字母开头，以字母或数字结尾。由字母、数字、下划线（_）和中划线（-）组成。账号名称在实例内必须是唯一的。不能使用某些预留字，被禁用的预留字请参见禁用词列表。说明在高权限账号名称中可使用关键字 root 和 admin。
        :param pulumi.Input[builtins.str] account_password: 数据库账号的密码。规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] account_privileges_sqls: 账号的指定数据库权限信息的 SQL 语句。
        :param pulumi.Input[builtins.str] account_status: 账号状态，取值为：Unavailable：不可用。Available：可用。
        :param pulumi.Input[builtins.str] account_type: 账号类型，取值范围：Super：高权限账号。Normal：普通账号。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] has_table_column_privilege_db_names: 账号拥有的表列权限所属的数据库。说明如果账号没有表列权限，则不返回该字段。
        :param pulumi.Input[builtins.str] host: 指定的数据库账号可以访问数据库的 IP 地址。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        """
        if account_desc is not None:
            pulumi.set(__self__, "account_desc", account_desc)
        if account_name is not None:
            pulumi.set(__self__, "account_name", account_name)
        if account_password is not None:
            pulumi.set(__self__, "account_password", account_password)
        if account_privileges is not None:
            pulumi.set(__self__, "account_privileges", account_privileges)
        if account_privileges_sqls is not None:
            pulumi.set(__self__, "account_privileges_sqls", account_privileges_sqls)
        if account_status is not None:
            pulumi.set(__self__, "account_status", account_status)
        if account_type is not None:
            pulumi.set(__self__, "account_type", account_type)
        if has_table_column_privilege_db_names is not None:
            pulumi.set(__self__, "has_table_column_privilege_db_names", has_table_column_privilege_db_names)
        if host is not None:
            pulumi.set(__self__, "host", host)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if table_column_privileges is not None:
            pulumi.set(__self__, "table_column_privileges", table_column_privileges)

    @property
    @pulumi.getter(name="accountDesc")
    def account_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账号信息描述信息，长度不超过 256 个字符。
        """
        return pulumi.get(self, "account_desc")

    @account_desc.setter
    def account_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_desc", value)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        数据库账号名称。命名规则如下：长度为 2~32 个字符。以字母开头，以字母或数字结尾。由字母、数字、下划线（_）和中划线（-）组成。账号名称在实例内必须是唯一的。不能使用某些预留字，被禁用的预留字请参见禁用词列表。说明在高权限账号名称中可使用关键字 root 和 admin。
        """
        return pulumi.get(self, "account_name")

    @account_name.setter
    def account_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_name", value)

    @property
    @pulumi.getter(name="accountPassword")
    def account_password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        数据库账号的密码。规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        """
        return pulumi.get(self, "account_password")

    @account_password.setter
    def account_password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_password", value)

    @property
    @pulumi.getter(name="accountPrivileges")
    def account_privileges(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountAccountPrivilegeArgs']]]]:
        return pulumi.get(self, "account_privileges")

    @account_privileges.setter
    def account_privileges(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountAccountPrivilegeArgs']]]]):
        pulumi.set(self, "account_privileges", value)

    @property
    @pulumi.getter(name="accountPrivilegesSqls")
    def account_privileges_sqls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        账号的指定数据库权限信息的 SQL 语句。
        """
        return pulumi.get(self, "account_privileges_sqls")

    @account_privileges_sqls.setter
    def account_privileges_sqls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "account_privileges_sqls", value)

    @property
    @pulumi.getter(name="accountStatus")
    def account_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账号状态，取值为：Unavailable：不可用。Available：可用。
        """
        return pulumi.get(self, "account_status")

    @account_status.setter
    def account_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_status", value)

    @property
    @pulumi.getter(name="accountType")
    def account_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账号类型，取值范围：Super：高权限账号。Normal：普通账号。
        """
        return pulumi.get(self, "account_type")

    @account_type.setter
    def account_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_type", value)

    @property
    @pulumi.getter(name="hasTableColumnPrivilegeDbNames")
    def has_table_column_privilege_db_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        账号拥有的表列权限所属的数据库。说明如果账号没有表列权限，则不返回该字段。
        """
        return pulumi.get(self, "has_table_column_privilege_db_names")

    @has_table_column_privilege_db_names.setter
    def has_table_column_privilege_db_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "has_table_column_privilege_db_names", value)

    @property
    @pulumi.getter
    def host(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        指定的数据库账号可以访问数据库的 IP 地址。
        """
        return pulumi.get(self, "host")

    @host.setter
    def host(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "host", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="tableColumnPrivileges")
    def table_column_privileges(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountTableColumnPrivilegeArgs']]]]:
        return pulumi.get(self, "table_column_privileges")

    @table_column_privileges.setter
    def table_column_privileges(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountTableColumnPrivilegeArgs']]]]):
        pulumi.set(self, "table_column_privileges", value)


@pulumi.type_token("bytepluscc:rdsmysql/dbAccount:DbAccount")
class DbAccount(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_desc: Optional[pulumi.Input[builtins.str]] = None,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 account_password: Optional[pulumi.Input[builtins.str]] = None,
                 account_privileges: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DbAccountAccountPrivilegeArgs', 'DbAccountAccountPrivilegeArgsDict']]]]] = None,
                 account_type: Optional[pulumi.Input[builtins.str]] = None,
                 host: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 table_column_privileges: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DbAccountTableColumnPrivilegeArgs', 'DbAccountTableColumnPrivilegeArgsDict']]]]] = None,
                 __props__=None):
        """
        数据库账号

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdsmysql/dbAccount:DbAccount example "instance_id|account_name|host"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_desc: 账号信息描述信息，长度不超过 256 个字符。
        :param pulumi.Input[builtins.str] account_name: 数据库账号名称。命名规则如下：长度为 2~32 个字符。以字母开头，以字母或数字结尾。由字母、数字、下划线（_）和中划线（-）组成。账号名称在实例内必须是唯一的。不能使用某些预留字，被禁用的预留字请参见禁用词列表。说明在高权限账号名称中可使用关键字 root 和 admin。
        :param pulumi.Input[builtins.str] account_password: 数据库账号的密码。规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        :param pulumi.Input[builtins.str] account_type: 账号类型，取值范围：Super：高权限账号。Normal：普通账号。
        :param pulumi.Input[builtins.str] host: 指定的数据库账号可以访问数据库的 IP 地址。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DbAccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        数据库账号

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdsmysql/dbAccount:DbAccount example "instance_id|account_name|host"
        ```

        :param str resource_name: The name of the resource.
        :param DbAccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DbAccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_desc: Optional[pulumi.Input[builtins.str]] = None,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 account_password: Optional[pulumi.Input[builtins.str]] = None,
                 account_privileges: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DbAccountAccountPrivilegeArgs', 'DbAccountAccountPrivilegeArgsDict']]]]] = None,
                 account_type: Optional[pulumi.Input[builtins.str]] = None,
                 host: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 table_column_privileges: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DbAccountTableColumnPrivilegeArgs', 'DbAccountTableColumnPrivilegeArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DbAccountArgs.__new__(DbAccountArgs)

            __props__.__dict__["account_desc"] = account_desc
            if account_name is None and not opts.urn:
                raise TypeError("Missing required property 'account_name'")
            __props__.__dict__["account_name"] = account_name
            if account_password is None and not opts.urn:
                raise TypeError("Missing required property 'account_password'")
            __props__.__dict__["account_password"] = account_password
            __props__.__dict__["account_privileges"] = account_privileges
            if account_type is None and not opts.urn:
                raise TypeError("Missing required property 'account_type'")
            __props__.__dict__["account_type"] = account_type
            __props__.__dict__["host"] = host
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["table_column_privileges"] = table_column_privileges
            __props__.__dict__["account_privileges_sqls"] = None
            __props__.__dict__["account_status"] = None
            __props__.__dict__["has_table_column_privilege_db_names"] = None
        super(DbAccount, __self__).__init__(
            'bytepluscc:rdsmysql/dbAccount:DbAccount',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_desc: Optional[pulumi.Input[builtins.str]] = None,
            account_name: Optional[pulumi.Input[builtins.str]] = None,
            account_password: Optional[pulumi.Input[builtins.str]] = None,
            account_privileges: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DbAccountAccountPrivilegeArgs', 'DbAccountAccountPrivilegeArgsDict']]]]] = None,
            account_privileges_sqls: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            account_status: Optional[pulumi.Input[builtins.str]] = None,
            account_type: Optional[pulumi.Input[builtins.str]] = None,
            has_table_column_privilege_db_names: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            host: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            table_column_privileges: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DbAccountTableColumnPrivilegeArgs', 'DbAccountTableColumnPrivilegeArgsDict']]]]] = None) -> 'DbAccount':
        """
        Get an existing DbAccount resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_desc: 账号信息描述信息，长度不超过 256 个字符。
        :param pulumi.Input[builtins.str] account_name: 数据库账号名称。命名规则如下：长度为 2~32 个字符。以字母开头，以字母或数字结尾。由字母、数字、下划线（_）和中划线（-）组成。账号名称在实例内必须是唯一的。不能使用某些预留字，被禁用的预留字请参见禁用词列表。说明在高权限账号名称中可使用关键字 root 和 admin。
        :param pulumi.Input[builtins.str] account_password: 数据库账号的密码。规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] account_privileges_sqls: 账号的指定数据库权限信息的 SQL 语句。
        :param pulumi.Input[builtins.str] account_status: 账号状态，取值为：Unavailable：不可用。Available：可用。
        :param pulumi.Input[builtins.str] account_type: 账号类型，取值范围：Super：高权限账号。Normal：普通账号。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] has_table_column_privilege_db_names: 账号拥有的表列权限所属的数据库。说明如果账号没有表列权限，则不返回该字段。
        :param pulumi.Input[builtins.str] host: 指定的数据库账号可以访问数据库的 IP 地址。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DbAccountState.__new__(_DbAccountState)

        __props__.__dict__["account_desc"] = account_desc
        __props__.__dict__["account_name"] = account_name
        __props__.__dict__["account_password"] = account_password
        __props__.__dict__["account_privileges"] = account_privileges
        __props__.__dict__["account_privileges_sqls"] = account_privileges_sqls
        __props__.__dict__["account_status"] = account_status
        __props__.__dict__["account_type"] = account_type
        __props__.__dict__["has_table_column_privilege_db_names"] = has_table_column_privilege_db_names
        __props__.__dict__["host"] = host
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["table_column_privileges"] = table_column_privileges
        return DbAccount(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountDesc")
    def account_desc(self) -> pulumi.Output[builtins.str]:
        """
        账号信息描述信息，长度不超过 256 个字符。
        """
        return pulumi.get(self, "account_desc")

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Output[builtins.str]:
        """
        数据库账号名称。命名规则如下：长度为 2~32 个字符。以字母开头，以字母或数字结尾。由字母、数字、下划线（_）和中划线（-）组成。账号名称在实例内必须是唯一的。不能使用某些预留字，被禁用的预留字请参见禁用词列表。说明在高权限账号名称中可使用关键字 root 和 admin。
        """
        return pulumi.get(self, "account_name")

    @property
    @pulumi.getter(name="accountPassword")
    def account_password(self) -> pulumi.Output[builtins.str]:
        """
        数据库账号的密码。规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        """
        return pulumi.get(self, "account_password")

    @property
    @pulumi.getter(name="accountPrivileges")
    def account_privileges(self) -> pulumi.Output[Sequence['outputs.DbAccountAccountPrivilege']]:
        return pulumi.get(self, "account_privileges")

    @property
    @pulumi.getter(name="accountPrivilegesSqls")
    def account_privileges_sqls(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        账号的指定数据库权限信息的 SQL 语句。
        """
        return pulumi.get(self, "account_privileges_sqls")

    @property
    @pulumi.getter(name="accountStatus")
    def account_status(self) -> pulumi.Output[builtins.str]:
        """
        账号状态，取值为：Unavailable：不可用。Available：可用。
        """
        return pulumi.get(self, "account_status")

    @property
    @pulumi.getter(name="accountType")
    def account_type(self) -> pulumi.Output[builtins.str]:
        """
        账号类型，取值范围：Super：高权限账号。Normal：普通账号。
        """
        return pulumi.get(self, "account_type")

    @property
    @pulumi.getter(name="hasTableColumnPrivilegeDbNames")
    def has_table_column_privilege_db_names(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        账号拥有的表列权限所属的数据库。说明如果账号没有表列权限，则不返回该字段。
        """
        return pulumi.get(self, "has_table_column_privilege_db_names")

    @property
    @pulumi.getter
    def host(self) -> pulumi.Output[builtins.str]:
        """
        指定的数据库账号可以访问数据库的 IP 地址。
        """
        return pulumi.get(self, "host")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="tableColumnPrivileges")
    def table_column_privileges(self) -> pulumi.Output[Sequence['outputs.DbAccountTableColumnPrivilege']]:
        return pulumi.get(self, "table_column_privileges")

