# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstanceEndpoint',
    'InstanceTag',
    'GetInstanceEndpointResult',
    'GetInstanceTagResult',
]

@pulumi.output_type
class InstanceEndpoint(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "addressType":
            suggest = "address_type"
        elif key == "eipId":
            suggest = "eip_id"
        elif key == "endpointId":
            suggest = "endpoint_id"
        elif key == "endpointStr":
            suggest = "endpoint_str"
        elif key == "networkType":
            suggest = "network_type"
        elif key == "privateDnsVisibility":
            suggest = "private_dns_visibility"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceEndpoint. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceEndpoint.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceEndpoint.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 address_type: Optional[builtins.str] = None,
                 eip_id: Optional[builtins.str] = None,
                 endpoint_id: Optional[builtins.str] = None,
                 endpoint_str: Optional[builtins.str] = None,
                 network_type: Optional[builtins.str] = None,
                 private_dns_visibility: Optional[builtins.bool] = None):
        """
        :param builtins.str address_type: 连接地址类型，关于连接地址的更多信息，请参见连接地址类型。取值范围如下：Zk：ZK 地址。Thrift：Thrift2 地址。HBaseReUsedEipId：当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示实例中其他组件（如 RS 节点、Master 节点等）共享绑定使用的 EIP ID 信息。
        :param builtins.str eip_id: 当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示 EIP ID。
        :param builtins.str endpoint_id: 连接地址 ID。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的 ID。当连接地址类型为 HBaseReUsedEipId 时，连接地址 ID 也固定为 HBaseReUsedEipId。
        :param builtins.str endpoint_str: 连接地址的连接串。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的连接串。当连接地址类型为 HBaseReUsedEipId 时，连接地址的连接串也固定为 HBaseReUsedEipId。
        :param builtins.str network_type: 连接地址网络类型。取值范围如下：Public：公网访问地址。Private：私网访问地址。
        :param builtins.bool private_dns_visibility: 私网域名是否开启公网解析。
        """
        if address_type is not None:
            pulumi.set(__self__, "address_type", address_type)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if endpoint_id is not None:
            pulumi.set(__self__, "endpoint_id", endpoint_id)
        if endpoint_str is not None:
            pulumi.set(__self__, "endpoint_str", endpoint_str)
        if network_type is not None:
            pulumi.set(__self__, "network_type", network_type)
        if private_dns_visibility is not None:
            pulumi.set(__self__, "private_dns_visibility", private_dns_visibility)

    @property
    @pulumi.getter(name="addressType")
    def address_type(self) -> Optional[builtins.str]:
        """
        连接地址类型，关于连接地址的更多信息，请参见连接地址类型。取值范围如下：Zk：ZK 地址。Thrift：Thrift2 地址。HBaseReUsedEipId：当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示实例中其他组件（如 RS 节点、Master 节点等）共享绑定使用的 EIP ID 信息。
        """
        return pulumi.get(self, "address_type")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[builtins.str]:
        """
        当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示 EIP ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> Optional[builtins.str]:
        """
        连接地址 ID。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的 ID。当连接地址类型为 HBaseReUsedEipId 时，连接地址 ID 也固定为 HBaseReUsedEipId。
        """
        return pulumi.get(self, "endpoint_id")

    @property
    @pulumi.getter(name="endpointStr")
    def endpoint_str(self) -> Optional[builtins.str]:
        """
        连接地址的连接串。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的连接串。当连接地址类型为 HBaseReUsedEipId 时，连接地址的连接串也固定为 HBaseReUsedEipId。
        """
        return pulumi.get(self, "endpoint_str")

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> Optional[builtins.str]:
        """
        连接地址网络类型。取值范围如下：Public：公网访问地址。Private：私网访问地址。
        """
        return pulumi.get(self, "network_type")

    @property
    @pulumi.getter(name="privateDnsVisibility")
    def private_dns_visibility(self) -> Optional[builtins.bool]:
        """
        私网域名是否开启公网解析。
        """
        return pulumi.get(self, "private_dns_visibility")


@pulumi.output_type
class InstanceTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 实例所绑定标签的标签键。
        :param builtins.str value: 实例所绑定标签的标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        实例所绑定标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        实例所绑定标签的标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetInstanceEndpointResult(dict):
    def __init__(__self__, *,
                 address_type: builtins.str,
                 eip_id: builtins.str,
                 endpoint_id: builtins.str,
                 endpoint_str: builtins.str,
                 network_type: builtins.str,
                 private_dns_visibility: builtins.bool):
        """
        :param builtins.str address_type: 连接地址类型，关于连接地址的更多信息，请参见连接地址类型。取值范围如下：Zk：ZK 地址。Thrift：Thrift2 地址。HBaseReUsedEipId：当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示实例中其他组件（如 RS 节点、Master 节点等）共享绑定使用的 EIP ID 信息。
        :param builtins.str eip_id: 当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示 EIP ID。
        :param builtins.str endpoint_id: 连接地址 ID。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的 ID。当连接地址类型为 HBaseReUsedEipId 时，连接地址 ID 也固定为 HBaseReUsedEipId。
        :param builtins.str endpoint_str: 连接地址的连接串。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的连接串。当连接地址类型为 HBaseReUsedEipId 时，连接地址的连接串也固定为 HBaseReUsedEipId。
        :param builtins.str network_type: 连接地址网络类型。取值范围如下：Public：公网访问地址。Private：私网访问地址。
        :param builtins.bool private_dns_visibility: 私网域名是否开启公网解析。
        """
        pulumi.set(__self__, "address_type", address_type)
        pulumi.set(__self__, "eip_id", eip_id)
        pulumi.set(__self__, "endpoint_id", endpoint_id)
        pulumi.set(__self__, "endpoint_str", endpoint_str)
        pulumi.set(__self__, "network_type", network_type)
        pulumi.set(__self__, "private_dns_visibility", private_dns_visibility)

    @property
    @pulumi.getter(name="addressType")
    def address_type(self) -> builtins.str:
        """
        连接地址类型，关于连接地址的更多信息，请参见连接地址类型。取值范围如下：Zk：ZK 地址。Thrift：Thrift2 地址。HBaseReUsedEipId：当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示实例中其他组件（如 RS 节点、Master 节点等）共享绑定使用的 EIP ID 信息。
        """
        return pulumi.get(self, "address_type")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> builtins.str:
        """
        当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示 EIP ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> builtins.str:
        """
        连接地址 ID。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的 ID。当连接地址类型为 HBaseReUsedEipId 时，连接地址 ID 也固定为 HBaseReUsedEipId。
        """
        return pulumi.get(self, "endpoint_id")

    @property
    @pulumi.getter(name="endpointStr")
    def endpoint_str(self) -> builtins.str:
        """
        连接地址的连接串。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的连接串。当连接地址类型为 HBaseReUsedEipId 时，连接地址的连接串也固定为 HBaseReUsedEipId。
        """
        return pulumi.get(self, "endpoint_str")

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> builtins.str:
        """
        连接地址网络类型。取值范围如下：Public：公网访问地址。Private：私网访问地址。
        """
        return pulumi.get(self, "network_type")

    @property
    @pulumi.getter(name="privateDnsVisibility")
    def private_dns_visibility(self) -> builtins.bool:
        """
        私网域名是否开启公网解析。
        """
        return pulumi.get(self, "private_dns_visibility")


@pulumi.output_type
class GetInstanceTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 实例所绑定标签的标签键。
        :param builtins.str value: 实例所绑定标签的标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        实例所绑定标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        实例所绑定标签的标签值。
        """
        return pulumi.get(self, "value")


