# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'KafkaTriggerKafkaCredentials',
    'SandboxEnv',
    'SandboxInstanceImageInfo',
    'SandboxInstanceTosMountConfig',
    'SandboxInstanceTosMountConfigTosMountPoint',
    'SandboxMetadata',
    'GetKafkaTriggerKafkaCredentialsResult',
    'GetSandboxEnvResult',
    'GetSandboxInstanceImageInfoResult',
    'GetSandboxInstanceTosMountConfigResult',
    'GetSandboxInstanceTosMountConfigTosMountPointResult',
    'GetSandboxMetadataResult',
]

@pulumi.output_type
class KafkaTriggerKafkaCredentials(dict):
    def __init__(__self__, *,
                 mechanism: Optional[builtins.str] = None,
                 password: Optional[builtins.str] = None,
                 username: Optional[builtins.str] = None):
        """
        :param builtins.str mechanism: Kafka 认证机制。取值：PLAIN，SCRAM-SHA-256。
        :param builtins.str password: 创建 Kafka 实例时设置的 SASL/PLAIN 用户密码。
        :param builtins.str username: 创建 Kafka 实例时设置的 SASL/PLAIN 用户名称。
        """
        if mechanism is not None:
            pulumi.set(__self__, "mechanism", mechanism)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def mechanism(self) -> Optional[builtins.str]:
        """
        Kafka 认证机制。取值：PLAIN，SCRAM-SHA-256。
        """
        return pulumi.get(self, "mechanism")

    @property
    @pulumi.getter
    def password(self) -> Optional[builtins.str]:
        """
        创建 Kafka 实例时设置的 SASL/PLAIN 用户密码。
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def username(self) -> Optional[builtins.str]:
        """
        创建 Kafka 实例时设置的 SASL/PLAIN 用户名称。
        """
        return pulumi.get(self, "username")


@pulumi.output_type
class SandboxEnv(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 环境变量键。
        :param builtins.str value: 环境变量值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        环境变量键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        环境变量值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class SandboxInstanceImageInfo(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "imageId":
            suggest = "image_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SandboxInstanceImageInfo. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SandboxInstanceImageInfo.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SandboxInstanceImageInfo.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 command: Optional[builtins.str] = None,
                 image: Optional[builtins.str] = None,
                 image_id: Optional[builtins.str] = None,
                 port: Optional[builtins.int] = None):
        """
        :param builtins.str command: 沙箱实例程序的启动命令。如需指定脚本文件，请使用绝对路径，并确保脚本具有相应的可执行权限。
        :param builtins.str image: 沙箱实例使用的已预热镜像地址。
        :param builtins.str image_id: 沙箱实例使用的已预热镜像 ID。
        :param builtins.int port: 沙箱实例镜像监听端口。
        """
        if command is not None:
            pulumi.set(__self__, "command", command)
        if image is not None:
            pulumi.set(__self__, "image", image)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @property
    @pulumi.getter
    def command(self) -> Optional[builtins.str]:
        """
        沙箱实例程序的启动命令。如需指定脚本文件，请使用绝对路径，并确保脚本具有相应的可执行权限。
        """
        return pulumi.get(self, "command")

    @property
    @pulumi.getter
    def image(self) -> Optional[builtins.str]:
        """
        沙箱实例使用的已预热镜像地址。
        """
        return pulumi.get(self, "image")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[builtins.str]:
        """
        沙箱实例使用的已预热镜像 ID。
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter
    def port(self) -> Optional[builtins.int]:
        """
        沙箱实例镜像监听端口。
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class SandboxInstanceTosMountConfig(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "tosMountPoints":
            suggest = "tos_mount_points"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SandboxInstanceTosMountConfig. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SandboxInstanceTosMountConfig.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SandboxInstanceTosMountConfig.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 enable: Optional[builtins.bool] = None,
                 tos_mount_points: Optional[Sequence['outputs.SandboxInstanceTosMountConfigTosMountPoint']] = None):
        """
        :param builtins.bool enable: 沙箱实例是否启用了实例级别的 TOS 挂载，参数值说明：true：是，false：否。
        """
        if enable is not None:
            pulumi.set(__self__, "enable", enable)
        if tos_mount_points is not None:
            pulumi.set(__self__, "tos_mount_points", tos_mount_points)

    @property
    @pulumi.getter
    def enable(self) -> Optional[builtins.bool]:
        """
        沙箱实例是否启用了实例级别的 TOS 挂载，参数值说明：true：是，false：否。
        """
        return pulumi.get(self, "enable")

    @property
    @pulumi.getter(name="tosMountPoints")
    def tos_mount_points(self) -> Optional[Sequence['outputs.SandboxInstanceTosMountConfigTosMountPoint']]:
        return pulumi.get(self, "tos_mount_points")


@pulumi.output_type
class SandboxInstanceTosMountConfigTosMountPoint(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "bucketPath":
            suggest = "bucket_path"
        elif key == "localMountPath":
            suggest = "local_mount_path"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SandboxInstanceTosMountConfigTosMountPoint. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SandboxInstanceTosMountConfigTosMountPoint.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SandboxInstanceTosMountConfigTosMountPoint.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 bucket_path: Optional[builtins.str] = None,
                 local_mount_path: Optional[builtins.str] = None):
        """
        :param builtins.str bucket_path: 沙箱实例挂载的 TOS 远端目录。
        :param builtins.str local_mount_path: 沙箱实例挂载的 TOS 存储桶本地目录。该目录为沙箱应用已配置的 TOS 存储挂载的本地目录时，系统根据指定的本地目录，修改与之对应的 TOS BucketPath。
        """
        if bucket_path is not None:
            pulumi.set(__self__, "bucket_path", bucket_path)
        if local_mount_path is not None:
            pulumi.set(__self__, "local_mount_path", local_mount_path)

    @property
    @pulumi.getter(name="bucketPath")
    def bucket_path(self) -> Optional[builtins.str]:
        """
        沙箱实例挂载的 TOS 远端目录。
        """
        return pulumi.get(self, "bucket_path")

    @property
    @pulumi.getter(name="localMountPath")
    def local_mount_path(self) -> Optional[builtins.str]:
        """
        沙箱实例挂载的 TOS 存储桶本地目录。该目录为沙箱应用已配置的 TOS 存储挂载的本地目录时，系统根据指定的本地目录，修改与之对应的 TOS BucketPath。
        """
        return pulumi.get(self, "local_mount_path")


@pulumi.output_type
class SandboxMetadata(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetKafkaTriggerKafkaCredentialsResult(dict):
    def __init__(__self__, *,
                 mechanism: builtins.str,
                 password: builtins.str,
                 username: builtins.str):
        """
        :param builtins.str mechanism: Kafka 认证机制。取值：PLAIN，SCRAM-SHA-256。
        :param builtins.str password: 创建 Kafka 实例时设置的 SASL/PLAIN 用户密码。
        :param builtins.str username: 创建 Kafka 实例时设置的 SASL/PLAIN 用户名称。
        """
        pulumi.set(__self__, "mechanism", mechanism)
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def mechanism(self) -> builtins.str:
        """
        Kafka 认证机制。取值：PLAIN，SCRAM-SHA-256。
        """
        return pulumi.get(self, "mechanism")

    @property
    @pulumi.getter
    def password(self) -> builtins.str:
        """
        创建 Kafka 实例时设置的 SASL/PLAIN 用户密码。
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def username(self) -> builtins.str:
        """
        创建 Kafka 实例时设置的 SASL/PLAIN 用户名称。
        """
        return pulumi.get(self, "username")


@pulumi.output_type
class GetSandboxEnvResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 环境变量键。
        :param builtins.str value: 环境变量值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        环境变量键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        环境变量值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetSandboxInstanceImageInfoResult(dict):
    def __init__(__self__, *,
                 command: builtins.str,
                 image: builtins.str,
                 image_id: builtins.str,
                 port: builtins.int):
        """
        :param builtins.str command: 沙箱实例程序的启动命令。如需指定脚本文件，请使用绝对路径，并确保脚本具有相应的可执行权限。
        :param builtins.str image: 沙箱实例使用的已预热镜像地址。
        :param builtins.str image_id: 沙箱实例使用的已预热镜像 ID。
        :param builtins.int port: 沙箱实例镜像监听端口。
        """
        pulumi.set(__self__, "command", command)
        pulumi.set(__self__, "image", image)
        pulumi.set(__self__, "image_id", image_id)
        pulumi.set(__self__, "port", port)

    @property
    @pulumi.getter
    def command(self) -> builtins.str:
        """
        沙箱实例程序的启动命令。如需指定脚本文件，请使用绝对路径，并确保脚本具有相应的可执行权限。
        """
        return pulumi.get(self, "command")

    @property
    @pulumi.getter
    def image(self) -> builtins.str:
        """
        沙箱实例使用的已预热镜像地址。
        """
        return pulumi.get(self, "image")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> builtins.str:
        """
        沙箱实例使用的已预热镜像 ID。
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter
    def port(self) -> builtins.int:
        """
        沙箱实例镜像监听端口。
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class GetSandboxInstanceTosMountConfigResult(dict):
    def __init__(__self__, *,
                 enable: builtins.bool,
                 tos_mount_points: Sequence['outputs.GetSandboxInstanceTosMountConfigTosMountPointResult']):
        """
        :param builtins.bool enable: 沙箱实例是否启用了实例级别的 TOS 挂载，参数值说明：true：是，false：否。
        :param Sequence['GetSandboxInstanceTosMountConfigTosMountPointArgs'] tos_mount_points: 启用了实例级别 TOS 挂载的沙箱实例具体 TOS 挂载目录信息。
        """
        pulumi.set(__self__, "enable", enable)
        pulumi.set(__self__, "tos_mount_points", tos_mount_points)

    @property
    @pulumi.getter
    def enable(self) -> builtins.bool:
        """
        沙箱实例是否启用了实例级别的 TOS 挂载，参数值说明：true：是，false：否。
        """
        return pulumi.get(self, "enable")

    @property
    @pulumi.getter(name="tosMountPoints")
    def tos_mount_points(self) -> Sequence['outputs.GetSandboxInstanceTosMountConfigTosMountPointResult']:
        """
        启用了实例级别 TOS 挂载的沙箱实例具体 TOS 挂载目录信息。
        """
        return pulumi.get(self, "tos_mount_points")


@pulumi.output_type
class GetSandboxInstanceTosMountConfigTosMountPointResult(dict):
    def __init__(__self__, *,
                 bucket_path: builtins.str,
                 local_mount_path: builtins.str):
        """
        :param builtins.str bucket_path: 沙箱实例挂载的 TOS 远端目录。
        :param builtins.str local_mount_path: 沙箱实例挂载的 TOS 存储桶本地目录。该目录为沙箱应用已配置的 TOS 存储挂载的本地目录时，系统根据指定的本地目录，修改与之对应的 TOS BucketPath。
        """
        pulumi.set(__self__, "bucket_path", bucket_path)
        pulumi.set(__self__, "local_mount_path", local_mount_path)

    @property
    @pulumi.getter(name="bucketPath")
    def bucket_path(self) -> builtins.str:
        """
        沙箱实例挂载的 TOS 远端目录。
        """
        return pulumi.get(self, "bucket_path")

    @property
    @pulumi.getter(name="localMountPath")
    def local_mount_path(self) -> builtins.str:
        """
        沙箱实例挂载的 TOS 存储桶本地目录。该目录为沙箱应用已配置的 TOS 存储挂载的本地目录时，系统根据指定的本地目录，修改与之对应的 TOS BucketPath。
        """
        return pulumi.get(self, "local_mount_path")


@pulumi.output_type
class GetSandboxMetadataResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        标签值。
        """
        return pulumi.get(self, "value")


