# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetCenResult',
    'AwaitableGetCenResult',
    'get_cen',
    'get_cen_output',
]

@pulumi.output_type
class GetCenResult:
    """
    A collection of values returned by getCen.
    """
    def __init__(__self__, account_id=None, cen_bandwidth_package_ids=None, cen_id=None, cen_name=None, creation_time=None, description=None, id=None, project_name=None, status=None, tags=None, update_time=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if cen_bandwidth_package_ids and not isinstance(cen_bandwidth_package_ids, list):
            raise TypeError("Expected argument 'cen_bandwidth_package_ids' to be a list")
        pulumi.set(__self__, "cen_bandwidth_package_ids", cen_bandwidth_package_ids)
        if cen_id and not isinstance(cen_id, str):
            raise TypeError("Expected argument 'cen_id' to be a str")
        pulumi.set(__self__, "cen_id", cen_id)
        if cen_name and not isinstance(cen_name, str):
            raise TypeError("Expected argument 'cen_name' to be a str")
        pulumi.set(__self__, "cen_name", cen_name)
        if creation_time and not isinstance(creation_time, str):
            raise TypeError("Expected argument 'creation_time' to be a str")
        pulumi.set(__self__, "creation_time", creation_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if update_time and not isinstance(update_time, str):
            raise TypeError("Expected argument 'update_time' to be a str")
        pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.str:
        """
        CEN实例所属的账号ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="cenBandwidthPackageIds")
    def cen_bandwidth_package_ids(self) -> Sequence[builtins.str]:
        """
        带宽包ID。
        """
        return pulumi.get(self, "cen_bandwidth_package_ids")

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> builtins.str:
        """
        CEN实例的ID。
        """
        return pulumi.get(self, "cen_id")

    @property
    @pulumi.getter(name="cenName")
    def cen_name(self) -> builtins.str:
        """
        CEN实例的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制为1～128个字符。不填则默认为CEN实例的ID。
        """
        return pulumi.get(self, "cen_name")

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> builtins.str:
        """
        创建CEN实例的时间。
        """
        return pulumi.get(self, "creation_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        CEN实例的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0～255个字符。不填则默认为空。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        CEN实例所属项目的名称。不填则默认为default。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        CEN实例的状态。Creating: 创建中Deleting: 删除中Pending：配置中Available：可用
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetCenTagResult']:
        """
        标签信息。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> builtins.str:
        """
        更新CEN实例的时间。
        """
        return pulumi.get(self, "update_time")


class AwaitableGetCenResult(GetCenResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCenResult(
            account_id=self.account_id,
            cen_bandwidth_package_ids=self.cen_bandwidth_package_ids,
            cen_id=self.cen_id,
            cen_name=self.cen_name,
            creation_time=self.creation_time,
            description=self.description,
            id=self.id,
            project_name=self.project_name,
            status=self.status,
            tags=self.tags,
            update_time=self.update_time)


def get_cen(id: Optional[builtins.str] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCenResult:
    """
    Data Source schema for Byteplus::CEN::CEN


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:cen/getCen:getCen', __args__, opts=opts, typ=GetCenResult).value

    return AwaitableGetCenResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        cen_bandwidth_package_ids=pulumi.get(__ret__, 'cen_bandwidth_package_ids'),
        cen_id=pulumi.get(__ret__, 'cen_id'),
        cen_name=pulumi.get(__ret__, 'cen_name'),
        creation_time=pulumi.get(__ret__, 'creation_time'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        project_name=pulumi.get(__ret__, 'project_name'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        update_time=pulumi.get(__ret__, 'update_time'))
def get_cen_output(id: Optional[pulumi.Input[builtins.str]] = None,
                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCenResult]:
    """
    Data Source schema for Byteplus::CEN::CEN


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:cen/getCen:getCen', __args__, opts=opts, typ=GetCenResult)
    return __ret__.apply(lambda __response__: GetCenResult(
        account_id=pulumi.get(__response__, 'account_id'),
        cen_bandwidth_package_ids=pulumi.get(__response__, 'cen_bandwidth_package_ids'),
        cen_id=pulumi.get(__response__, 'cen_id'),
        cen_name=pulumi.get(__response__, 'cen_name'),
        creation_time=pulumi.get(__response__, 'creation_time'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        project_name=pulumi.get(__response__, 'project_name'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        update_time=pulumi.get(__response__, 'update_time')))
