# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'ShareConfigAllowIpAccessRule',
    'ShareConfigAllowRefererAccessRule',
    'ShareConfigAllowRefererAccessRuleCommonType',
    'ShareConfigCommonMatchs',
    'ShareConfigCommonMatchsCommonType',
    'ShareConfigDenyIpAccessRule',
    'ShareConfigDenyRefererAccessRule',
    'ShareConfigDenyRefererAccessRuleCommonType',
    'GetShareConfigAllowIpAccessRuleResult',
    'GetShareConfigAllowRefererAccessRuleResult',
    'GetShareConfigAllowRefererAccessRuleCommonTypeResult',
    'GetShareConfigCommonMatchsResult',
    'GetShareConfigCommonMatchsCommonTypeResult',
    'GetShareConfigDenyIpAccessRuleResult',
    'GetShareConfigDenyRefererAccessRuleResult',
    'GetShareConfigDenyRefererAccessRuleCommonTypeResult',
]

@pulumi.output_type
class ShareConfigAllowIpAccessRule(dict):
    def __init__(__self__, *,
                 rules: Optional[Sequence[builtins.str]] = None):
        """
        :param Sequence[builtins.str] rules: 表示一个条目列表。列表中的每个条目是一个 IP 地址或 CIDR 网段。IP 地址和网段可以是 IPv4 和 IPv6 格式。列表的额度如下：对于 AddSharedConfig，列表中条目的数量不能超过 30,000 个。
        """
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter
    def rules(self) -> Optional[Sequence[builtins.str]]:
        """
        表示一个条目列表。列表中的每个条目是一个 IP 地址或 CIDR 网段。IP 地址和网段可以是 IPv4 和 IPv6 格式。列表的额度如下：对于 AddSharedConfig，列表中条目的数量不能超过 30,000 个。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class ShareConfigAllowRefererAccessRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "allowEmpty":
            suggest = "allow_empty"
        elif key == "commonType":
            suggest = "common_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ShareConfigAllowRefererAccessRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ShareConfigAllowRefererAccessRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ShareConfigAllowRefererAccessRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 allow_empty: Optional[builtins.bool] = None,
                 common_type: Optional['outputs.ShareConfigAllowRefererAccessRuleCommonType'] = None):
        """
        :param builtins.bool allow_empty: 表示是否不允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。false：表示允许。该参数的默认值是 false。
        :param 'ShareConfigAllowRefererAccessRuleCommonTypeArgs' common_type: 表示该通用列表的内容。
        """
        if allow_empty is not None:
            pulumi.set(__self__, "allow_empty", allow_empty)
        if common_type is not None:
            pulumi.set(__self__, "common_type", common_type)

    @property
    @pulumi.getter(name="allowEmpty")
    def allow_empty(self) -> Optional[builtins.bool]:
        """
        表示是否不允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。false：表示允许。该参数的默认值是 false。
        """
        return pulumi.get(self, "allow_empty")

    @property
    @pulumi.getter(name="commonType")
    def common_type(self) -> Optional['outputs.ShareConfigAllowRefererAccessRuleCommonType']:
        """
        表示该通用列表的内容。
        """
        return pulumi.get(self, "common_type")


@pulumi.output_type
class ShareConfigAllowRefererAccessRuleCommonType(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ignoreCase":
            suggest = "ignore_case"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ShareConfigAllowRefererAccessRuleCommonType. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ShareConfigAllowRefererAccessRuleCommonType.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ShareConfigAllowRefererAccessRuleCommonType.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ignore_case: Optional[builtins.bool] = None,
                 rules: Optional[Sequence[builtins.str]] = None):
        """
        :param builtins.bool ignore_case: 表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        :param Sequence[builtins.str] rules: 表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        if ignore_case is not None:
            pulumi.set(__self__, "ignore_case", ignore_case)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="ignoreCase")
    def ignore_case(self) -> Optional[builtins.bool]:
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        return pulumi.get(self, "ignore_case")

    @property
    @pulumi.getter
    def rules(self) -> Optional[Sequence[builtins.str]]:
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class ShareConfigCommonMatchs(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "commonType":
            suggest = "common_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ShareConfigCommonMatchs. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ShareConfigCommonMatchs.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ShareConfigCommonMatchs.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 common_type: Optional['outputs.ShareConfigCommonMatchsCommonType'] = None):
        """
        :param 'ShareConfigCommonMatchsCommonTypeArgs' common_type: 表示该通用列表的内容。
        """
        if common_type is not None:
            pulumi.set(__self__, "common_type", common_type)

    @property
    @pulumi.getter(name="commonType")
    def common_type(self) -> Optional['outputs.ShareConfigCommonMatchsCommonType']:
        """
        表示该通用列表的内容。
        """
        return pulumi.get(self, "common_type")


@pulumi.output_type
class ShareConfigCommonMatchsCommonType(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ignoreCase":
            suggest = "ignore_case"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ShareConfigCommonMatchsCommonType. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ShareConfigCommonMatchsCommonType.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ShareConfigCommonMatchsCommonType.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ignore_case: Optional[builtins.bool] = None,
                 rules: Optional[Sequence[builtins.str]] = None):
        """
        :param builtins.bool ignore_case: 表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        :param Sequence[builtins.str] rules: 表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        if ignore_case is not None:
            pulumi.set(__self__, "ignore_case", ignore_case)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="ignoreCase")
    def ignore_case(self) -> Optional[builtins.bool]:
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        return pulumi.get(self, "ignore_case")

    @property
    @pulumi.getter
    def rules(self) -> Optional[Sequence[builtins.str]]:
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class ShareConfigDenyIpAccessRule(dict):
    def __init__(__self__, *,
                 rules: Optional[Sequence[builtins.str]] = None):
        """
        :param Sequence[builtins.str] rules: 表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access_rule。
        """
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter
    def rules(self) -> Optional[Sequence[builtins.str]]:
        """
        表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access_rule。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class ShareConfigDenyRefererAccessRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "allowEmpty":
            suggest = "allow_empty"
        elif key == "commonType":
            suggest = "common_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ShareConfigDenyRefererAccessRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ShareConfigDenyRefererAccessRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ShareConfigDenyRefererAccessRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 allow_empty: Optional[builtins.bool] = None,
                 common_type: Optional['outputs.ShareConfigDenyRefererAccessRuleCommonType'] = None):
        """
        :param builtins.bool allow_empty: 表示是否允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示允许。false：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。该参数的默认值是 true。
        :param 'ShareConfigDenyRefererAccessRuleCommonTypeArgs' common_type: 表示该通用列表的内容。
        """
        if allow_empty is not None:
            pulumi.set(__self__, "allow_empty", allow_empty)
        if common_type is not None:
            pulumi.set(__self__, "common_type", common_type)

    @property
    @pulumi.getter(name="allowEmpty")
    def allow_empty(self) -> Optional[builtins.bool]:
        """
        表示是否允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示允许。false：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。该参数的默认值是 true。
        """
        return pulumi.get(self, "allow_empty")

    @property
    @pulumi.getter(name="commonType")
    def common_type(self) -> Optional['outputs.ShareConfigDenyRefererAccessRuleCommonType']:
        """
        表示该通用列表的内容。
        """
        return pulumi.get(self, "common_type")


@pulumi.output_type
class ShareConfigDenyRefererAccessRuleCommonType(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ignoreCase":
            suggest = "ignore_case"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ShareConfigDenyRefererAccessRuleCommonType. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ShareConfigDenyRefererAccessRuleCommonType.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ShareConfigDenyRefererAccessRuleCommonType.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ignore_case: Optional[builtins.bool] = None,
                 rules: Optional[Sequence[builtins.str]] = None):
        """
        :param builtins.bool ignore_case: 表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        :param Sequence[builtins.str] rules: 表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        if ignore_case is not None:
            pulumi.set(__self__, "ignore_case", ignore_case)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="ignoreCase")
    def ignore_case(self) -> Optional[builtins.bool]:
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        return pulumi.get(self, "ignore_case")

    @property
    @pulumi.getter
    def rules(self) -> Optional[Sequence[builtins.str]]:
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class GetShareConfigAllowIpAccessRuleResult(dict):
    def __init__(__self__, *,
                 rules: Sequence[builtins.str]):
        """
        :param Sequence[builtins.str] rules: 表示一个条目列表。列表中的每个条目是一个 IP 地址或 CIDR 网段。IP 地址和网段可以是 IPv4 和 IPv6 格式。列表的额度如下：对于 AddSharedConfig，列表中条目的数量不能超过 30,000 个。
        """
        pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter
    def rules(self) -> Sequence[builtins.str]:
        """
        表示一个条目列表。列表中的每个条目是一个 IP 地址或 CIDR 网段。IP 地址和网段可以是 IPv4 和 IPv6 格式。列表的额度如下：对于 AddSharedConfig，列表中条目的数量不能超过 30,000 个。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class GetShareConfigAllowRefererAccessRuleResult(dict):
    def __init__(__self__, *,
                 allow_empty: builtins.bool,
                 common_type: 'outputs.GetShareConfigAllowRefererAccessRuleCommonTypeResult'):
        """
        :param builtins.bool allow_empty: 表示是否不允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。false：表示允许。该参数的默认值是 false。
        :param 'GetShareConfigAllowRefererAccessRuleCommonTypeArgs' common_type: 表示该通用列表的内容。
        """
        pulumi.set(__self__, "allow_empty", allow_empty)
        pulumi.set(__self__, "common_type", common_type)

    @property
    @pulumi.getter(name="allowEmpty")
    def allow_empty(self) -> builtins.bool:
        """
        表示是否不允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。false：表示允许。该参数的默认值是 false。
        """
        return pulumi.get(self, "allow_empty")

    @property
    @pulumi.getter(name="commonType")
    def common_type(self) -> 'outputs.GetShareConfigAllowRefererAccessRuleCommonTypeResult':
        """
        表示该通用列表的内容。
        """
        return pulumi.get(self, "common_type")


@pulumi.output_type
class GetShareConfigAllowRefererAccessRuleCommonTypeResult(dict):
    def __init__(__self__, *,
                 ignore_case: builtins.bool,
                 rules: Sequence[builtins.str]):
        """
        :param builtins.bool ignore_case: 表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        :param Sequence[builtins.str] rules: 表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        pulumi.set(__self__, "ignore_case", ignore_case)
        pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="ignoreCase")
    def ignore_case(self) -> builtins.bool:
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        return pulumi.get(self, "ignore_case")

    @property
    @pulumi.getter
    def rules(self) -> Sequence[builtins.str]:
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class GetShareConfigCommonMatchsResult(dict):
    def __init__(__self__, *,
                 common_type: 'outputs.GetShareConfigCommonMatchsCommonTypeResult'):
        """
        :param 'GetShareConfigCommonMatchsCommonTypeArgs' common_type: 表示该通用列表的内容。
        """
        pulumi.set(__self__, "common_type", common_type)

    @property
    @pulumi.getter(name="commonType")
    def common_type(self) -> 'outputs.GetShareConfigCommonMatchsCommonTypeResult':
        """
        表示该通用列表的内容。
        """
        return pulumi.get(self, "common_type")


@pulumi.output_type
class GetShareConfigCommonMatchsCommonTypeResult(dict):
    def __init__(__self__, *,
                 ignore_case: builtins.bool,
                 rules: Sequence[builtins.str]):
        """
        :param builtins.bool ignore_case: 表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        :param Sequence[builtins.str] rules: 表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        pulumi.set(__self__, "ignore_case", ignore_case)
        pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="ignoreCase")
    def ignore_case(self) -> builtins.bool:
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        return pulumi.get(self, "ignore_case")

    @property
    @pulumi.getter
    def rules(self) -> Sequence[builtins.str]:
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class GetShareConfigDenyIpAccessRuleResult(dict):
    def __init__(__self__, *,
                 rules: Sequence[builtins.str]):
        """
        :param Sequence[builtins.str] rules: 表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access_rule。
        """
        pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter
    def rules(self) -> Sequence[builtins.str]:
        """
        表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access_rule。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class GetShareConfigDenyRefererAccessRuleResult(dict):
    def __init__(__self__, *,
                 allow_empty: builtins.bool,
                 common_type: 'outputs.GetShareConfigDenyRefererAccessRuleCommonTypeResult'):
        """
        :param builtins.bool allow_empty: 表示是否允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示允许。false：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。该参数的默认值是 true。
        :param 'GetShareConfigDenyRefererAccessRuleCommonTypeArgs' common_type: 表示该通用列表的内容。
        """
        pulumi.set(__self__, "allow_empty", allow_empty)
        pulumi.set(__self__, "common_type", common_type)

    @property
    @pulumi.getter(name="allowEmpty")
    def allow_empty(self) -> builtins.bool:
        """
        表示是否允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示允许。false：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。该参数的默认值是 true。
        """
        return pulumi.get(self, "allow_empty")

    @property
    @pulumi.getter(name="commonType")
    def common_type(self) -> 'outputs.GetShareConfigDenyRefererAccessRuleCommonTypeResult':
        """
        表示该通用列表的内容。
        """
        return pulumi.get(self, "common_type")


@pulumi.output_type
class GetShareConfigDenyRefererAccessRuleCommonTypeResult(dict):
    def __init__(__self__, *,
                 ignore_case: builtins.bool,
                 rules: Sequence[builtins.str]):
        """
        :param builtins.bool ignore_case: 表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        :param Sequence[builtins.str] rules: 表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        pulumi.set(__self__, "ignore_case", ignore_case)
        pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="ignoreCase")
    def ignore_case(self) -> builtins.bool:
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        return pulumi.get(self, "ignore_case")

    @property
    @pulumi.getter
    def rules(self) -> Sequence[builtins.str]:
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        return pulumi.get(self, "rules")


