# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['KafkaTriggerArgs', 'KafkaTrigger']

@pulumi.input_type
class KafkaTriggerArgs:
    def __init__(__self__, *,
                 function_id: pulumi.Input[builtins.str],
                 mq_instance_id: pulumi.Input[builtins.str],
                 name: pulumi.Input[builtins.str],
                 topic_name: pulumi.Input[builtins.str],
                 batch_flush_duration_milliseconds: Optional[pulumi.Input[builtins.int]] = None,
                 batch_size: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 kafka_credentials: Optional[pulumi.Input['KafkaTriggerKafkaCredentialsArgs']] = None,
                 maximum_retry_attempts: Optional[pulumi.Input[builtins.int]] = None,
                 starting_position: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a KafkaTrigger resource.
        :param pulumi.Input[builtins.str] function_id: 函数 ID。
        :param pulumi.Input[builtins.str] mq_instance_id: 消息队列 Kafka 实例 ID。
        :param pulumi.Input[builtins.str] name: Kafka 触发器名字。同一函数下，触发器名称不可重复。只能包含大小写字母、数字、下划线，并且以字母开头，长度限制为 4~63 个字符。
        :param pulumi.Input[builtins.str] topic_name: 消息队列 Kafka 实例的 Topic 名称。
        :param pulumi.Input[builtins.int] batch_flush_duration_milliseconds: 触发器批量消费的最长等待时间。单位为毫秒（ms），取值范围为 1000 ~ 60000 ms，默认值为 1000 ms。
        :param pulumi.Input[builtins.int] batch_size: 触发器批量消费的每批次消息数。
        :param pulumi.Input[builtins.str] description: Kafka 触发器描述。长度限制为 200 个字符以内。
        :param pulumi.Input[builtins.bool] enabled: 是否在创建触发器的同时启用触发器。取值：true：启用。false：关闭。
        :param pulumi.Input['KafkaTriggerKafkaCredentialsArgs'] kafka_credentials: Kafka 身份认证。函数服务将通过 Kafka ACL 权限策略，对 PLAIN 和 SCRAM-SHA-256 两种类型的 SASL 用户进行消息消费鉴权。
        :param pulumi.Input[builtins.int] maximum_retry_attempts: 函数发生运行错误（包括用户代码错误和 Runtime 错误）时的最大重试次数。取值范围为 0～100 的正整数。
        :param pulumi.Input[builtins.str] starting_position: 指定开始消费 Topic 中消息的位置。取值：Latest：只消费订阅 Topic 后产生的消息。Earliest：从 Topic 中生产的第一条消息开始消费。
        """
        pulumi.set(__self__, "function_id", function_id)
        pulumi.set(__self__, "mq_instance_id", mq_instance_id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "topic_name", topic_name)
        if batch_flush_duration_milliseconds is not None:
            pulumi.set(__self__, "batch_flush_duration_milliseconds", batch_flush_duration_milliseconds)
        if batch_size is not None:
            pulumi.set(__self__, "batch_size", batch_size)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if kafka_credentials is not None:
            pulumi.set(__self__, "kafka_credentials", kafka_credentials)
        if maximum_retry_attempts is not None:
            pulumi.set(__self__, "maximum_retry_attempts", maximum_retry_attempts)
        if starting_position is not None:
            pulumi.set(__self__, "starting_position", starting_position)

    @property
    @pulumi.getter(name="functionId")
    def function_id(self) -> pulumi.Input[builtins.str]:
        """
        函数 ID。
        """
        return pulumi.get(self, "function_id")

    @function_id.setter
    def function_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "function_id", value)

    @property
    @pulumi.getter(name="mqInstanceId")
    def mq_instance_id(self) -> pulumi.Input[builtins.str]:
        """
        消息队列 Kafka 实例 ID。
        """
        return pulumi.get(self, "mq_instance_id")

    @mq_instance_id.setter
    def mq_instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "mq_instance_id", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        Kafka 触发器名字。同一函数下，触发器名称不可重复。只能包含大小写字母、数字、下划线，并且以字母开头，长度限制为 4~63 个字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> pulumi.Input[builtins.str]:
        """
        消息队列 Kafka 实例的 Topic 名称。
        """
        return pulumi.get(self, "topic_name")

    @topic_name.setter
    def topic_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "topic_name", value)

    @property
    @pulumi.getter(name="batchFlushDurationMilliseconds")
    def batch_flush_duration_milliseconds(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        触发器批量消费的最长等待时间。单位为毫秒（ms），取值范围为 1000 ~ 60000 ms，默认值为 1000 ms。
        """
        return pulumi.get(self, "batch_flush_duration_milliseconds")

    @batch_flush_duration_milliseconds.setter
    def batch_flush_duration_milliseconds(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "batch_flush_duration_milliseconds", value)

    @property
    @pulumi.getter(name="batchSize")
    def batch_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        触发器批量消费的每批次消息数。
        """
        return pulumi.get(self, "batch_size")

    @batch_size.setter
    def batch_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "batch_size", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kafka 触发器描述。长度限制为 200 个字符以内。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否在创建触发器的同时启用触发器。取值：true：启用。false：关闭。
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="kafkaCredentials")
    def kafka_credentials(self) -> Optional[pulumi.Input['KafkaTriggerKafkaCredentialsArgs']]:
        """
        Kafka 身份认证。函数服务将通过 Kafka ACL 权限策略，对 PLAIN 和 SCRAM-SHA-256 两种类型的 SASL 用户进行消息消费鉴权。
        """
        return pulumi.get(self, "kafka_credentials")

    @kafka_credentials.setter
    def kafka_credentials(self, value: Optional[pulumi.Input['KafkaTriggerKafkaCredentialsArgs']]):
        pulumi.set(self, "kafka_credentials", value)

    @property
    @pulumi.getter(name="maximumRetryAttempts")
    def maximum_retry_attempts(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        函数发生运行错误（包括用户代码错误和 Runtime 错误）时的最大重试次数。取值范围为 0～100 的正整数。
        """
        return pulumi.get(self, "maximum_retry_attempts")

    @maximum_retry_attempts.setter
    def maximum_retry_attempts(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "maximum_retry_attempts", value)

    @property
    @pulumi.getter(name="startingPosition")
    def starting_position(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        指定开始消费 Topic 中消息的位置。取值：Latest：只消费订阅 Topic 后产生的消息。Earliest：从 Topic 中生产的第一条消息开始消费。
        """
        return pulumi.get(self, "starting_position")

    @starting_position.setter
    def starting_position(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "starting_position", value)


@pulumi.input_type
class _KafkaTriggerState:
    def __init__(__self__, *,
                 batch_flush_duration_milliseconds: Optional[pulumi.Input[builtins.int]] = None,
                 batch_size: Optional[pulumi.Input[builtins.int]] = None,
                 consumer_group: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 function_id: Optional[pulumi.Input[builtins.str]] = None,
                 kafka_credentials: Optional[pulumi.Input['KafkaTriggerKafkaCredentialsArgs']] = None,
                 kafka_trigger_id: Optional[pulumi.Input[builtins.str]] = None,
                 maximum_retry_attempts: Optional[pulumi.Input[builtins.int]] = None,
                 mq_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 starting_position: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 topic_name: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering KafkaTrigger resources.
        :param pulumi.Input[builtins.int] batch_flush_duration_milliseconds: 触发器批量消费的最长等待时间。单位为毫秒（ms），取值范围为 1000 ~ 60000 ms，默认值为 1000 ms。
        :param pulumi.Input[builtins.int] batch_size: 触发器批量消费的每批次消息数。
        :param pulumi.Input[builtins.str] consumer_group: 消息队列 Kafka 实例的消费组名字。
        :param pulumi.Input[builtins.str] created_time: Kafka 触发器创建时间。
        :param pulumi.Input[builtins.str] description: Kafka 触发器描述。长度限制为 200 个字符以内。
        :param pulumi.Input[builtins.bool] enabled: 是否在创建触发器的同时启用触发器。取值：true：启用。false：关闭。
        :param pulumi.Input[builtins.str] function_id: 函数 ID。
        :param pulumi.Input['KafkaTriggerKafkaCredentialsArgs'] kafka_credentials: Kafka 身份认证。函数服务将通过 Kafka ACL 权限策略，对 PLAIN 和 SCRAM-SHA-256 两种类型的 SASL 用户进行消息消费鉴权。
        :param pulumi.Input[builtins.str] kafka_trigger_id: Kafka 触发器 ID。
        :param pulumi.Input[builtins.int] maximum_retry_attempts: 函数发生运行错误（包括用户代码错误和 Runtime 错误）时的最大重试次数。取值范围为 0～100 的正整数。
        :param pulumi.Input[builtins.str] mq_instance_id: 消息队列 Kafka 实例 ID。
        :param pulumi.Input[builtins.str] name: Kafka 触发器名字。同一函数下，触发器名称不可重复。只能包含大小写字母、数字、下划线，并且以字母开头，长度限制为 4~63 个字符。
        :param pulumi.Input[builtins.str] starting_position: 指定开始消费 Topic 中消息的位置。取值：Latest：只消费订阅 Topic 后产生的消息。Earliest：从 Topic 中生产的第一条消息开始消费。
        :param pulumi.Input[builtins.str] status: Kafka 触发器状态。参数值说明：ready：运行，failed：失败，pending：启动中
        :param pulumi.Input[builtins.str] topic_name: 消息队列 Kafka 实例的 Topic 名称。
        :param pulumi.Input[builtins.str] updated_time: Kafka 触发器最近一次更新时间。
        """
        if batch_flush_duration_milliseconds is not None:
            pulumi.set(__self__, "batch_flush_duration_milliseconds", batch_flush_duration_milliseconds)
        if batch_size is not None:
            pulumi.set(__self__, "batch_size", batch_size)
        if consumer_group is not None:
            pulumi.set(__self__, "consumer_group", consumer_group)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if function_id is not None:
            pulumi.set(__self__, "function_id", function_id)
        if kafka_credentials is not None:
            pulumi.set(__self__, "kafka_credentials", kafka_credentials)
        if kafka_trigger_id is not None:
            pulumi.set(__self__, "kafka_trigger_id", kafka_trigger_id)
        if maximum_retry_attempts is not None:
            pulumi.set(__self__, "maximum_retry_attempts", maximum_retry_attempts)
        if mq_instance_id is not None:
            pulumi.set(__self__, "mq_instance_id", mq_instance_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if starting_position is not None:
            pulumi.set(__self__, "starting_position", starting_position)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if topic_name is not None:
            pulumi.set(__self__, "topic_name", topic_name)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="batchFlushDurationMilliseconds")
    def batch_flush_duration_milliseconds(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        触发器批量消费的最长等待时间。单位为毫秒（ms），取值范围为 1000 ~ 60000 ms，默认值为 1000 ms。
        """
        return pulumi.get(self, "batch_flush_duration_milliseconds")

    @batch_flush_duration_milliseconds.setter
    def batch_flush_duration_milliseconds(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "batch_flush_duration_milliseconds", value)

    @property
    @pulumi.getter(name="batchSize")
    def batch_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        触发器批量消费的每批次消息数。
        """
        return pulumi.get(self, "batch_size")

    @batch_size.setter
    def batch_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "batch_size", value)

    @property
    @pulumi.getter(name="consumerGroup")
    def consumer_group(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        消息队列 Kafka 实例的消费组名字。
        """
        return pulumi.get(self, "consumer_group")

    @consumer_group.setter
    def consumer_group(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "consumer_group", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kafka 触发器创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kafka 触发器描述。长度限制为 200 个字符以内。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否在创建触发器的同时启用触发器。取值：true：启用。false：关闭。
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="functionId")
    def function_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        函数 ID。
        """
        return pulumi.get(self, "function_id")

    @function_id.setter
    def function_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "function_id", value)

    @property
    @pulumi.getter(name="kafkaCredentials")
    def kafka_credentials(self) -> Optional[pulumi.Input['KafkaTriggerKafkaCredentialsArgs']]:
        """
        Kafka 身份认证。函数服务将通过 Kafka ACL 权限策略，对 PLAIN 和 SCRAM-SHA-256 两种类型的 SASL 用户进行消息消费鉴权。
        """
        return pulumi.get(self, "kafka_credentials")

    @kafka_credentials.setter
    def kafka_credentials(self, value: Optional[pulumi.Input['KafkaTriggerKafkaCredentialsArgs']]):
        pulumi.set(self, "kafka_credentials", value)

    @property
    @pulumi.getter(name="kafkaTriggerId")
    def kafka_trigger_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kafka 触发器 ID。
        """
        return pulumi.get(self, "kafka_trigger_id")

    @kafka_trigger_id.setter
    def kafka_trigger_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kafka_trigger_id", value)

    @property
    @pulumi.getter(name="maximumRetryAttempts")
    def maximum_retry_attempts(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        函数发生运行错误（包括用户代码错误和 Runtime 错误）时的最大重试次数。取值范围为 0～100 的正整数。
        """
        return pulumi.get(self, "maximum_retry_attempts")

    @maximum_retry_attempts.setter
    def maximum_retry_attempts(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "maximum_retry_attempts", value)

    @property
    @pulumi.getter(name="mqInstanceId")
    def mq_instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        消息队列 Kafka 实例 ID。
        """
        return pulumi.get(self, "mq_instance_id")

    @mq_instance_id.setter
    def mq_instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mq_instance_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kafka 触发器名字。同一函数下，触发器名称不可重复。只能包含大小写字母、数字、下划线，并且以字母开头，长度限制为 4~63 个字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="startingPosition")
    def starting_position(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        指定开始消费 Topic 中消息的位置。取值：Latest：只消费订阅 Topic 后产生的消息。Earliest：从 Topic 中生产的第一条消息开始消费。
        """
        return pulumi.get(self, "starting_position")

    @starting_position.setter
    def starting_position(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "starting_position", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kafka 触发器状态。参数值说明：ready：运行，failed：失败，pending：启动中
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        消息队列 Kafka 实例的 Topic 名称。
        """
        return pulumi.get(self, "topic_name")

    @topic_name.setter
    def topic_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "topic_name", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kafka 触发器最近一次更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:vefaas/kafkaTrigger:KafkaTrigger")
class KafkaTrigger(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 batch_flush_duration_milliseconds: Optional[pulumi.Input[builtins.int]] = None,
                 batch_size: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 function_id: Optional[pulumi.Input[builtins.str]] = None,
                 kafka_credentials: Optional[pulumi.Input[Union['KafkaTriggerKafkaCredentialsArgs', 'KafkaTriggerKafkaCredentialsArgsDict']]] = None,
                 maximum_retry_attempts: Optional[pulumi.Input[builtins.int]] = None,
                 mq_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 starting_position: Optional[pulumi.Input[builtins.str]] = None,
                 topic_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        函数服务支持对接消息队列 Kafka 版。通过创建 Kafka 触发器，函数服务将作为消费者消费 Kafka 中的消息，并将消息传递给用户函数，触发函数代码逻辑。您无需关心函数服务消费消息的细节，只需编写处理消息的函数。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        vefaas_trigger_demo = bytepluscc.vefaas.KafkaTrigger("VefaasTriggerDemo",
            function_id="djb27tnr****",
            name="VefaasTriggerDemo",
            maximum_retry_attempts=74,
            starting_position="Earliest",
            enabled=False,
            kafka_credentials={
                "mechanism": "PLAIN",
                "username": "VefaasTriggerDemo",
                "password": "*****",
            },
            mq_instance_id="kafka-cnng8cm4q2fncrvs****",
            topic_name="VefaasTriggerDemo",
            description="VefaasTriggerDemo description",
            batch_flush_duration_milliseconds=8637,
            batch_size=709)
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vefaas/kafkaTrigger:KafkaTrigger example "function_id|kafka_trigger_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] batch_flush_duration_milliseconds: 触发器批量消费的最长等待时间。单位为毫秒（ms），取值范围为 1000 ~ 60000 ms，默认值为 1000 ms。
        :param pulumi.Input[builtins.int] batch_size: 触发器批量消费的每批次消息数。
        :param pulumi.Input[builtins.str] description: Kafka 触发器描述。长度限制为 200 个字符以内。
        :param pulumi.Input[builtins.bool] enabled: 是否在创建触发器的同时启用触发器。取值：true：启用。false：关闭。
        :param pulumi.Input[builtins.str] function_id: 函数 ID。
        :param pulumi.Input[Union['KafkaTriggerKafkaCredentialsArgs', 'KafkaTriggerKafkaCredentialsArgsDict']] kafka_credentials: Kafka 身份认证。函数服务将通过 Kafka ACL 权限策略，对 PLAIN 和 SCRAM-SHA-256 两种类型的 SASL 用户进行消息消费鉴权。
        :param pulumi.Input[builtins.int] maximum_retry_attempts: 函数发生运行错误（包括用户代码错误和 Runtime 错误）时的最大重试次数。取值范围为 0～100 的正整数。
        :param pulumi.Input[builtins.str] mq_instance_id: 消息队列 Kafka 实例 ID。
        :param pulumi.Input[builtins.str] name: Kafka 触发器名字。同一函数下，触发器名称不可重复。只能包含大小写字母、数字、下划线，并且以字母开头，长度限制为 4~63 个字符。
        :param pulumi.Input[builtins.str] starting_position: 指定开始消费 Topic 中消息的位置。取值：Latest：只消费订阅 Topic 后产生的消息。Earliest：从 Topic 中生产的第一条消息开始消费。
        :param pulumi.Input[builtins.str] topic_name: 消息队列 Kafka 实例的 Topic 名称。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KafkaTriggerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        函数服务支持对接消息队列 Kafka 版。通过创建 Kafka 触发器，函数服务将作为消费者消费 Kafka 中的消息，并将消息传递给用户函数，触发函数代码逻辑。您无需关心函数服务消费消息的细节，只需编写处理消息的函数。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        vefaas_trigger_demo = bytepluscc.vefaas.KafkaTrigger("VefaasTriggerDemo",
            function_id="djb27tnr****",
            name="VefaasTriggerDemo",
            maximum_retry_attempts=74,
            starting_position="Earliest",
            enabled=False,
            kafka_credentials={
                "mechanism": "PLAIN",
                "username": "VefaasTriggerDemo",
                "password": "*****",
            },
            mq_instance_id="kafka-cnng8cm4q2fncrvs****",
            topic_name="VefaasTriggerDemo",
            description="VefaasTriggerDemo description",
            batch_flush_duration_milliseconds=8637,
            batch_size=709)
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vefaas/kafkaTrigger:KafkaTrigger example "function_id|kafka_trigger_id"
        ```

        :param str resource_name: The name of the resource.
        :param KafkaTriggerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KafkaTriggerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 batch_flush_duration_milliseconds: Optional[pulumi.Input[builtins.int]] = None,
                 batch_size: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 function_id: Optional[pulumi.Input[builtins.str]] = None,
                 kafka_credentials: Optional[pulumi.Input[Union['KafkaTriggerKafkaCredentialsArgs', 'KafkaTriggerKafkaCredentialsArgsDict']]] = None,
                 maximum_retry_attempts: Optional[pulumi.Input[builtins.int]] = None,
                 mq_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 starting_position: Optional[pulumi.Input[builtins.str]] = None,
                 topic_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KafkaTriggerArgs.__new__(KafkaTriggerArgs)

            __props__.__dict__["batch_flush_duration_milliseconds"] = batch_flush_duration_milliseconds
            __props__.__dict__["batch_size"] = batch_size
            __props__.__dict__["description"] = description
            __props__.__dict__["enabled"] = enabled
            if function_id is None and not opts.urn:
                raise TypeError("Missing required property 'function_id'")
            __props__.__dict__["function_id"] = function_id
            __props__.__dict__["kafka_credentials"] = kafka_credentials
            __props__.__dict__["maximum_retry_attempts"] = maximum_retry_attempts
            if mq_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'mq_instance_id'")
            __props__.__dict__["mq_instance_id"] = mq_instance_id
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["starting_position"] = starting_position
            if topic_name is None and not opts.urn:
                raise TypeError("Missing required property 'topic_name'")
            __props__.__dict__["topic_name"] = topic_name
            __props__.__dict__["consumer_group"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["kafka_trigger_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
        super(KafkaTrigger, __self__).__init__(
            'bytepluscc:vefaas/kafkaTrigger:KafkaTrigger',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            batch_flush_duration_milliseconds: Optional[pulumi.Input[builtins.int]] = None,
            batch_size: Optional[pulumi.Input[builtins.int]] = None,
            consumer_group: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            enabled: Optional[pulumi.Input[builtins.bool]] = None,
            function_id: Optional[pulumi.Input[builtins.str]] = None,
            kafka_credentials: Optional[pulumi.Input[Union['KafkaTriggerKafkaCredentialsArgs', 'KafkaTriggerKafkaCredentialsArgsDict']]] = None,
            kafka_trigger_id: Optional[pulumi.Input[builtins.str]] = None,
            maximum_retry_attempts: Optional[pulumi.Input[builtins.int]] = None,
            mq_instance_id: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            starting_position: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            topic_name: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'KafkaTrigger':
        """
        Get an existing KafkaTrigger resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] batch_flush_duration_milliseconds: 触发器批量消费的最长等待时间。单位为毫秒（ms），取值范围为 1000 ~ 60000 ms，默认值为 1000 ms。
        :param pulumi.Input[builtins.int] batch_size: 触发器批量消费的每批次消息数。
        :param pulumi.Input[builtins.str] consumer_group: 消息队列 Kafka 实例的消费组名字。
        :param pulumi.Input[builtins.str] created_time: Kafka 触发器创建时间。
        :param pulumi.Input[builtins.str] description: Kafka 触发器描述。长度限制为 200 个字符以内。
        :param pulumi.Input[builtins.bool] enabled: 是否在创建触发器的同时启用触发器。取值：true：启用。false：关闭。
        :param pulumi.Input[builtins.str] function_id: 函数 ID。
        :param pulumi.Input[Union['KafkaTriggerKafkaCredentialsArgs', 'KafkaTriggerKafkaCredentialsArgsDict']] kafka_credentials: Kafka 身份认证。函数服务将通过 Kafka ACL 权限策略，对 PLAIN 和 SCRAM-SHA-256 两种类型的 SASL 用户进行消息消费鉴权。
        :param pulumi.Input[builtins.str] kafka_trigger_id: Kafka 触发器 ID。
        :param pulumi.Input[builtins.int] maximum_retry_attempts: 函数发生运行错误（包括用户代码错误和 Runtime 错误）时的最大重试次数。取值范围为 0～100 的正整数。
        :param pulumi.Input[builtins.str] mq_instance_id: 消息队列 Kafka 实例 ID。
        :param pulumi.Input[builtins.str] name: Kafka 触发器名字。同一函数下，触发器名称不可重复。只能包含大小写字母、数字、下划线，并且以字母开头，长度限制为 4~63 个字符。
        :param pulumi.Input[builtins.str] starting_position: 指定开始消费 Topic 中消息的位置。取值：Latest：只消费订阅 Topic 后产生的消息。Earliest：从 Topic 中生产的第一条消息开始消费。
        :param pulumi.Input[builtins.str] status: Kafka 触发器状态。参数值说明：ready：运行，failed：失败，pending：启动中
        :param pulumi.Input[builtins.str] topic_name: 消息队列 Kafka 实例的 Topic 名称。
        :param pulumi.Input[builtins.str] updated_time: Kafka 触发器最近一次更新时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KafkaTriggerState.__new__(_KafkaTriggerState)

        __props__.__dict__["batch_flush_duration_milliseconds"] = batch_flush_duration_milliseconds
        __props__.__dict__["batch_size"] = batch_size
        __props__.__dict__["consumer_group"] = consumer_group
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["function_id"] = function_id
        __props__.__dict__["kafka_credentials"] = kafka_credentials
        __props__.__dict__["kafka_trigger_id"] = kafka_trigger_id
        __props__.__dict__["maximum_retry_attempts"] = maximum_retry_attempts
        __props__.__dict__["mq_instance_id"] = mq_instance_id
        __props__.__dict__["name"] = name
        __props__.__dict__["starting_position"] = starting_position
        __props__.__dict__["status"] = status
        __props__.__dict__["topic_name"] = topic_name
        __props__.__dict__["updated_time"] = updated_time
        return KafkaTrigger(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="batchFlushDurationMilliseconds")
    def batch_flush_duration_milliseconds(self) -> pulumi.Output[builtins.int]:
        """
        触发器批量消费的最长等待时间。单位为毫秒（ms），取值范围为 1000 ~ 60000 ms，默认值为 1000 ms。
        """
        return pulumi.get(self, "batch_flush_duration_milliseconds")

    @property
    @pulumi.getter(name="batchSize")
    def batch_size(self) -> pulumi.Output[builtins.int]:
        """
        触发器批量消费的每批次消息数。
        """
        return pulumi.get(self, "batch_size")

    @property
    @pulumi.getter(name="consumerGroup")
    def consumer_group(self) -> pulumi.Output[builtins.str]:
        """
        消息队列 Kafka 实例的消费组名字。
        """
        return pulumi.get(self, "consumer_group")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        Kafka 触发器创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        Kafka 触发器描述。长度限制为 200 个字符以内。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否在创建触发器的同时启用触发器。取值：true：启用。false：关闭。
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="functionId")
    def function_id(self) -> pulumi.Output[builtins.str]:
        """
        函数 ID。
        """
        return pulumi.get(self, "function_id")

    @property
    @pulumi.getter(name="kafkaCredentials")
    def kafka_credentials(self) -> pulumi.Output['outputs.KafkaTriggerKafkaCredentials']:
        """
        Kafka 身份认证。函数服务将通过 Kafka ACL 权限策略，对 PLAIN 和 SCRAM-SHA-256 两种类型的 SASL 用户进行消息消费鉴权。
        """
        return pulumi.get(self, "kafka_credentials")

    @property
    @pulumi.getter(name="kafkaTriggerId")
    def kafka_trigger_id(self) -> pulumi.Output[builtins.str]:
        """
        Kafka 触发器 ID。
        """
        return pulumi.get(self, "kafka_trigger_id")

    @property
    @pulumi.getter(name="maximumRetryAttempts")
    def maximum_retry_attempts(self) -> pulumi.Output[builtins.int]:
        """
        函数发生运行错误（包括用户代码错误和 Runtime 错误）时的最大重试次数。取值范围为 0～100 的正整数。
        """
        return pulumi.get(self, "maximum_retry_attempts")

    @property
    @pulumi.getter(name="mqInstanceId")
    def mq_instance_id(self) -> pulumi.Output[builtins.str]:
        """
        消息队列 Kafka 实例 ID。
        """
        return pulumi.get(self, "mq_instance_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Kafka 触发器名字。同一函数下，触发器名称不可重复。只能包含大小写字母、数字、下划线，并且以字母开头，长度限制为 4~63 个字符。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="startingPosition")
    def starting_position(self) -> pulumi.Output[builtins.str]:
        """
        指定开始消费 Topic 中消息的位置。取值：Latest：只消费订阅 Topic 后产生的消息。Earliest：从 Topic 中生产的第一条消息开始消费。
        """
        return pulumi.get(self, "starting_position")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Kafka 触发器状态。参数值说明：ready：运行，failed：失败，pending：启动中
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> pulumi.Output[builtins.str]:
        """
        消息队列 Kafka 实例的 Topic 名称。
        """
        return pulumi.get(self, "topic_name")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        Kafka 触发器最近一次更新时间。
        """
        return pulumi.get(self, "updated_time")

