# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DnatentryArgs', 'Dnatentry']

@pulumi.input_type
class DnatentryArgs:
    def __init__(__self__, *,
                 external_ip: pulumi.Input[builtins.str],
                 external_port: pulumi.Input[builtins.str],
                 internal_ip: pulumi.Input[builtins.str],
                 internal_port: pulumi.Input[builtins.str],
                 nat_gateway_id: pulumi.Input[builtins.str],
                 protocol: pulumi.Input[builtins.str],
                 dnat_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 port_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Dnatentry resource.
        :param pulumi.Input[builtins.str] external_ip: NAT网关用于网络地址转换的IP地址。当NAT网关为公网NAT网关时，传入其绑定的公网IP地址。当NAT网关为私网NAT网关时，传入其中转IP地址。
        :param pulumi.Input[builtins.str] external_port: 接收来自公网外部请求的端口或端口段。
        :param pulumi.Input[builtins.str] internal_ip: 云服务器实例的私网IP。
        :param pulumi.Input[builtins.str] internal_port: 云服务器实例私网IP的端口或端口段。
        :param pulumi.Input[builtins.str] nat_gateway_id: DNAT规则所属NAT网关的ID。
        :param pulumi.Input[builtins.str] protocol: 协议类型。tcp：转发TCP协议的报文。udp：转发UDP协议的报文。
        :param pulumi.Input[builtins.str] dnat_entry_name: DNAT规则的名称。
        :param pulumi.Input[builtins.str] port_type: DNAT规则的端口类型。specified：指定端口。any：任意端口。即IP映射。
        """
        pulumi.set(__self__, "external_ip", external_ip)
        pulumi.set(__self__, "external_port", external_port)
        pulumi.set(__self__, "internal_ip", internal_ip)
        pulumi.set(__self__, "internal_port", internal_port)
        pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        pulumi.set(__self__, "protocol", protocol)
        if dnat_entry_name is not None:
            pulumi.set(__self__, "dnat_entry_name", dnat_entry_name)
        if port_type is not None:
            pulumi.set(__self__, "port_type", port_type)

    @property
    @pulumi.getter(name="externalIp")
    def external_ip(self) -> pulumi.Input[builtins.str]:
        """
        NAT网关用于网络地址转换的IP地址。当NAT网关为公网NAT网关时，传入其绑定的公网IP地址。当NAT网关为私网NAT网关时，传入其中转IP地址。
        """
        return pulumi.get(self, "external_ip")

    @external_ip.setter
    def external_ip(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "external_ip", value)

    @property
    @pulumi.getter(name="externalPort")
    def external_port(self) -> pulumi.Input[builtins.str]:
        """
        接收来自公网外部请求的端口或端口段。
        """
        return pulumi.get(self, "external_port")

    @external_port.setter
    def external_port(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "external_port", value)

    @property
    @pulumi.getter(name="internalIp")
    def internal_ip(self) -> pulumi.Input[builtins.str]:
        """
        云服务器实例的私网IP。
        """
        return pulumi.get(self, "internal_ip")

    @internal_ip.setter
    def internal_ip(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "internal_ip", value)

    @property
    @pulumi.getter(name="internalPort")
    def internal_port(self) -> pulumi.Input[builtins.str]:
        """
        云服务器实例私网IP的端口或端口段。
        """
        return pulumi.get(self, "internal_port")

    @internal_port.setter
    def internal_port(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "internal_port", value)

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> pulumi.Input[builtins.str]:
        """
        DNAT规则所属NAT网关的ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "nat_gateway_id", value)

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[builtins.str]:
        """
        协议类型。tcp：转发TCP协议的报文。udp：转发UDP协议的报文。
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="dnatEntryName")
    def dnat_entry_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNAT规则的名称。
        """
        return pulumi.get(self, "dnat_entry_name")

    @dnat_entry_name.setter
    def dnat_entry_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dnat_entry_name", value)

    @property
    @pulumi.getter(name="portType")
    def port_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNAT规则的端口类型。specified：指定端口。any：任意端口。即IP映射。
        """
        return pulumi.get(self, "port_type")

    @port_type.setter
    def port_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "port_type", value)


@pulumi.input_type
class _DnatentryState:
    def __init__(__self__, *,
                 dnat_entry_id: Optional[pulumi.Input[builtins.str]] = None,
                 dnat_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 external_ip: Optional[pulumi.Input[builtins.str]] = None,
                 external_port: Optional[pulumi.Input[builtins.str]] = None,
                 internal_ip: Optional[pulumi.Input[builtins.str]] = None,
                 internal_port: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 port_type: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Dnatentry resources.
        :param pulumi.Input[builtins.str] dnat_entry_id: DNAT规则的ID。
        :param pulumi.Input[builtins.str] dnat_entry_name: DNAT规则的名称。
        :param pulumi.Input[builtins.str] external_ip: NAT网关用于网络地址转换的IP地址。当NAT网关为公网NAT网关时，传入其绑定的公网IP地址。当NAT网关为私网NAT网关时，传入其中转IP地址。
        :param pulumi.Input[builtins.str] external_port: 接收来自公网外部请求的端口或端口段。
        :param pulumi.Input[builtins.str] internal_ip: 云服务器实例的私网IP。
        :param pulumi.Input[builtins.str] internal_port: 云服务器实例私网IP的端口或端口段。
        :param pulumi.Input[builtins.str] nat_gateway_id: DNAT规则所属NAT网关的ID。
        :param pulumi.Input[builtins.str] port_type: DNAT规则的端口类型。specified：指定端口。any：任意端口。即IP映射。
        :param pulumi.Input[builtins.str] protocol: 协议类型。tcp：转发TCP协议的报文。udp：转发UDP协议的报文。
        :param pulumi.Input[builtins.str] status: DNAT规则的状态。Creating：创建中。Deleting：删除中。Available：可用。
        """
        if dnat_entry_id is not None:
            pulumi.set(__self__, "dnat_entry_id", dnat_entry_id)
        if dnat_entry_name is not None:
            pulumi.set(__self__, "dnat_entry_name", dnat_entry_name)
        if external_ip is not None:
            pulumi.set(__self__, "external_ip", external_ip)
        if external_port is not None:
            pulumi.set(__self__, "external_port", external_port)
        if internal_ip is not None:
            pulumi.set(__self__, "internal_ip", internal_ip)
        if internal_port is not None:
            pulumi.set(__self__, "internal_port", internal_port)
        if nat_gateway_id is not None:
            pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if port_type is not None:
            pulumi.set(__self__, "port_type", port_type)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="dnatEntryId")
    def dnat_entry_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNAT规则的ID。
        """
        return pulumi.get(self, "dnat_entry_id")

    @dnat_entry_id.setter
    def dnat_entry_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dnat_entry_id", value)

    @property
    @pulumi.getter(name="dnatEntryName")
    def dnat_entry_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNAT规则的名称。
        """
        return pulumi.get(self, "dnat_entry_name")

    @dnat_entry_name.setter
    def dnat_entry_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dnat_entry_name", value)

    @property
    @pulumi.getter(name="externalIp")
    def external_ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关用于网络地址转换的IP地址。当NAT网关为公网NAT网关时，传入其绑定的公网IP地址。当NAT网关为私网NAT网关时，传入其中转IP地址。
        """
        return pulumi.get(self, "external_ip")

    @external_ip.setter
    def external_ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "external_ip", value)

    @property
    @pulumi.getter(name="externalPort")
    def external_port(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        接收来自公网外部请求的端口或端口段。
        """
        return pulumi.get(self, "external_port")

    @external_port.setter
    def external_port(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "external_port", value)

    @property
    @pulumi.getter(name="internalIp")
    def internal_ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        云服务器实例的私网IP。
        """
        return pulumi.get(self, "internal_ip")

    @internal_ip.setter
    def internal_ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "internal_ip", value)

    @property
    @pulumi.getter(name="internalPort")
    def internal_port(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        云服务器实例私网IP的端口或端口段。
        """
        return pulumi.get(self, "internal_port")

    @internal_port.setter
    def internal_port(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "internal_port", value)

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNAT规则所属NAT网关的ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_gateway_id", value)

    @property
    @pulumi.getter(name="portType")
    def port_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNAT规则的端口类型。specified：指定端口。any：任意端口。即IP映射。
        """
        return pulumi.get(self, "port_type")

    @port_type.setter
    def port_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "port_type", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        协议类型。tcp：转发TCP协议的报文。udp：转发UDP协议的报文。
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNAT规则的状态。Creating：创建中。Deleting：删除中。Available：可用。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("bytepluscc:natgateway/dnatentry:Dnatentry")
class Dnatentry(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dnat_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 external_ip: Optional[pulumi.Input[builtins.str]] = None,
                 external_port: Optional[pulumi.Input[builtins.str]] = None,
                 internal_ip: Optional[pulumi.Input[builtins.str]] = None,
                 internal_port: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 port_type: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        目的地址转换。即当中转IP及端口被访问时，私网NAT网关将访问请求中的目的地址和端口替换成云服务器的私网IP及端口后，进行转发。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        nat_gateway_dnatentry_demo = bytepluscc.natgateway.Dnatentry("NatGatewayDnatentryDemo",
            dnat_entry_name="NatGatewayDnatentryDemo",
            protocol="udp",
            internal_ip="192.168.xxx.53",
            internal_port="20-25",
            external_ip="115.190.xxx.9",
            external_port="25-30",
            nat_gateway_id="ngw-2pc28yhdpbx8g227qo1sxxxxx",
            port_type="specified")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:natgateway/dnatentry:Dnatentry example "dnat_entry_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] dnat_entry_name: DNAT规则的名称。
        :param pulumi.Input[builtins.str] external_ip: NAT网关用于网络地址转换的IP地址。当NAT网关为公网NAT网关时，传入其绑定的公网IP地址。当NAT网关为私网NAT网关时，传入其中转IP地址。
        :param pulumi.Input[builtins.str] external_port: 接收来自公网外部请求的端口或端口段。
        :param pulumi.Input[builtins.str] internal_ip: 云服务器实例的私网IP。
        :param pulumi.Input[builtins.str] internal_port: 云服务器实例私网IP的端口或端口段。
        :param pulumi.Input[builtins.str] nat_gateway_id: DNAT规则所属NAT网关的ID。
        :param pulumi.Input[builtins.str] port_type: DNAT规则的端口类型。specified：指定端口。any：任意端口。即IP映射。
        :param pulumi.Input[builtins.str] protocol: 协议类型。tcp：转发TCP协议的报文。udp：转发UDP协议的报文。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DnatentryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        目的地址转换。即当中转IP及端口被访问时，私网NAT网关将访问请求中的目的地址和端口替换成云服务器的私网IP及端口后，进行转发。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        nat_gateway_dnatentry_demo = bytepluscc.natgateway.Dnatentry("NatGatewayDnatentryDemo",
            dnat_entry_name="NatGatewayDnatentryDemo",
            protocol="udp",
            internal_ip="192.168.xxx.53",
            internal_port="20-25",
            external_ip="115.190.xxx.9",
            external_port="25-30",
            nat_gateway_id="ngw-2pc28yhdpbx8g227qo1sxxxxx",
            port_type="specified")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:natgateway/dnatentry:Dnatentry example "dnat_entry_id"
        ```

        :param str resource_name: The name of the resource.
        :param DnatentryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DnatentryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dnat_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 external_ip: Optional[pulumi.Input[builtins.str]] = None,
                 external_port: Optional[pulumi.Input[builtins.str]] = None,
                 internal_ip: Optional[pulumi.Input[builtins.str]] = None,
                 internal_port: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 port_type: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DnatentryArgs.__new__(DnatentryArgs)

            __props__.__dict__["dnat_entry_name"] = dnat_entry_name
            if external_ip is None and not opts.urn:
                raise TypeError("Missing required property 'external_ip'")
            __props__.__dict__["external_ip"] = external_ip
            if external_port is None and not opts.urn:
                raise TypeError("Missing required property 'external_port'")
            __props__.__dict__["external_port"] = external_port
            if internal_ip is None and not opts.urn:
                raise TypeError("Missing required property 'internal_ip'")
            __props__.__dict__["internal_ip"] = internal_ip
            if internal_port is None and not opts.urn:
                raise TypeError("Missing required property 'internal_port'")
            __props__.__dict__["internal_port"] = internal_port
            if nat_gateway_id is None and not opts.urn:
                raise TypeError("Missing required property 'nat_gateway_id'")
            __props__.__dict__["nat_gateway_id"] = nat_gateway_id
            __props__.__dict__["port_type"] = port_type
            if protocol is None and not opts.urn:
                raise TypeError("Missing required property 'protocol'")
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["dnat_entry_id"] = None
            __props__.__dict__["status"] = None
        super(Dnatentry, __self__).__init__(
            'bytepluscc:natgateway/dnatentry:Dnatentry',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            dnat_entry_id: Optional[pulumi.Input[builtins.str]] = None,
            dnat_entry_name: Optional[pulumi.Input[builtins.str]] = None,
            external_ip: Optional[pulumi.Input[builtins.str]] = None,
            external_port: Optional[pulumi.Input[builtins.str]] = None,
            internal_ip: Optional[pulumi.Input[builtins.str]] = None,
            internal_port: Optional[pulumi.Input[builtins.str]] = None,
            nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            port_type: Optional[pulumi.Input[builtins.str]] = None,
            protocol: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'Dnatentry':
        """
        Get an existing Dnatentry resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] dnat_entry_id: DNAT规则的ID。
        :param pulumi.Input[builtins.str] dnat_entry_name: DNAT规则的名称。
        :param pulumi.Input[builtins.str] external_ip: NAT网关用于网络地址转换的IP地址。当NAT网关为公网NAT网关时，传入其绑定的公网IP地址。当NAT网关为私网NAT网关时，传入其中转IP地址。
        :param pulumi.Input[builtins.str] external_port: 接收来自公网外部请求的端口或端口段。
        :param pulumi.Input[builtins.str] internal_ip: 云服务器实例的私网IP。
        :param pulumi.Input[builtins.str] internal_port: 云服务器实例私网IP的端口或端口段。
        :param pulumi.Input[builtins.str] nat_gateway_id: DNAT规则所属NAT网关的ID。
        :param pulumi.Input[builtins.str] port_type: DNAT规则的端口类型。specified：指定端口。any：任意端口。即IP映射。
        :param pulumi.Input[builtins.str] protocol: 协议类型。tcp：转发TCP协议的报文。udp：转发UDP协议的报文。
        :param pulumi.Input[builtins.str] status: DNAT规则的状态。Creating：创建中。Deleting：删除中。Available：可用。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DnatentryState.__new__(_DnatentryState)

        __props__.__dict__["dnat_entry_id"] = dnat_entry_id
        __props__.__dict__["dnat_entry_name"] = dnat_entry_name
        __props__.__dict__["external_ip"] = external_ip
        __props__.__dict__["external_port"] = external_port
        __props__.__dict__["internal_ip"] = internal_ip
        __props__.__dict__["internal_port"] = internal_port
        __props__.__dict__["nat_gateway_id"] = nat_gateway_id
        __props__.__dict__["port_type"] = port_type
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["status"] = status
        return Dnatentry(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="dnatEntryId")
    def dnat_entry_id(self) -> pulumi.Output[builtins.str]:
        """
        DNAT规则的ID。
        """
        return pulumi.get(self, "dnat_entry_id")

    @property
    @pulumi.getter(name="dnatEntryName")
    def dnat_entry_name(self) -> pulumi.Output[builtins.str]:
        """
        DNAT规则的名称。
        """
        return pulumi.get(self, "dnat_entry_name")

    @property
    @pulumi.getter(name="externalIp")
    def external_ip(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关用于网络地址转换的IP地址。当NAT网关为公网NAT网关时，传入其绑定的公网IP地址。当NAT网关为私网NAT网关时，传入其中转IP地址。
        """
        return pulumi.get(self, "external_ip")

    @property
    @pulumi.getter(name="externalPort")
    def external_port(self) -> pulumi.Output[builtins.str]:
        """
        接收来自公网外部请求的端口或端口段。
        """
        return pulumi.get(self, "external_port")

    @property
    @pulumi.getter(name="internalIp")
    def internal_ip(self) -> pulumi.Output[builtins.str]:
        """
        云服务器实例的私网IP。
        """
        return pulumi.get(self, "internal_ip")

    @property
    @pulumi.getter(name="internalPort")
    def internal_port(self) -> pulumi.Output[builtins.str]:
        """
        云服务器实例私网IP的端口或端口段。
        """
        return pulumi.get(self, "internal_port")

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        DNAT规则所属NAT网关的ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @property
    @pulumi.getter(name="portType")
    def port_type(self) -> pulumi.Output[builtins.str]:
        """
        DNAT规则的端口类型。specified：指定端口。any：任意端口。即IP映射。
        """
        return pulumi.get(self, "port_type")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[builtins.str]:
        """
        协议类型。tcp：转发TCP协议的报文。udp：转发UDP协议的报文。
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        DNAT规则的状态。Creating：创建中。Deleting：删除中。Available：可用。
        """
        return pulumi.get(self, "status")

