# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InstanceArgs', 'Instance']

@pulumi.input_type
class InstanceArgs:
    def __init__(__self__, *,
                 billing_type: pulumi.Input[builtins.str],
                 name: pulumi.Input[builtins.str],
                 project_name: pulumi.Input[builtins.str],
                 security_group_id_lists: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 specification: pulumi.Input[builtins.str],
                 subnet_id_lists: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 vpc_id: pulumi.Input[builtins.str],
                 zone_id_lists: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 auto_renew: Optional[pulumi.Input[builtins.str]] = None,
                 billing_period: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 endpoints: Optional[pulumi.Input['InstanceEndpointsArgs']] = None,
                 message_retention: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]] = None,
                 times: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a Instance resource.
        :param pulumi.Input[builtins.str] billing_type: 实例的计费方式，取值如下：POST：按量计费。MIX：包年包月。
        :param pulumi.Input[builtins.str] name: 自定设置 BMQ 实例的名称，约束限制如下：由小写字母、数字和中划线（-）组成。长度为 1~64 字符。
        :param pulumi.Input[builtins.str] project_name: 实例所属项目名称。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_id_lists: 实例使用安全组列表。
        :param pulumi.Input[builtins.str] specification: 实例规格。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_id_lists: 实例使用的子网列表。
        :param pulumi.Input[builtins.str] vpc_id: 实例所在VPC ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] zone_id_lists: 实例所在可用区列表。
        :param pulumi.Input[builtins.str] auto_renew: 是否开启自动续费，取值如下：true：开启自动续费。false：关闭自动续费。
        :param pulumi.Input[builtins.str] billing_period: 购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        :param pulumi.Input[builtins.str] description: 实例的描述语句。
        :param pulumi.Input[builtins.str] eip_id: 实例是否开启公网访问。如果需要开启公网访问，请配置相同地域的公网 IP 的 ID。
        :param pulumi.Input['InstanceEndpointsArgs'] endpoints: 实例所有接入点响应数据。
        :param pulumi.Input[builtins.int] message_retention: 实例下所有 Topic 的消息保留时长，单位为小时。
        :param pulumi.Input[builtins.int] times: 包年包月类型实例的购买时长，单位为月。
        """
        pulumi.set(__self__, "billing_type", billing_type)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "project_name", project_name)
        pulumi.set(__self__, "security_group_id_lists", security_group_id_lists)
        pulumi.set(__self__, "specification", specification)
        pulumi.set(__self__, "subnet_id_lists", subnet_id_lists)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "zone_id_lists", zone_id_lists)
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if billing_period is not None:
            pulumi.set(__self__, "billing_period", billing_period)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if endpoints is not None:
            pulumi.set(__self__, "endpoints", endpoints)
        if message_retention is not None:
            pulumi.set(__self__, "message_retention", message_retention)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if times is not None:
            pulumi.set(__self__, "times", times)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> pulumi.Input[builtins.str]:
        """
        实例的计费方式，取值如下：POST：按量计费。MIX：包年包月。
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        自定设置 BMQ 实例的名称，约束限制如下：由小写字母、数字和中划线（-）组成。长度为 1~64 字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Input[builtins.str]:
        """
        实例所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="securityGroupIdLists")
    def security_group_id_lists(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        实例使用安全组列表。
        """
        return pulumi.get(self, "security_group_id_lists")

    @security_group_id_lists.setter
    def security_group_id_lists(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "security_group_id_lists", value)

    @property
    @pulumi.getter
    def specification(self) -> pulumi.Input[builtins.str]:
        """
        实例规格。
        """
        return pulumi.get(self, "specification")

    @specification.setter
    def specification(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "specification", value)

    @property
    @pulumi.getter(name="subnetIdLists")
    def subnet_id_lists(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        实例使用的子网列表。
        """
        return pulumi.get(self, "subnet_id_lists")

    @subnet_id_lists.setter
    def subnet_id_lists(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "subnet_id_lists", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        实例所在VPC ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneIdLists")
    def zone_id_lists(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        实例所在可用区列表。
        """
        return pulumi.get(self, "zone_id_lists")

    @zone_id_lists.setter
    def zone_id_lists(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "zone_id_lists", value)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否开启自动续费，取值如下：true：开启自动续费。false：关闭自动续费。
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="billingPeriod")
    def billing_period(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        """
        return pulumi.get(self, "billing_period")

    @billing_period.setter
    def billing_period(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "billing_period", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的描述语句。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例是否开启公网访问。如果需要开启公网访问，请配置相同地域的公网 IP 的 ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter
    def endpoints(self) -> Optional[pulumi.Input['InstanceEndpointsArgs']]:
        """
        实例所有接入点响应数据。
        """
        return pulumi.get(self, "endpoints")

    @endpoints.setter
    def endpoints(self, value: Optional[pulumi.Input['InstanceEndpointsArgs']]):
        pulumi.set(self, "endpoints", value)

    @property
    @pulumi.getter(name="messageRetention")
    def message_retention(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例下所有 Topic 的消息保留时长，单位为小时。
        """
        return pulumi.get(self, "message_retention")

    @message_retention.setter
    def message_retention(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "message_retention", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def times(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        包年包月类型实例的购买时长，单位为月。
        """
        return pulumi.get(self, "times")

    @times.setter
    def times(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "times", value)


@pulumi.input_type
class _InstanceState:
    def __init__(__self__, *,
                 auto_renew: Optional[pulumi.Input[builtins.str]] = None,
                 billing_period: Optional[pulumi.Input[builtins.str]] = None,
                 billing_type: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 endpoints: Optional[pulumi.Input['InstanceEndpointsArgs']] = None,
                 expiration_time: Optional[pulumi.Input[builtins.str]] = None,
                 group_limit: Optional[pulumi.Input[builtins.int]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 message_retention: Optional[pulumi.Input[builtins.int]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 partition_limit: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_tags: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceResourceTagArgs']]]] = None,
                 resources: Optional[pulumi.Input['InstanceResourcesArgs']] = None,
                 security_group_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 specification: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]] = None,
                 times: Optional[pulumi.Input[builtins.int]] = None,
                 topic_limit: Optional[pulumi.Input[builtins.int]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Instance resources.
        :param pulumi.Input[builtins.str] auto_renew: 是否开启自动续费，取值如下：true：开启自动续费。false：关闭自动续费。
        :param pulumi.Input[builtins.str] billing_period: 购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        :param pulumi.Input[builtins.str] billing_type: 实例的计费方式，取值如下：POST：按量计费。MIX：包年包月。
        :param pulumi.Input[builtins.str] created_time: 实例的创建时间。
        :param pulumi.Input[builtins.str] description: 实例的描述语句。
        :param pulumi.Input[builtins.str] eip_id: 实例是否开启公网访问。如果需要开启公网访问，请配置相同地域的公网 IP 的 ID。
        :param pulumi.Input['InstanceEndpointsArgs'] endpoints: 实例所有接入点响应数据。
        :param pulumi.Input[builtins.str] expiration_time: 实例过期时间。
        :param pulumi.Input[builtins.int] group_limit: 实例消费组数量上限。
        :param pulumi.Input[builtins.str] instance_id: 实例ID。
        :param pulumi.Input[builtins.int] message_retention: 实例下所有 Topic 的消息保留时长，单位为小时。
        :param pulumi.Input[builtins.str] name: 自定设置 BMQ 实例的名称，约束限制如下：由小写字母、数字和中划线（-）组成。长度为 1~64 字符。
        :param pulumi.Input[builtins.int] partition_limit: 实例分区数量上限。
        :param pulumi.Input[builtins.str] project_name: 实例所属项目名称。
        :param pulumi.Input['InstanceResourcesArgs'] resources: 实例资源统计响应数据。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_id_lists: 实例使用安全组列表。
        :param pulumi.Input[builtins.str] specification: 实例规格。
        :param pulumi.Input[builtins.str] status: 实例的状态。取值如下：INITIALIZING：初始化中，INITIALIZATION*FAILED：初始化失败，RUNNING：运行中，MODIFYING：更新中，MODIFY*FAILED：更新失败，RELEASING：释放中，STOPPING：停止中，STOPPED：停止，RECOVERING：恢复中，EXCEPTION：异常，CAPACITY*EXPAXION*FAILED：扩容失败，EXPANDING*CAPACITY：扩容中，CANCEL*EXPANDING_CAPACITY：扩容取消中，RESTARTING：重启中，UNPAID：未支付
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_id_lists: 实例使用的子网列表。
        :param pulumi.Input[builtins.int] times: 包年包月类型实例的购买时长，单位为月。
        :param pulumi.Input[builtins.int] topic_limit: 实例Topic数量上限。
        :param pulumi.Input[builtins.str] vpc_id: 实例所在VPC ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] zone_id_lists: 实例所在可用区列表。
        """
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if billing_period is not None:
            pulumi.set(__self__, "billing_period", billing_period)
        if billing_type is not None:
            pulumi.set(__self__, "billing_type", billing_type)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if endpoints is not None:
            pulumi.set(__self__, "endpoints", endpoints)
        if expiration_time is not None:
            pulumi.set(__self__, "expiration_time", expiration_time)
        if group_limit is not None:
            pulumi.set(__self__, "group_limit", group_limit)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if message_retention is not None:
            pulumi.set(__self__, "message_retention", message_retention)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if partition_limit is not None:
            pulumi.set(__self__, "partition_limit", partition_limit)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if resource_tags is not None:
            pulumi.set(__self__, "resource_tags", resource_tags)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if security_group_id_lists is not None:
            pulumi.set(__self__, "security_group_id_lists", security_group_id_lists)
        if specification is not None:
            pulumi.set(__self__, "specification", specification)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subnet_id_lists is not None:
            pulumi.set(__self__, "subnet_id_lists", subnet_id_lists)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if times is not None:
            pulumi.set(__self__, "times", times)
        if topic_limit is not None:
            pulumi.set(__self__, "topic_limit", topic_limit)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_id_lists is not None:
            pulumi.set(__self__, "zone_id_lists", zone_id_lists)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否开启自动续费，取值如下：true：开启自动续费。false：关闭自动续费。
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="billingPeriod")
    def billing_period(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        """
        return pulumi.get(self, "billing_period")

    @billing_period.setter
    def billing_period(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "billing_period", value)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的计费方式，取值如下：POST：按量计费。MIX：包年包月。
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的描述语句。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例是否开启公网访问。如果需要开启公网访问，请配置相同地域的公网 IP 的 ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter
    def endpoints(self) -> Optional[pulumi.Input['InstanceEndpointsArgs']]:
        """
        实例所有接入点响应数据。
        """
        return pulumi.get(self, "endpoints")

    @endpoints.setter
    def endpoints(self, value: Optional[pulumi.Input['InstanceEndpointsArgs']]):
        pulumi.set(self, "endpoints", value)

    @property
    @pulumi.getter(name="expirationTime")
    def expiration_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例过期时间。
        """
        return pulumi.get(self, "expiration_time")

    @expiration_time.setter
    def expiration_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expiration_time", value)

    @property
    @pulumi.getter(name="groupLimit")
    def group_limit(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例消费组数量上限。
        """
        return pulumi.get(self, "group_limit")

    @group_limit.setter
    def group_limit(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "group_limit", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="messageRetention")
    def message_retention(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例下所有 Topic 的消息保留时长，单位为小时。
        """
        return pulumi.get(self, "message_retention")

    @message_retention.setter
    def message_retention(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "message_retention", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        自定设置 BMQ 实例的名称，约束限制如下：由小写字母、数字和中划线（-）组成。长度为 1~64 字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="partitionLimit")
    def partition_limit(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例分区数量上限。
        """
        return pulumi.get(self, "partition_limit")

    @partition_limit.setter
    def partition_limit(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "partition_limit", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="resourceTags")
    def resource_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceResourceTagArgs']]]]:
        return pulumi.get(self, "resource_tags")

    @resource_tags.setter
    def resource_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceResourceTagArgs']]]]):
        pulumi.set(self, "resource_tags", value)

    @property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input['InstanceResourcesArgs']]:
        """
        实例资源统计响应数据。
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input['InstanceResourcesArgs']]):
        pulumi.set(self, "resources", value)

    @property
    @pulumi.getter(name="securityGroupIdLists")
    def security_group_id_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        实例使用安全组列表。
        """
        return pulumi.get(self, "security_group_id_lists")

    @security_group_id_lists.setter
    def security_group_id_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "security_group_id_lists", value)

    @property
    @pulumi.getter
    def specification(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例规格。
        """
        return pulumi.get(self, "specification")

    @specification.setter
    def specification(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "specification", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的状态。取值如下：INITIALIZING：初始化中，INITIALIZATION*FAILED：初始化失败，RUNNING：运行中，MODIFYING：更新中，MODIFY*FAILED：更新失败，RELEASING：释放中，STOPPING：停止中，STOPPED：停止，RECOVERING：恢复中，EXCEPTION：异常，CAPACITY*EXPAXION*FAILED：扩容失败，EXPANDING*CAPACITY：扩容中，CANCEL*EXPANDING_CAPACITY：扩容取消中，RESTARTING：重启中，UNPAID：未支付
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subnetIdLists")
    def subnet_id_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        实例使用的子网列表。
        """
        return pulumi.get(self, "subnet_id_lists")

    @subnet_id_lists.setter
    def subnet_id_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "subnet_id_lists", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def times(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        包年包月类型实例的购买时长，单位为月。
        """
        return pulumi.get(self, "times")

    @times.setter
    def times(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "times", value)

    @property
    @pulumi.getter(name="topicLimit")
    def topic_limit(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例Topic数量上限。
        """
        return pulumi.get(self, "topic_limit")

    @topic_limit.setter
    def topic_limit(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "topic_limit", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所在VPC ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneIdLists")
    def zone_id_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        实例所在可用区列表。
        """
        return pulumi.get(self, "zone_id_lists")

    @zone_id_lists.setter
    def zone_id_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "zone_id_lists", value)


@pulumi.type_token("bytepluscc:bmq/instance:Instance")
class Instance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_renew: Optional[pulumi.Input[builtins.str]] = None,
                 billing_period: Optional[pulumi.Input[builtins.str]] = None,
                 billing_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 endpoints: Optional[pulumi.Input[Union['InstanceEndpointsArgs', 'InstanceEndpointsArgsDict']]] = None,
                 message_retention: Optional[pulumi.Input[builtins.int]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 specification: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
                 times: Optional[pulumi.Input[builtins.int]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        云原生消息引擎 100% 兼容 Apache Kafka 协议，基于云原生的全托管、高吞吐、低时延、高可用、高可扩展性、高稳定性的分布式消息引擎服务，支持灵活动态扩缩容和流批一体计算，提供企业级大数据量级的实时流数据处理能力，帮助您构建数据处理的“中枢神经系统”，广泛应用于日志收集、数据聚合、离线数据分析等业务场景。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        b_mq_instance_demo = bytepluscc.bmq.Instance("BMQInstanceDemo",
            name="BMQInstanceDemo",
            billing_type="POST",
            project_name="default",
            specification="bmq.standard",
            vpc_id="vpc-miltj87lh2ww5smt1bxxxxx",
            message_retention=1,
            endpoints={
                "public": {
                    "eip_id": "eip-3nriu2y2ufwu8931exxxxx",
                },
                "overlay": {
                    "vpc_ids": ["vpc-miltj87lh2ww5smt1bxxxxx"],
                },
            },
            security_group_id_lists=["sg-3nqnz9en1ucxs931eaxxxxx"],
            subnet_id_lists=["subnet-w02wsq25fitc865ykaxxxxx"],
            zone_id_lists=["cn-beijing-a"],
            tags=[{
                "key": "env",
                "type": "CUSTOM",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:bmq/instance:Instance example "instance_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] auto_renew: 是否开启自动续费，取值如下：true：开启自动续费。false：关闭自动续费。
        :param pulumi.Input[builtins.str] billing_period: 购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        :param pulumi.Input[builtins.str] billing_type: 实例的计费方式，取值如下：POST：按量计费。MIX：包年包月。
        :param pulumi.Input[builtins.str] description: 实例的描述语句。
        :param pulumi.Input[builtins.str] eip_id: 实例是否开启公网访问。如果需要开启公网访问，请配置相同地域的公网 IP 的 ID。
        :param pulumi.Input[Union['InstanceEndpointsArgs', 'InstanceEndpointsArgsDict']] endpoints: 实例所有接入点响应数据。
        :param pulumi.Input[builtins.int] message_retention: 实例下所有 Topic 的消息保留时长，单位为小时。
        :param pulumi.Input[builtins.str] name: 自定设置 BMQ 实例的名称，约束限制如下：由小写字母、数字和中划线（-）组成。长度为 1~64 字符。
        :param pulumi.Input[builtins.str] project_name: 实例所属项目名称。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_id_lists: 实例使用安全组列表。
        :param pulumi.Input[builtins.str] specification: 实例规格。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_id_lists: 实例使用的子网列表。
        :param pulumi.Input[builtins.int] times: 包年包月类型实例的购买时长，单位为月。
        :param pulumi.Input[builtins.str] vpc_id: 实例所在VPC ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] zone_id_lists: 实例所在可用区列表。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        云原生消息引擎 100% 兼容 Apache Kafka 协议，基于云原生的全托管、高吞吐、低时延、高可用、高可扩展性、高稳定性的分布式消息引擎服务，支持灵活动态扩缩容和流批一体计算，提供企业级大数据量级的实时流数据处理能力，帮助您构建数据处理的“中枢神经系统”，广泛应用于日志收集、数据聚合、离线数据分析等业务场景。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        b_mq_instance_demo = bytepluscc.bmq.Instance("BMQInstanceDemo",
            name="BMQInstanceDemo",
            billing_type="POST",
            project_name="default",
            specification="bmq.standard",
            vpc_id="vpc-miltj87lh2ww5smt1bxxxxx",
            message_retention=1,
            endpoints={
                "public": {
                    "eip_id": "eip-3nriu2y2ufwu8931exxxxx",
                },
                "overlay": {
                    "vpc_ids": ["vpc-miltj87lh2ww5smt1bxxxxx"],
                },
            },
            security_group_id_lists=["sg-3nqnz9en1ucxs931eaxxxxx"],
            subnet_id_lists=["subnet-w02wsq25fitc865ykaxxxxx"],
            zone_id_lists=["cn-beijing-a"],
            tags=[{
                "key": "env",
                "type": "CUSTOM",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:bmq/instance:Instance example "instance_id"
        ```

        :param str resource_name: The name of the resource.
        :param InstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_renew: Optional[pulumi.Input[builtins.str]] = None,
                 billing_period: Optional[pulumi.Input[builtins.str]] = None,
                 billing_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 endpoints: Optional[pulumi.Input[Union['InstanceEndpointsArgs', 'InstanceEndpointsArgsDict']]] = None,
                 message_retention: Optional[pulumi.Input[builtins.int]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 specification: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
                 times: Optional[pulumi.Input[builtins.int]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceArgs.__new__(InstanceArgs)

            __props__.__dict__["auto_renew"] = auto_renew
            __props__.__dict__["billing_period"] = billing_period
            if billing_type is None and not opts.urn:
                raise TypeError("Missing required property 'billing_type'")
            __props__.__dict__["billing_type"] = billing_type
            __props__.__dict__["description"] = description
            __props__.__dict__["eip_id"] = eip_id
            __props__.__dict__["endpoints"] = endpoints
            __props__.__dict__["message_retention"] = message_retention
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            if project_name is None and not opts.urn:
                raise TypeError("Missing required property 'project_name'")
            __props__.__dict__["project_name"] = project_name
            if security_group_id_lists is None and not opts.urn:
                raise TypeError("Missing required property 'security_group_id_lists'")
            __props__.__dict__["security_group_id_lists"] = security_group_id_lists
            if specification is None and not opts.urn:
                raise TypeError("Missing required property 'specification'")
            __props__.__dict__["specification"] = specification
            if subnet_id_lists is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_id_lists'")
            __props__.__dict__["subnet_id_lists"] = subnet_id_lists
            __props__.__dict__["tags"] = tags
            __props__.__dict__["times"] = times
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            if zone_id_lists is None and not opts.urn:
                raise TypeError("Missing required property 'zone_id_lists'")
            __props__.__dict__["zone_id_lists"] = zone_id_lists
            __props__.__dict__["created_time"] = None
            __props__.__dict__["expiration_time"] = None
            __props__.__dict__["group_limit"] = None
            __props__.__dict__["instance_id"] = None
            __props__.__dict__["partition_limit"] = None
            __props__.__dict__["resource_tags"] = None
            __props__.__dict__["resources"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["topic_limit"] = None
        super(Instance, __self__).__init__(
            'bytepluscc:bmq/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_renew: Optional[pulumi.Input[builtins.str]] = None,
            billing_period: Optional[pulumi.Input[builtins.str]] = None,
            billing_type: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            eip_id: Optional[pulumi.Input[builtins.str]] = None,
            endpoints: Optional[pulumi.Input[Union['InstanceEndpointsArgs', 'InstanceEndpointsArgsDict']]] = None,
            expiration_time: Optional[pulumi.Input[builtins.str]] = None,
            group_limit: Optional[pulumi.Input[builtins.int]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            message_retention: Optional[pulumi.Input[builtins.int]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            partition_limit: Optional[pulumi.Input[builtins.int]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            resource_tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceResourceTagArgs', 'InstanceResourceTagArgsDict']]]]] = None,
            resources: Optional[pulumi.Input[Union['InstanceResourcesArgs', 'InstanceResourcesArgsDict']]] = None,
            security_group_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            specification: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            subnet_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
            times: Optional[pulumi.Input[builtins.int]] = None,
            topic_limit: Optional[pulumi.Input[builtins.int]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'Instance':
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] auto_renew: 是否开启自动续费，取值如下：true：开启自动续费。false：关闭自动续费。
        :param pulumi.Input[builtins.str] billing_period: 购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        :param pulumi.Input[builtins.str] billing_type: 实例的计费方式，取值如下：POST：按量计费。MIX：包年包月。
        :param pulumi.Input[builtins.str] created_time: 实例的创建时间。
        :param pulumi.Input[builtins.str] description: 实例的描述语句。
        :param pulumi.Input[builtins.str] eip_id: 实例是否开启公网访问。如果需要开启公网访问，请配置相同地域的公网 IP 的 ID。
        :param pulumi.Input[Union['InstanceEndpointsArgs', 'InstanceEndpointsArgsDict']] endpoints: 实例所有接入点响应数据。
        :param pulumi.Input[builtins.str] expiration_time: 实例过期时间。
        :param pulumi.Input[builtins.int] group_limit: 实例消费组数量上限。
        :param pulumi.Input[builtins.str] instance_id: 实例ID。
        :param pulumi.Input[builtins.int] message_retention: 实例下所有 Topic 的消息保留时长，单位为小时。
        :param pulumi.Input[builtins.str] name: 自定设置 BMQ 实例的名称，约束限制如下：由小写字母、数字和中划线（-）组成。长度为 1~64 字符。
        :param pulumi.Input[builtins.int] partition_limit: 实例分区数量上限。
        :param pulumi.Input[builtins.str] project_name: 实例所属项目名称。
        :param pulumi.Input[Union['InstanceResourcesArgs', 'InstanceResourcesArgsDict']] resources: 实例资源统计响应数据。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_id_lists: 实例使用安全组列表。
        :param pulumi.Input[builtins.str] specification: 实例规格。
        :param pulumi.Input[builtins.str] status: 实例的状态。取值如下：INITIALIZING：初始化中，INITIALIZATION*FAILED：初始化失败，RUNNING：运行中，MODIFYING：更新中，MODIFY*FAILED：更新失败，RELEASING：释放中，STOPPING：停止中，STOPPED：停止，RECOVERING：恢复中，EXCEPTION：异常，CAPACITY*EXPAXION*FAILED：扩容失败，EXPANDING*CAPACITY：扩容中，CANCEL*EXPANDING_CAPACITY：扩容取消中，RESTARTING：重启中，UNPAID：未支付
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_id_lists: 实例使用的子网列表。
        :param pulumi.Input[builtins.int] times: 包年包月类型实例的购买时长，单位为月。
        :param pulumi.Input[builtins.int] topic_limit: 实例Topic数量上限。
        :param pulumi.Input[builtins.str] vpc_id: 实例所在VPC ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] zone_id_lists: 实例所在可用区列表。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceState.__new__(_InstanceState)

        __props__.__dict__["auto_renew"] = auto_renew
        __props__.__dict__["billing_period"] = billing_period
        __props__.__dict__["billing_type"] = billing_type
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["eip_id"] = eip_id
        __props__.__dict__["endpoints"] = endpoints
        __props__.__dict__["expiration_time"] = expiration_time
        __props__.__dict__["group_limit"] = group_limit
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["message_retention"] = message_retention
        __props__.__dict__["name"] = name
        __props__.__dict__["partition_limit"] = partition_limit
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["resource_tags"] = resource_tags
        __props__.__dict__["resources"] = resources
        __props__.__dict__["security_group_id_lists"] = security_group_id_lists
        __props__.__dict__["specification"] = specification
        __props__.__dict__["status"] = status
        __props__.__dict__["subnet_id_lists"] = subnet_id_lists
        __props__.__dict__["tags"] = tags
        __props__.__dict__["times"] = times
        __props__.__dict__["topic_limit"] = topic_limit
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["zone_id_lists"] = zone_id_lists
        return Instance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> pulumi.Output[builtins.str]:
        """
        是否开启自动续费，取值如下：true：开启自动续费。false：关闭自动续费。
        """
        return pulumi.get(self, "auto_renew")

    @property
    @pulumi.getter(name="billingPeriod")
    def billing_period(self) -> pulumi.Output[builtins.str]:
        """
        购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        """
        return pulumi.get(self, "billing_period")

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> pulumi.Output[builtins.str]:
        """
        实例的计费方式，取值如下：POST：按量计费。MIX：包年包月。
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        实例的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        实例的描述语句。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> pulumi.Output[builtins.str]:
        """
        实例是否开启公网访问。如果需要开启公网访问，请配置相同地域的公网 IP 的 ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter
    def endpoints(self) -> pulumi.Output['outputs.InstanceEndpoints']:
        """
        实例所有接入点响应数据。
        """
        return pulumi.get(self, "endpoints")

    @property
    @pulumi.getter(name="expirationTime")
    def expiration_time(self) -> pulumi.Output[builtins.str]:
        """
        实例过期时间。
        """
        return pulumi.get(self, "expiration_time")

    @property
    @pulumi.getter(name="groupLimit")
    def group_limit(self) -> pulumi.Output[builtins.int]:
        """
        实例消费组数量上限。
        """
        return pulumi.get(self, "group_limit")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="messageRetention")
    def message_retention(self) -> pulumi.Output[builtins.int]:
        """
        实例下所有 Topic 的消息保留时长，单位为小时。
        """
        return pulumi.get(self, "message_retention")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        自定设置 BMQ 实例的名称，约束限制如下：由小写字母、数字和中划线（-）组成。长度为 1~64 字符。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="partitionLimit")
    def partition_limit(self) -> pulumi.Output[builtins.int]:
        """
        实例分区数量上限。
        """
        return pulumi.get(self, "partition_limit")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        实例所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="resourceTags")
    def resource_tags(self) -> pulumi.Output[Sequence['outputs.InstanceResourceTag']]:
        return pulumi.get(self, "resource_tags")

    @property
    @pulumi.getter
    def resources(self) -> pulumi.Output['outputs.InstanceResources']:
        """
        实例资源统计响应数据。
        """
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter(name="securityGroupIdLists")
    def security_group_id_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        实例使用安全组列表。
        """
        return pulumi.get(self, "security_group_id_lists")

    @property
    @pulumi.getter
    def specification(self) -> pulumi.Output[builtins.str]:
        """
        实例规格。
        """
        return pulumi.get(self, "specification")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        实例的状态。取值如下：INITIALIZING：初始化中，INITIALIZATION*FAILED：初始化失败，RUNNING：运行中，MODIFYING：更新中，MODIFY*FAILED：更新失败，RELEASING：释放中，STOPPING：停止中，STOPPED：停止，RECOVERING：恢复中，EXCEPTION：异常，CAPACITY*EXPAXION*FAILED：扩容失败，EXPANDING*CAPACITY：扩容中，CANCEL*EXPANDING_CAPACITY：扩容取消中，RESTARTING：重启中，UNPAID：未支付
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetIdLists")
    def subnet_id_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        实例使用的子网列表。
        """
        return pulumi.get(self, "subnet_id_lists")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.InstanceTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def times(self) -> pulumi.Output[builtins.int]:
        """
        包年包月类型实例的购买时长，单位为月。
        """
        return pulumi.get(self, "times")

    @property
    @pulumi.getter(name="topicLimit")
    def topic_limit(self) -> pulumi.Output[builtins.int]:
        """
        实例Topic数量上限。
        """
        return pulumi.get(self, "topic_limit")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        实例所在VPC ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneIdLists")
    def zone_id_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        实例所在可用区列表。
        """
        return pulumi.get(self, "zone_id_lists")

