# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'KeyMultiRegionConfiguration',
    'KeyMultiRegionConfigurationPrimaryKey',
    'KeyMultiRegionConfigurationReplicaKey',
    'KeyTag',
    'GetKeyMultiRegionConfigurationResult',
    'GetKeyMultiRegionConfigurationPrimaryKeyResult',
    'GetKeyMultiRegionConfigurationReplicaKeyResult',
    'GetKeyTagResult',
]

@pulumi.output_type
class KeyMultiRegionConfiguration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "multiRegionKeyType":
            suggest = "multi_region_key_type"
        elif key == "primaryKey":
            suggest = "primary_key"
        elif key == "replicaKeys":
            suggest = "replica_keys"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in KeyMultiRegionConfiguration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        KeyMultiRegionConfiguration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        KeyMultiRegionConfiguration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 multi_region_key_type: Optional[builtins.str] = None,
                 primary_key: Optional['outputs.KeyMultiRegionConfigurationPrimaryKey'] = None,
                 replica_keys: Optional[Sequence['outputs.KeyMultiRegionConfigurationReplicaKey']] = None):
        """
        :param builtins.str multi_region_key_type: 多区域密钥的类型。
        :param 'KeyMultiRegionConfigurationPrimaryKeyArgs' primary_key: 主多区域键的事务识别号和区域 ID。
        """
        if multi_region_key_type is not None:
            pulumi.set(__self__, "multi_region_key_type", multi_region_key_type)
        if primary_key is not None:
            pulumi.set(__self__, "primary_key", primary_key)
        if replica_keys is not None:
            pulumi.set(__self__, "replica_keys", replica_keys)

    @property
    @pulumi.getter(name="multiRegionKeyType")
    def multi_region_key_type(self) -> Optional[builtins.str]:
        """
        多区域密钥的类型。
        """
        return pulumi.get(self, "multi_region_key_type")

    @property
    @pulumi.getter(name="primaryKey")
    def primary_key(self) -> Optional['outputs.KeyMultiRegionConfigurationPrimaryKey']:
        """
        主多区域键的事务识别号和区域 ID。
        """
        return pulumi.get(self, "primary_key")

    @property
    @pulumi.getter(name="replicaKeys")
    def replica_keys(self) -> Optional[Sequence['outputs.KeyMultiRegionConfigurationReplicaKey']]:
        return pulumi.get(self, "replica_keys")


@pulumi.output_type
class KeyMultiRegionConfigurationPrimaryKey(dict):
    def __init__(__self__, *,
                 region: Optional[builtins.str] = None,
                 trn: Optional[builtins.str] = None):
        """
        :param builtins.str region: 多区域密钥的区域 ID。
        :param builtins.str trn: 多区域密钥的 TRN。
        """
        if region is not None:
            pulumi.set(__self__, "region", region)
        if trn is not None:
            pulumi.set(__self__, "trn", trn)

    @property
    @pulumi.getter
    def region(self) -> Optional[builtins.str]:
        """
        多区域密钥的区域 ID。
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter
    def trn(self) -> Optional[builtins.str]:
        """
        多区域密钥的 TRN。
        """
        return pulumi.get(self, "trn")


@pulumi.output_type
class KeyMultiRegionConfigurationReplicaKey(dict):
    def __init__(__self__, *,
                 region: Optional[builtins.str] = None,
                 trn: Optional[builtins.str] = None):
        """
        :param builtins.str region: 多区域密钥的区域 ID。
        :param builtins.str trn: 多区域密钥的转换。
        """
        if region is not None:
            pulumi.set(__self__, "region", region)
        if trn is not None:
            pulumi.set(__self__, "trn", trn)

    @property
    @pulumi.getter
    def region(self) -> Optional[builtins.str]:
        """
        多区域密钥的区域 ID。
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter
    def trn(self) -> Optional[builtins.str]:
        """
        多区域密钥的转换。
        """
        return pulumi.get(self, "trn")


@pulumi.output_type
class KeyTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: KMS密钥的标签键
        :param builtins.str value: KMS密钥的标签值
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        KMS密钥的标签键
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        KMS密钥的标签值
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetKeyMultiRegionConfigurationResult(dict):
    def __init__(__self__, *,
                 multi_region_key_type: builtins.str,
                 primary_key: 'outputs.GetKeyMultiRegionConfigurationPrimaryKeyResult',
                 replica_keys: Sequence['outputs.GetKeyMultiRegionConfigurationReplicaKeyResult']):
        """
        :param builtins.str multi_region_key_type: 多区域密钥的类型。
        :param 'GetKeyMultiRegionConfigurationPrimaryKeyArgs' primary_key: 主多区域键的事务识别号和区域 ID。
        :param Sequence['GetKeyMultiRegionConfigurationReplicaKeyArgs'] replica_keys: 副本多区域密钥的事务记录编号和区域 ID。
        """
        pulumi.set(__self__, "multi_region_key_type", multi_region_key_type)
        pulumi.set(__self__, "primary_key", primary_key)
        pulumi.set(__self__, "replica_keys", replica_keys)

    @property
    @pulumi.getter(name="multiRegionKeyType")
    def multi_region_key_type(self) -> builtins.str:
        """
        多区域密钥的类型。
        """
        return pulumi.get(self, "multi_region_key_type")

    @property
    @pulumi.getter(name="primaryKey")
    def primary_key(self) -> 'outputs.GetKeyMultiRegionConfigurationPrimaryKeyResult':
        """
        主多区域键的事务识别号和区域 ID。
        """
        return pulumi.get(self, "primary_key")

    @property
    @pulumi.getter(name="replicaKeys")
    def replica_keys(self) -> Sequence['outputs.GetKeyMultiRegionConfigurationReplicaKeyResult']:
        """
        副本多区域密钥的事务记录编号和区域 ID。
        """
        return pulumi.get(self, "replica_keys")


@pulumi.output_type
class GetKeyMultiRegionConfigurationPrimaryKeyResult(dict):
    def __init__(__self__, *,
                 region: builtins.str,
                 trn: builtins.str):
        """
        :param builtins.str region: 多区域密钥的区域 ID。
        :param builtins.str trn: 多区域密钥的 TRN。
        """
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "trn", trn)

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        多区域密钥的区域 ID。
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter
    def trn(self) -> builtins.str:
        """
        多区域密钥的 TRN。
        """
        return pulumi.get(self, "trn")


@pulumi.output_type
class GetKeyMultiRegionConfigurationReplicaKeyResult(dict):
    def __init__(__self__, *,
                 region: builtins.str,
                 trn: builtins.str):
        """
        :param builtins.str region: 多区域密钥的区域 ID。
        :param builtins.str trn: 多区域密钥的转换。
        """
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "trn", trn)

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        多区域密钥的区域 ID。
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter
    def trn(self) -> builtins.str:
        """
        多区域密钥的转换。
        """
        return pulumi.get(self, "trn")


@pulumi.output_type
class GetKeyTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: KMS密钥的标签键
        :param builtins.str value: KMS密钥的标签值
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        KMS密钥的标签键
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        KMS密钥的标签值
        """
        return pulumi.get(self, "value")


