# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'NgwEipAddress',
    'NgwNatIpAddress',
    'NgwTag',
    'GetNgwEipAddressResult',
    'GetNgwNatIpAddressResult',
    'GetNgwTagResult',
]

@pulumi.output_type
class NgwEipAddress(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "allocationId":
            suggest = "allocation_id"
        elif key == "eipAddress":
            suggest = "eip_address"
        elif key == "usingStatus":
            suggest = "using_status"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in NgwEipAddress. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        NgwEipAddress.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        NgwEipAddress.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 allocation_id: Optional[builtins.str] = None,
                 eip_address: Optional[builtins.str] = None,
                 using_status: Optional[builtins.str] = None):
        """
        :param builtins.str allocation_id: 公网IP的ID。
        :param builtins.str eip_address: 公网IP的地址。
        :param builtins.str using_status: 公网IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        if allocation_id is not None:
            pulumi.set(__self__, "allocation_id", allocation_id)
        if eip_address is not None:
            pulumi.set(__self__, "eip_address", eip_address)
        if using_status is not None:
            pulumi.set(__self__, "using_status", using_status)

    @property
    @pulumi.getter(name="allocationId")
    def allocation_id(self) -> Optional[builtins.str]:
        """
        公网IP的ID。
        """
        return pulumi.get(self, "allocation_id")

    @property
    @pulumi.getter(name="eipAddress")
    def eip_address(self) -> Optional[builtins.str]:
        """
        公网IP的地址。
        """
        return pulumi.get(self, "eip_address")

    @property
    @pulumi.getter(name="usingStatus")
    def using_status(self) -> Optional[builtins.str]:
        """
        公网IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        return pulumi.get(self, "using_status")


@pulumi.output_type
class NgwNatIpAddress(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "natIpAddress":
            suggest = "nat_ip_address"
        elif key == "natIpId":
            suggest = "nat_ip_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in NgwNatIpAddress. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        NgwNatIpAddress.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        NgwNatIpAddress.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 nat_ip_address: Optional[builtins.str] = None,
                 nat_ip_id: Optional[builtins.str] = None):
        """
        :param builtins.str nat_ip_address: 中转Ip地址。
        :param builtins.str nat_ip_id: 中转Ip id。
        """
        if nat_ip_address is not None:
            pulumi.set(__self__, "nat_ip_address", nat_ip_address)
        if nat_ip_id is not None:
            pulumi.set(__self__, "nat_ip_id", nat_ip_id)

    @property
    @pulumi.getter(name="natIpAddress")
    def nat_ip_address(self) -> Optional[builtins.str]:
        """
        中转Ip地址。
        """
        return pulumi.get(self, "nat_ip_address")

    @property
    @pulumi.getter(name="natIpId")
    def nat_ip_id(self) -> Optional[builtins.str]:
        """
        中转Ip id。
        """
        return pulumi.get(self, "nat_ip_id")


@pulumi.output_type
class NgwTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 用户标签的标签键。
        :param builtins.str value: 用户标签的标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetNgwEipAddressResult(dict):
    def __init__(__self__, *,
                 allocation_id: builtins.str,
                 eip_address: builtins.str,
                 using_status: builtins.str):
        """
        :param builtins.str allocation_id: 公网IP的ID。
        :param builtins.str eip_address: 公网IP的地址。
        :param builtins.str using_status: 公网IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        pulumi.set(__self__, "allocation_id", allocation_id)
        pulumi.set(__self__, "eip_address", eip_address)
        pulumi.set(__self__, "using_status", using_status)

    @property
    @pulumi.getter(name="allocationId")
    def allocation_id(self) -> builtins.str:
        """
        公网IP的ID。
        """
        return pulumi.get(self, "allocation_id")

    @property
    @pulumi.getter(name="eipAddress")
    def eip_address(self) -> builtins.str:
        """
        公网IP的地址。
        """
        return pulumi.get(self, "eip_address")

    @property
    @pulumi.getter(name="usingStatus")
    def using_status(self) -> builtins.str:
        """
        公网IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        return pulumi.get(self, "using_status")


@pulumi.output_type
class GetNgwNatIpAddressResult(dict):
    def __init__(__self__, *,
                 nat_ip_address: builtins.str,
                 nat_ip_id: builtins.str):
        """
        :param builtins.str nat_ip_address: 中转Ip地址。
        :param builtins.str nat_ip_id: 中转Ip id。
        """
        pulumi.set(__self__, "nat_ip_address", nat_ip_address)
        pulumi.set(__self__, "nat_ip_id", nat_ip_id)

    @property
    @pulumi.getter(name="natIpAddress")
    def nat_ip_address(self) -> builtins.str:
        """
        中转Ip地址。
        """
        return pulumi.get(self, "nat_ip_address")

    @property
    @pulumi.getter(name="natIpId")
    def nat_ip_id(self) -> builtins.str:
        """
        中转Ip id。
        """
        return pulumi.get(self, "nat_ip_id")


@pulumi.output_type
class GetNgwTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 用户标签的标签键。
        :param builtins.str value: 用户标签的标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")


