# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstanceCapacityInfoArgs',
    'InstanceCapacityInfoArgsDict',
    'InstanceTagArgs',
    'InstanceTagArgsDict',
]

MYPY = False

if not MYPY:
    class InstanceCapacityInfoArgsDict(TypedDict):
        total_ti_b: NotRequired[pulumi.Input[builtins.int]]
        """
        文件系统总容量，单位为 TiB。注意：磁盘均衡耗时会根据集群容量、集群负载等因素有所不同，如 PiB 级以上的集群扩容通常需要天级别的磁盘均衡时间，磁盘均衡完成后扩容容量才会生效（并为扩容容量计费）。
        """
        used_gi_b: NotRequired[pulumi.Input[builtins.int]]
        """
        已使用容量（GiB）。
        """
elif False:
    InstanceCapacityInfoArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceCapacityInfoArgs:
    def __init__(__self__, *,
                 total_ti_b: Optional[pulumi.Input[builtins.int]] = None,
                 used_gi_b: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.int] total_ti_b: 文件系统总容量，单位为 TiB。注意：磁盘均衡耗时会根据集群容量、集群负载等因素有所不同，如 PiB 级以上的集群扩容通常需要天级别的磁盘均衡时间，磁盘均衡完成后扩容容量才会生效（并为扩容容量计费）。
        :param pulumi.Input[builtins.int] used_gi_b: 已使用容量（GiB）。
        """
        if total_ti_b is not None:
            pulumi.set(__self__, "total_ti_b", total_ti_b)
        if used_gi_b is not None:
            pulumi.set(__self__, "used_gi_b", used_gi_b)

    @property
    @pulumi.getter(name="totalTiB")
    def total_ti_b(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        文件系统总容量，单位为 TiB。注意：磁盘均衡耗时会根据集群容量、集群负载等因素有所不同，如 PiB 级以上的集群扩容通常需要天级别的磁盘均衡时间，磁盘均衡完成后扩容容量才会生效（并为扩容容量计费）。
        """
        return pulumi.get(self, "total_ti_b")

    @total_ti_b.setter
    def total_ti_b(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "total_ti_b", value)

    @property
    @pulumi.getter(name="usedGiB")
    def used_gi_b(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        已使用容量（GiB）。
        """
        return pulumi.get(self, "used_gi_b")

    @used_gi_b.setter
    def used_gi_b(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "used_gi_b", value)


if not MYPY:
    class InstanceTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        用户标签的标签键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        用户标签的标签值。
        """
elif False:
    InstanceTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 用户标签的标签键。
        :param pulumi.Input[builtins.str] value: 用户标签的标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


