# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GatewayServiceArgs', 'GatewayService']

@pulumi.input_type
class GatewayServiceArgs:
    def __init__(__self__, *,
                 auth_spec: pulumi.Input['GatewayServiceAuthSpecArgs'],
                 gateway_id: pulumi.Input[builtins.str],
                 protocols: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 service_name: pulumi.Input[builtins.str],
                 comments: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a GatewayService resource.
        :param pulumi.Input['GatewayServiceAuthSpecArgs'] auth_spec: 认证配置。
        :param pulumi.Input[builtins.str] gateway_id: 网关ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] protocols: 服务支持的协议。取值：HTTP：HTTP。HTTPS：HTTPS。
        :param pulumi.Input[builtins.str] service_name: 服务名称。支持大小写字母、数字和中划线（-），长度限制为2~128个字符。不能以中划线（-）开头。。
        :param pulumi.Input[builtins.str] comments: 备注，长度限制为0~253个字符。
        """
        pulumi.set(__self__, "auth_spec", auth_spec)
        pulumi.set(__self__, "gateway_id", gateway_id)
        pulumi.set(__self__, "protocols", protocols)
        pulumi.set(__self__, "service_name", service_name)
        if comments is not None:
            pulumi.set(__self__, "comments", comments)

    @property
    @pulumi.getter(name="authSpec")
    def auth_spec(self) -> pulumi.Input['GatewayServiceAuthSpecArgs']:
        """
        认证配置。
        """
        return pulumi.get(self, "auth_spec")

    @auth_spec.setter
    def auth_spec(self, value: pulumi.Input['GatewayServiceAuthSpecArgs']):
        pulumi.set(self, "auth_spec", value)

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> pulumi.Input[builtins.str]:
        """
        网关ID。
        """
        return pulumi.get(self, "gateway_id")

    @gateway_id.setter
    def gateway_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "gateway_id", value)

    @property
    @pulumi.getter
    def protocols(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        服务支持的协议。取值：HTTP：HTTP。HTTPS：HTTPS。
        """
        return pulumi.get(self, "protocols")

    @protocols.setter
    def protocols(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "protocols", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        服务名称。支持大小写字母、数字和中划线（-），长度限制为2~128个字符。不能以中划线（-）开头。。
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def comments(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备注，长度限制为0~253个字符。
        """
        return pulumi.get(self, "comments")

    @comments.setter
    def comments(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "comments", value)


@pulumi.input_type
class _GatewayServiceState:
    def __init__(__self__, *,
                 auth_spec: Optional[pulumi.Input['GatewayServiceAuthSpecArgs']] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 custom_domains: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayServiceCustomDomainArgs']]]] = None,
                 domain_spec: Optional[pulumi.Input['GatewayServiceDomainSpecArgs']] = None,
                 domains: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayServiceDomainArgs']]]] = None,
                 gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 message: Optional[pulumi.Input[builtins.str]] = None,
                 protocols: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering GatewayService resources.
        :param pulumi.Input['GatewayServiceAuthSpecArgs'] auth_spec: 认证配置。
        :param pulumi.Input[builtins.str] comments: 备注，长度限制为0~253个字符。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input['GatewayServiceDomainSpecArgs'] domain_spec: 域名详情。
        :param pulumi.Input[builtins.str] gateway_id: 网关ID。
        :param pulumi.Input[builtins.str] gateway_name: 网关名称。
        :param pulumi.Input[builtins.str] message: 服务创建失败、删除失败或异常时的错误信息。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] protocols: 服务支持的协议。取值：HTTP：HTTP。HTTPS：HTTPS。
        :param pulumi.Input[builtins.str] service_id: 服务ID。
        :param pulumi.Input[builtins.str] service_name: 服务名称。支持大小写字母、数字和中划线（-），长度限制为2~128个字符。不能以中划线（-）开头。。
        :param pulumi.Input[builtins.str] status: Creating：创建中。CreatedFailed：创建失败。Running：运行中。Deleting：删除中。DeletedFailed：删除失败。Abnormal：异常。
        """
        if auth_spec is not None:
            pulumi.set(__self__, "auth_spec", auth_spec)
        if comments is not None:
            pulumi.set(__self__, "comments", comments)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if custom_domains is not None:
            pulumi.set(__self__, "custom_domains", custom_domains)
        if domain_spec is not None:
            pulumi.set(__self__, "domain_spec", domain_spec)
        if domains is not None:
            pulumi.set(__self__, "domains", domains)
        if gateway_id is not None:
            pulumi.set(__self__, "gateway_id", gateway_id)
        if gateway_name is not None:
            pulumi.set(__self__, "gateway_name", gateway_name)
        if message is not None:
            pulumi.set(__self__, "message", message)
        if protocols is not None:
            pulumi.set(__self__, "protocols", protocols)
        if service_id is not None:
            pulumi.set(__self__, "service_id", service_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="authSpec")
    def auth_spec(self) -> Optional[pulumi.Input['GatewayServiceAuthSpecArgs']]:
        """
        认证配置。
        """
        return pulumi.get(self, "auth_spec")

    @auth_spec.setter
    def auth_spec(self, value: Optional[pulumi.Input['GatewayServiceAuthSpecArgs']]):
        pulumi.set(self, "auth_spec", value)

    @property
    @pulumi.getter
    def comments(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备注，长度限制为0~253个字符。
        """
        return pulumi.get(self, "comments")

    @comments.setter
    def comments(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "comments", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="customDomains")
    def custom_domains(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GatewayServiceCustomDomainArgs']]]]:
        return pulumi.get(self, "custom_domains")

    @custom_domains.setter
    def custom_domains(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayServiceCustomDomainArgs']]]]):
        pulumi.set(self, "custom_domains", value)

    @property
    @pulumi.getter(name="domainSpec")
    def domain_spec(self) -> Optional[pulumi.Input['GatewayServiceDomainSpecArgs']]:
        """
        域名详情。
        """
        return pulumi.get(self, "domain_spec")

    @domain_spec.setter
    def domain_spec(self, value: Optional[pulumi.Input['GatewayServiceDomainSpecArgs']]):
        pulumi.set(self, "domain_spec", value)

    @property
    @pulumi.getter
    def domains(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GatewayServiceDomainArgs']]]]:
        return pulumi.get(self, "domains")

    @domains.setter
    def domains(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayServiceDomainArgs']]]]):
        pulumi.set(self, "domains", value)

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网关ID。
        """
        return pulumi.get(self, "gateway_id")

    @gateway_id.setter
    def gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "gateway_id", value)

    @property
    @pulumi.getter(name="gatewayName")
    def gateway_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网关名称。
        """
        return pulumi.get(self, "gateway_name")

    @gateway_name.setter
    def gateway_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "gateway_name", value)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务创建失败、删除失败或异常时的错误信息。
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter
    def protocols(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        服务支持的协议。取值：HTTP：HTTP。HTTPS：HTTPS。
        """
        return pulumi.get(self, "protocols")

    @protocols.setter
    def protocols(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "protocols", value)

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务ID。
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务名称。支持大小写字母、数字和中划线（-），长度限制为2~128个字符。不能以中划线（-）开头。。
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Creating：创建中。CreatedFailed：创建失败。Running：运行中。Deleting：删除中。DeletedFailed：删除失败。Abnormal：异常。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("bytepluscc:apig/gatewayService:GatewayService")
class GatewayService(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_spec: Optional[pulumi.Input[Union['GatewayServiceAuthSpecArgs', 'GatewayServiceAuthSpecArgsDict']]] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 protocols: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        服务是一组路由对外暴露的入口，用于区分流量的来源和协议，实现业务、环境、逻辑租户隔离。服务可以绑定独立的访问域名，以域名维度访问业务。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        apig_gateway_service_demo = bytepluscc.apig.GatewayService("ApigGatewayServiceDemo",
            service_name="ApigGatewayServiceDemo",
            gateway_id="gd3vehjs7npja181xxxxx",
            protocols=[
                "HTTP",
                "HTTPS",
            ],
            auth_spec={
                "enable": False,
            },
            comments="ApigGatewayServiceDemo-test")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:apig/gatewayService:GatewayService example "service_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['GatewayServiceAuthSpecArgs', 'GatewayServiceAuthSpecArgsDict']] auth_spec: 认证配置。
        :param pulumi.Input[builtins.str] comments: 备注，长度限制为0~253个字符。
        :param pulumi.Input[builtins.str] gateway_id: 网关ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] protocols: 服务支持的协议。取值：HTTP：HTTP。HTTPS：HTTPS。
        :param pulumi.Input[builtins.str] service_name: 服务名称。支持大小写字母、数字和中划线（-），长度限制为2~128个字符。不能以中划线（-）开头。。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GatewayServiceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        服务是一组路由对外暴露的入口，用于区分流量的来源和协议，实现业务、环境、逻辑租户隔离。服务可以绑定独立的访问域名，以域名维度访问业务。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        apig_gateway_service_demo = bytepluscc.apig.GatewayService("ApigGatewayServiceDemo",
            service_name="ApigGatewayServiceDemo",
            gateway_id="gd3vehjs7npja181xxxxx",
            protocols=[
                "HTTP",
                "HTTPS",
            ],
            auth_spec={
                "enable": False,
            },
            comments="ApigGatewayServiceDemo-test")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:apig/gatewayService:GatewayService example "service_id"
        ```

        :param str resource_name: The name of the resource.
        :param GatewayServiceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GatewayServiceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_spec: Optional[pulumi.Input[Union['GatewayServiceAuthSpecArgs', 'GatewayServiceAuthSpecArgsDict']]] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 protocols: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GatewayServiceArgs.__new__(GatewayServiceArgs)

            if auth_spec is None and not opts.urn:
                raise TypeError("Missing required property 'auth_spec'")
            __props__.__dict__["auth_spec"] = auth_spec
            __props__.__dict__["comments"] = comments
            if gateway_id is None and not opts.urn:
                raise TypeError("Missing required property 'gateway_id'")
            __props__.__dict__["gateway_id"] = gateway_id
            if protocols is None and not opts.urn:
                raise TypeError("Missing required property 'protocols'")
            __props__.__dict__["protocols"] = protocols
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["created_time"] = None
            __props__.__dict__["custom_domains"] = None
            __props__.__dict__["domain_spec"] = None
            __props__.__dict__["domains"] = None
            __props__.__dict__["gateway_name"] = None
            __props__.__dict__["message"] = None
            __props__.__dict__["service_id"] = None
            __props__.__dict__["status"] = None
        super(GatewayService, __self__).__init__(
            'bytepluscc:apig/gatewayService:GatewayService',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auth_spec: Optional[pulumi.Input[Union['GatewayServiceAuthSpecArgs', 'GatewayServiceAuthSpecArgsDict']]] = None,
            comments: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            custom_domains: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GatewayServiceCustomDomainArgs', 'GatewayServiceCustomDomainArgsDict']]]]] = None,
            domain_spec: Optional[pulumi.Input[Union['GatewayServiceDomainSpecArgs', 'GatewayServiceDomainSpecArgsDict']]] = None,
            domains: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GatewayServiceDomainArgs', 'GatewayServiceDomainArgsDict']]]]] = None,
            gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            gateway_name: Optional[pulumi.Input[builtins.str]] = None,
            message: Optional[pulumi.Input[builtins.str]] = None,
            protocols: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            service_id: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'GatewayService':
        """
        Get an existing GatewayService resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['GatewayServiceAuthSpecArgs', 'GatewayServiceAuthSpecArgsDict']] auth_spec: 认证配置。
        :param pulumi.Input[builtins.str] comments: 备注，长度限制为0~253个字符。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[Union['GatewayServiceDomainSpecArgs', 'GatewayServiceDomainSpecArgsDict']] domain_spec: 域名详情。
        :param pulumi.Input[builtins.str] gateway_id: 网关ID。
        :param pulumi.Input[builtins.str] gateway_name: 网关名称。
        :param pulumi.Input[builtins.str] message: 服务创建失败、删除失败或异常时的错误信息。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] protocols: 服务支持的协议。取值：HTTP：HTTP。HTTPS：HTTPS。
        :param pulumi.Input[builtins.str] service_id: 服务ID。
        :param pulumi.Input[builtins.str] service_name: 服务名称。支持大小写字母、数字和中划线（-），长度限制为2~128个字符。不能以中划线（-）开头。。
        :param pulumi.Input[builtins.str] status: Creating：创建中。CreatedFailed：创建失败。Running：运行中。Deleting：删除中。DeletedFailed：删除失败。Abnormal：异常。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GatewayServiceState.__new__(_GatewayServiceState)

        __props__.__dict__["auth_spec"] = auth_spec
        __props__.__dict__["comments"] = comments
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["custom_domains"] = custom_domains
        __props__.__dict__["domain_spec"] = domain_spec
        __props__.__dict__["domains"] = domains
        __props__.__dict__["gateway_id"] = gateway_id
        __props__.__dict__["gateway_name"] = gateway_name
        __props__.__dict__["message"] = message
        __props__.__dict__["protocols"] = protocols
        __props__.__dict__["service_id"] = service_id
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["status"] = status
        return GatewayService(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authSpec")
    def auth_spec(self) -> pulumi.Output['outputs.GatewayServiceAuthSpec']:
        """
        认证配置。
        """
        return pulumi.get(self, "auth_spec")

    @property
    @pulumi.getter
    def comments(self) -> pulumi.Output[builtins.str]:
        """
        备注，长度限制为0~253个字符。
        """
        return pulumi.get(self, "comments")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="customDomains")
    def custom_domains(self) -> pulumi.Output[Sequence['outputs.GatewayServiceCustomDomain']]:
        return pulumi.get(self, "custom_domains")

    @property
    @pulumi.getter(name="domainSpec")
    def domain_spec(self) -> pulumi.Output['outputs.GatewayServiceDomainSpec']:
        """
        域名详情。
        """
        return pulumi.get(self, "domain_spec")

    @property
    @pulumi.getter
    def domains(self) -> pulumi.Output[Sequence['outputs.GatewayServiceDomain']]:
        return pulumi.get(self, "domains")

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        网关ID。
        """
        return pulumi.get(self, "gateway_id")

    @property
    @pulumi.getter(name="gatewayName")
    def gateway_name(self) -> pulumi.Output[builtins.str]:
        """
        网关名称。
        """
        return pulumi.get(self, "gateway_name")

    @property
    @pulumi.getter
    def message(self) -> pulumi.Output[builtins.str]:
        """
        服务创建失败、删除失败或异常时的错误信息。
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter
    def protocols(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        服务支持的协议。取值：HTTP：HTTP。HTTPS：HTTPS。
        """
        return pulumi.get(self, "protocols")

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> pulumi.Output[builtins.str]:
        """
        服务ID。
        """
        return pulumi.get(self, "service_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        服务名称。支持大小写字母、数字和中划线（-），长度限制为2~128个字符。不能以中划线（-）开头。。
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Creating：创建中。CreatedFailed：创建失败。Running：运行中。Deleting：删除中。DeletedFailed：删除失败。Abnormal：异常。
        """
        return pulumi.get(self, "status")

