# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NgwArgs', 'Ngw']

@pulumi.input_type
class NgwArgs:
    def __init__(__self__, *,
                 vpc_id: pulumi.Input[builtins.str],
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 network_type: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 smart_schedule_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 smart_schedule_rule: Optional[pulumi.Input[builtins.str]] = None,
                 spec: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NgwTagArgs']]]] = None):
        """
        The set of arguments for constructing a Ngw resource.
        :param pulumi.Input[builtins.str] vpc_id: NAT网关所在私有网络的ID。
        :param pulumi.Input[builtins.int] billing_type: NAT网关的计费方式。取值如下：1 ：包年包月。2（默认值）：按量计费-按规格计费。3：按量计费-按使用量计费。当NetworkType传入intranet时，本参数仅支持且必须传入3。
        :param pulumi.Input[builtins.str] description: NAT网关的描述。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1 ～ 255个字符。不填默认空字符串。
        :param pulumi.Input[builtins.str] nat_gateway_name: NAT网关的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认是NAT网关实例的ID。
        :param pulumi.Input[builtins.str] network_type: NAT网关类型。internet：公网NAT网关。intranet：私网NAT网关。
        :param pulumi.Input[builtins.int] period: 购买包年包月NAT网关的时长，默认1。当PeriodUnit传入Month，Period取值范围：1 ~ 9、12、24、36。当PeriodUnit传入Year，Period取值范围：1 ~ 3。
        :param pulumi.Input[builtins.str] period_unit: 购买包年包月NAT网关时长的单位，默认Month。Month ：月。Year ：年。
        :param pulumi.Input[builtins.str] project_name: NAT网关所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[builtins.bool] smart_schedule_enabled: 是否开启智能调度。
        :param pulumi.Input[builtins.str] smart_schedule_rule: 智能调度策略规则。ChinaMobile：中国移动。ChinaUnicom：中国联通。ChinaTelecom：中国电信。BGP：BGP多线。
        :param pulumi.Input[builtins.str] spec: NAT网关的规格。Small（默认）：小型。Medium：中型。Large：大型。Extra*Large*1：超大型-1。Extra*Large*2：超大型-2。
        :param pulumi.Input[builtins.str] subnet_id: NAT网关所在子网的ID。传入的子网，必须是VpcId传入的私有网络的子网。子网内至少有一个可用的私网IP。系统自动生成的NAT网关网卡将占用该子网一个私网IP。子网所在的可用区需要已部署NAT网关资源。子网所在可用区将作为NAT网关的主可用区，并自动关联备可用区。当主可用区发生故障时，NAT网关自动切换到备可用区。
        """
        pulumi.set(__self__, "vpc_id", vpc_id)
        if billing_type is not None:
            pulumi.set(__self__, "billing_type", billing_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if nat_gateway_name is not None:
            pulumi.set(__self__, "nat_gateway_name", nat_gateway_name)
        if network_type is not None:
            pulumi.set(__self__, "network_type", network_type)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_unit is not None:
            pulumi.set(__self__, "period_unit", period_unit)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if smart_schedule_enabled is not None:
            pulumi.set(__self__, "smart_schedule_enabled", smart_schedule_enabled)
        if smart_schedule_rule is not None:
            pulumi.set(__self__, "smart_schedule_rule", smart_schedule_rule)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        NAT网关所在私有网络的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        NAT网关的计费方式。取值如下：1 ：包年包月。2（默认值）：按量计费-按规格计费。3：按量计费-按使用量计费。当NetworkType传入intranet时，本参数仅支持且必须传入3。
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关的描述。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1 ～ 255个字符。不填默认空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="natGatewayName")
    def nat_gateway_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认是NAT网关实例的ID。
        """
        return pulumi.get(self, "nat_gateway_name")

    @nat_gateway_name.setter
    def nat_gateway_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_gateway_name", value)

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关类型。internet：公网NAT网关。intranet：私网NAT网关。
        """
        return pulumi.get(self, "network_type")

    @network_type.setter
    def network_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_type", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        购买包年包月NAT网关的时长，默认1。当PeriodUnit传入Month，Period取值范围：1 ~ 9、12、24、36。当PeriodUnit传入Year，Period取值范围：1 ~ 3。
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        购买包年包月NAT网关时长的单位，默认Month。Month ：月。Year ：年。
        """
        return pulumi.get(self, "period_unit")

    @period_unit.setter
    def period_unit(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "period_unit", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="smartScheduleEnabled")
    def smart_schedule_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启智能调度。
        """
        return pulumi.get(self, "smart_schedule_enabled")

    @smart_schedule_enabled.setter
    def smart_schedule_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "smart_schedule_enabled", value)

    @property
    @pulumi.getter(name="smartScheduleRule")
    def smart_schedule_rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        智能调度策略规则。ChinaMobile：中国移动。ChinaUnicom：中国联通。ChinaTelecom：中国电信。BGP：BGP多线。
        """
        return pulumi.get(self, "smart_schedule_rule")

    @smart_schedule_rule.setter
    def smart_schedule_rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "smart_schedule_rule", value)

    @property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关的规格。Small（默认）：小型。Medium：中型。Large：大型。Extra*Large*1：超大型-1。Extra*Large*2：超大型-2。
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "spec", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关所在子网的ID。传入的子网，必须是VpcId传入的私有网络的子网。子网内至少有一个可用的私网IP。系统自动生成的NAT网关网卡将占用该子网一个私网IP。子网所在的可用区需要已部署NAT网关资源。子网所在可用区将作为NAT网关的主可用区，并自动关联备可用区。当主可用区发生故障时，NAT网关自动切换到备可用区。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NgwTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NgwTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _NgwState:
    def __init__(__self__, *,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 business_status: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 deleted_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 direct_mode: Optional[pulumi.Input[builtins.bool]] = None,
                 dnat_entry_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 eip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input['NgwEipAddressArgs']]]] = None,
                 expired_time: Optional[pulumi.Input[builtins.str]] = None,
                 lock_reason: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input['NgwNatIpAddressArgs']]]] = None,
                 network_interface_id: Optional[pulumi.Input[builtins.str]] = None,
                 network_type: Optional[pulumi.Input[builtins.str]] = None,
                 overdue_time: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 smart_schedule_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 smart_schedule_rule: Optional[pulumi.Input[builtins.str]] = None,
                 snat_entry_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 spec: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NgwTagArgs']]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Ngw resources.
        :param pulumi.Input[builtins.int] billing_type: NAT网关的计费方式。取值如下：1 ：包年包月。2（默认值）：按量计费-按规格计费。3：按量计费-按使用量计费。当NetworkType传入intranet时，本参数仅支持且必须传入3。
        :param pulumi.Input[builtins.str] business_status: NAT网关是否被锁定。空值：正常未被锁定。Normal：正常未被锁定。FinancialLocked：因欠费被锁定。
        :param pulumi.Input[builtins.str] created_time: 创建时间
        :param pulumi.Input[builtins.str] deleted_time: 删除时间
        :param pulumi.Input[builtins.str] description: NAT网关的描述。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1 ～ 255个字符。不填默认空字符串。
        :param pulumi.Input[builtins.bool] direct_mode: 标识该nat是直通还是非直通。   - true（默认）：EIP直通nat网关。   - false：非EIP直通nat网关。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] dnat_entry_ids: DNAT规则ID列表。
        :param pulumi.Input[builtins.str] expired_time: 包年包月NAT网关到期时间。仅包年包月计费类型的NAT网关会返回此参数。
        :param pulumi.Input[builtins.str] lock_reason: NAT被锁定的原因。financial：因欠费被锁定。security：因安全原因被锁定。
        :param pulumi.Input[builtins.str] nat_gateway_id: NAT网关ID。
        :param pulumi.Input[builtins.str] nat_gateway_name: NAT网关的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认是NAT网关实例的ID。
        :param pulumi.Input[builtins.str] network_interface_id: NAT网关占用的网卡ID。
        :param pulumi.Input[builtins.str] network_type: NAT网关类型。internet：公网NAT网关。intranet：私网NAT网关。
        :param pulumi.Input[builtins.str] overdue_time: 资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值。
        :param pulumi.Input[builtins.int] period: 购买包年包月NAT网关的时长，默认1。当PeriodUnit传入Month，Period取值范围：1 ~ 9、12、24、36。当PeriodUnit传入Year，Period取值范围：1 ~ 3。
        :param pulumi.Input[builtins.str] period_unit: 购买包年包月NAT网关时长的单位，默认Month。Month ：月。Year ：年。
        :param pulumi.Input[builtins.str] project_name: NAT网关所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[builtins.bool] smart_schedule_enabled: 是否开启智能调度。
        :param pulumi.Input[builtins.str] smart_schedule_rule: 智能调度策略规则。ChinaMobile：中国移动。ChinaUnicom：中国联通。ChinaTelecom：中国电信。BGP：BGP多线。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] snat_entry_ids: SNAT规则ID列表。
        :param pulumi.Input[builtins.str] spec: NAT网关的规格。Small（默认）：小型。Medium：中型。Large：大型。Extra*Large*1：超大型-1。Extra*Large*2：超大型-2。
        :param pulumi.Input[builtins.str] status: NAT网关的状态。Available：可用。Creating：创建中。Pending：操作中。Deleting：删除中。
        :param pulumi.Input[builtins.str] subnet_id: NAT网关所在子网的ID。传入的子网，必须是VpcId传入的私有网络的子网。子网内至少有一个可用的私网IP。系统自动生成的NAT网关网卡将占用该子网一个私网IP。子网所在的可用区需要已部署NAT网关资源。子网所在可用区将作为NAT网关的主可用区，并自动关联备可用区。当主可用区发生故障时，NAT网关自动切换到备可用区。
        :param pulumi.Input[builtins.str] updated_time: NAT网关的最后操作时间。
        :param pulumi.Input[builtins.str] vpc_id: NAT网关所在私有网络的ID。
        :param pulumi.Input[builtins.str] zone_id: NAT网关所属主可用区的ID。
        """
        if billing_type is not None:
            pulumi.set(__self__, "billing_type", billing_type)
        if business_status is not None:
            pulumi.set(__self__, "business_status", business_status)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if deleted_time is not None:
            pulumi.set(__self__, "deleted_time", deleted_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if direct_mode is not None:
            pulumi.set(__self__, "direct_mode", direct_mode)
        if dnat_entry_ids is not None:
            pulumi.set(__self__, "dnat_entry_ids", dnat_entry_ids)
        if eip_addresses is not None:
            pulumi.set(__self__, "eip_addresses", eip_addresses)
        if expired_time is not None:
            pulumi.set(__self__, "expired_time", expired_time)
        if lock_reason is not None:
            pulumi.set(__self__, "lock_reason", lock_reason)
        if nat_gateway_id is not None:
            pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if nat_gateway_name is not None:
            pulumi.set(__self__, "nat_gateway_name", nat_gateway_name)
        if nat_ip_addresses is not None:
            pulumi.set(__self__, "nat_ip_addresses", nat_ip_addresses)
        if network_interface_id is not None:
            pulumi.set(__self__, "network_interface_id", network_interface_id)
        if network_type is not None:
            pulumi.set(__self__, "network_type", network_type)
        if overdue_time is not None:
            pulumi.set(__self__, "overdue_time", overdue_time)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_unit is not None:
            pulumi.set(__self__, "period_unit", period_unit)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if smart_schedule_enabled is not None:
            pulumi.set(__self__, "smart_schedule_enabled", smart_schedule_enabled)
        if smart_schedule_rule is not None:
            pulumi.set(__self__, "smart_schedule_rule", smart_schedule_rule)
        if snat_entry_ids is not None:
            pulumi.set(__self__, "snat_entry_ids", snat_entry_ids)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        NAT网关的计费方式。取值如下：1 ：包年包月。2（默认值）：按量计费-按规格计费。3：按量计费-按使用量计费。当NetworkType传入intranet时，本参数仅支持且必须传入3。
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关是否被锁定。空值：正常未被锁定。Normal：正常未被锁定。FinancialLocked：因欠费被锁定。
        """
        return pulumi.get(self, "business_status")

    @business_status.setter
    def business_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "business_status", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        删除时间
        """
        return pulumi.get(self, "deleted_time")

    @deleted_time.setter
    def deleted_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deleted_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关的描述。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1 ～ 255个字符。不填默认空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="directMode")
    def direct_mode(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        标识该nat是直通还是非直通。   - true（默认）：EIP直通nat网关。   - false：非EIP直通nat网关。
        """
        return pulumi.get(self, "direct_mode")

    @direct_mode.setter
    def direct_mode(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "direct_mode", value)

    @property
    @pulumi.getter(name="dnatEntryIds")
    def dnat_entry_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        DNAT规则ID列表。
        """
        return pulumi.get(self, "dnat_entry_ids")

    @dnat_entry_ids.setter
    def dnat_entry_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "dnat_entry_ids", value)

    @property
    @pulumi.getter(name="eipAddresses")
    def eip_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NgwEipAddressArgs']]]]:
        return pulumi.get(self, "eip_addresses")

    @eip_addresses.setter
    def eip_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NgwEipAddressArgs']]]]):
        pulumi.set(self, "eip_addresses", value)

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        包年包月NAT网关到期时间。仅包年包月计费类型的NAT网关会返回此参数。
        """
        return pulumi.get(self, "expired_time")

    @expired_time.setter
    def expired_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expired_time", value)

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT被锁定的原因。financial：因欠费被锁定。security：因安全原因被锁定。
        """
        return pulumi.get(self, "lock_reason")

    @lock_reason.setter
    def lock_reason(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "lock_reason", value)

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_gateway_id", value)

    @property
    @pulumi.getter(name="natGatewayName")
    def nat_gateway_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认是NAT网关实例的ID。
        """
        return pulumi.get(self, "nat_gateway_name")

    @nat_gateway_name.setter
    def nat_gateway_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_gateway_name", value)

    @property
    @pulumi.getter(name="natIpAddresses")
    def nat_ip_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NgwNatIpAddressArgs']]]]:
        return pulumi.get(self, "nat_ip_addresses")

    @nat_ip_addresses.setter
    def nat_ip_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NgwNatIpAddressArgs']]]]):
        pulumi.set(self, "nat_ip_addresses", value)

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关占用的网卡ID。
        """
        return pulumi.get(self, "network_interface_id")

    @network_interface_id.setter
    def network_interface_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_interface_id", value)

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关类型。internet：公网NAT网关。intranet：私网NAT网关。
        """
        return pulumi.get(self, "network_type")

    @network_type.setter
    def network_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_type", value)

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值。
        """
        return pulumi.get(self, "overdue_time")

    @overdue_time.setter
    def overdue_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "overdue_time", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        购买包年包月NAT网关的时长，默认1。当PeriodUnit传入Month，Period取值范围：1 ~ 9、12、24、36。当PeriodUnit传入Year，Period取值范围：1 ~ 3。
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        购买包年包月NAT网关时长的单位，默认Month。Month ：月。Year ：年。
        """
        return pulumi.get(self, "period_unit")

    @period_unit.setter
    def period_unit(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "period_unit", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="smartScheduleEnabled")
    def smart_schedule_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启智能调度。
        """
        return pulumi.get(self, "smart_schedule_enabled")

    @smart_schedule_enabled.setter
    def smart_schedule_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "smart_schedule_enabled", value)

    @property
    @pulumi.getter(name="smartScheduleRule")
    def smart_schedule_rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        智能调度策略规则。ChinaMobile：中国移动。ChinaUnicom：中国联通。ChinaTelecom：中国电信。BGP：BGP多线。
        """
        return pulumi.get(self, "smart_schedule_rule")

    @smart_schedule_rule.setter
    def smart_schedule_rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "smart_schedule_rule", value)

    @property
    @pulumi.getter(name="snatEntryIds")
    def snat_entry_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        SNAT规则ID列表。
        """
        return pulumi.get(self, "snat_entry_ids")

    @snat_entry_ids.setter
    def snat_entry_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "snat_entry_ids", value)

    @property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关的规格。Small（默认）：小型。Medium：中型。Large：大型。Extra*Large*1：超大型-1。Extra*Large*2：超大型-2。
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "spec", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关的状态。Available：可用。Creating：创建中。Pending：操作中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关所在子网的ID。传入的子网，必须是VpcId传入的私有网络的子网。子网内至少有一个可用的私网IP。系统自动生成的NAT网关网卡将占用该子网一个私网IP。子网所在的可用区需要已部署NAT网关资源。子网所在可用区将作为NAT网关的主可用区，并自动关联备可用区。当主可用区发生故障时，NAT网关自动切换到备可用区。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NgwTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NgwTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关的最后操作时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关所在私有网络的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关所属主可用区的ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.type_token("bytepluscc:natgateway/ngw:Ngw")
class Ngw(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 network_type: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 smart_schedule_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 smart_schedule_rule: Optional[pulumi.Input[builtins.str]] = None,
                 spec: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NgwTagArgs', 'NgwTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        NAT网关为私有网络内的云服务器提供网络地址转换服务。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        nat_gateway_ngw_demo = bytepluscc.natgateway.Ngw("NatGatewayNGWDemo",
            spec="Small",
            vpc_id="vpc-2f8kicbjkot8g4f4pzyyxxxxx",
            subnet_id="subnet-3hicda1321wqo3nkipk4xxxxx",
            nat_gateway_name="NatGatewayNGWDemo",
            billing_type=2,
            project_name="default",
            network_type="internet",
            description="NatGatewayNGWDemo",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:natgateway/ngw:Ngw example "nat_gateway_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] billing_type: NAT网关的计费方式。取值如下：1 ：包年包月。2（默认值）：按量计费-按规格计费。3：按量计费-按使用量计费。当NetworkType传入intranet时，本参数仅支持且必须传入3。
        :param pulumi.Input[builtins.str] description: NAT网关的描述。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1 ～ 255个字符。不填默认空字符串。
        :param pulumi.Input[builtins.str] nat_gateway_name: NAT网关的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认是NAT网关实例的ID。
        :param pulumi.Input[builtins.str] network_type: NAT网关类型。internet：公网NAT网关。intranet：私网NAT网关。
        :param pulumi.Input[builtins.int] period: 购买包年包月NAT网关的时长，默认1。当PeriodUnit传入Month，Period取值范围：1 ~ 9、12、24、36。当PeriodUnit传入Year，Period取值范围：1 ~ 3。
        :param pulumi.Input[builtins.str] period_unit: 购买包年包月NAT网关时长的单位，默认Month。Month ：月。Year ：年。
        :param pulumi.Input[builtins.str] project_name: NAT网关所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[builtins.bool] smart_schedule_enabled: 是否开启智能调度。
        :param pulumi.Input[builtins.str] smart_schedule_rule: 智能调度策略规则。ChinaMobile：中国移动。ChinaUnicom：中国联通。ChinaTelecom：中国电信。BGP：BGP多线。
        :param pulumi.Input[builtins.str] spec: NAT网关的规格。Small（默认）：小型。Medium：中型。Large：大型。Extra*Large*1：超大型-1。Extra*Large*2：超大型-2。
        :param pulumi.Input[builtins.str] subnet_id: NAT网关所在子网的ID。传入的子网，必须是VpcId传入的私有网络的子网。子网内至少有一个可用的私网IP。系统自动生成的NAT网关网卡将占用该子网一个私网IP。子网所在的可用区需要已部署NAT网关资源。子网所在可用区将作为NAT网关的主可用区，并自动关联备可用区。当主可用区发生故障时，NAT网关自动切换到备可用区。
        :param pulumi.Input[builtins.str] vpc_id: NAT网关所在私有网络的ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NgwArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        NAT网关为私有网络内的云服务器提供网络地址转换服务。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        nat_gateway_ngw_demo = bytepluscc.natgateway.Ngw("NatGatewayNGWDemo",
            spec="Small",
            vpc_id="vpc-2f8kicbjkot8g4f4pzyyxxxxx",
            subnet_id="subnet-3hicda1321wqo3nkipk4xxxxx",
            nat_gateway_name="NatGatewayNGWDemo",
            billing_type=2,
            project_name="default",
            network_type="internet",
            description="NatGatewayNGWDemo",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:natgateway/ngw:Ngw example "nat_gateway_id"
        ```

        :param str resource_name: The name of the resource.
        :param NgwArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NgwArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 network_type: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 smart_schedule_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 smart_schedule_rule: Optional[pulumi.Input[builtins.str]] = None,
                 spec: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NgwTagArgs', 'NgwTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NgwArgs.__new__(NgwArgs)

            __props__.__dict__["billing_type"] = billing_type
            __props__.__dict__["description"] = description
            __props__.__dict__["nat_gateway_name"] = nat_gateway_name
            __props__.__dict__["network_type"] = network_type
            __props__.__dict__["period"] = period
            __props__.__dict__["period_unit"] = period_unit
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["smart_schedule_enabled"] = smart_schedule_enabled
            __props__.__dict__["smart_schedule_rule"] = smart_schedule_rule
            __props__.__dict__["spec"] = spec
            __props__.__dict__["subnet_id"] = subnet_id
            __props__.__dict__["tags"] = tags
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["business_status"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["deleted_time"] = None
            __props__.__dict__["direct_mode"] = None
            __props__.__dict__["dnat_entry_ids"] = None
            __props__.__dict__["eip_addresses"] = None
            __props__.__dict__["expired_time"] = None
            __props__.__dict__["lock_reason"] = None
            __props__.__dict__["nat_gateway_id"] = None
            __props__.__dict__["nat_ip_addresses"] = None
            __props__.__dict__["network_interface_id"] = None
            __props__.__dict__["overdue_time"] = None
            __props__.__dict__["snat_entry_ids"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
            __props__.__dict__["zone_id"] = None
        super(Ngw, __self__).__init__(
            'bytepluscc:natgateway/ngw:Ngw',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            billing_type: Optional[pulumi.Input[builtins.int]] = None,
            business_status: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            deleted_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            direct_mode: Optional[pulumi.Input[builtins.bool]] = None,
            dnat_entry_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            eip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NgwEipAddressArgs', 'NgwEipAddressArgsDict']]]]] = None,
            expired_time: Optional[pulumi.Input[builtins.str]] = None,
            lock_reason: Optional[pulumi.Input[builtins.str]] = None,
            nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            nat_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
            nat_ip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NgwNatIpAddressArgs', 'NgwNatIpAddressArgsDict']]]]] = None,
            network_interface_id: Optional[pulumi.Input[builtins.str]] = None,
            network_type: Optional[pulumi.Input[builtins.str]] = None,
            overdue_time: Optional[pulumi.Input[builtins.str]] = None,
            period: Optional[pulumi.Input[builtins.int]] = None,
            period_unit: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            smart_schedule_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            smart_schedule_rule: Optional[pulumi.Input[builtins.str]] = None,
            snat_entry_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            spec: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NgwTagArgs', 'NgwTagArgsDict']]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Ngw':
        """
        Get an existing Ngw resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] billing_type: NAT网关的计费方式。取值如下：1 ：包年包月。2（默认值）：按量计费-按规格计费。3：按量计费-按使用量计费。当NetworkType传入intranet时，本参数仅支持且必须传入3。
        :param pulumi.Input[builtins.str] business_status: NAT网关是否被锁定。空值：正常未被锁定。Normal：正常未被锁定。FinancialLocked：因欠费被锁定。
        :param pulumi.Input[builtins.str] created_time: 创建时间
        :param pulumi.Input[builtins.str] deleted_time: 删除时间
        :param pulumi.Input[builtins.str] description: NAT网关的描述。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1 ～ 255个字符。不填默认空字符串。
        :param pulumi.Input[builtins.bool] direct_mode: 标识该nat是直通还是非直通。   - true（默认）：EIP直通nat网关。   - false：非EIP直通nat网关。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] dnat_entry_ids: DNAT规则ID列表。
        :param pulumi.Input[builtins.str] expired_time: 包年包月NAT网关到期时间。仅包年包月计费类型的NAT网关会返回此参数。
        :param pulumi.Input[builtins.str] lock_reason: NAT被锁定的原因。financial：因欠费被锁定。security：因安全原因被锁定。
        :param pulumi.Input[builtins.str] nat_gateway_id: NAT网关ID。
        :param pulumi.Input[builtins.str] nat_gateway_name: NAT网关的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认是NAT网关实例的ID。
        :param pulumi.Input[builtins.str] network_interface_id: NAT网关占用的网卡ID。
        :param pulumi.Input[builtins.str] network_type: NAT网关类型。internet：公网NAT网关。intranet：私网NAT网关。
        :param pulumi.Input[builtins.str] overdue_time: 资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值。
        :param pulumi.Input[builtins.int] period: 购买包年包月NAT网关的时长，默认1。当PeriodUnit传入Month，Period取值范围：1 ~ 9、12、24、36。当PeriodUnit传入Year，Period取值范围：1 ~ 3。
        :param pulumi.Input[builtins.str] period_unit: 购买包年包月NAT网关时长的单位，默认Month。Month ：月。Year ：年。
        :param pulumi.Input[builtins.str] project_name: NAT网关所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[builtins.bool] smart_schedule_enabled: 是否开启智能调度。
        :param pulumi.Input[builtins.str] smart_schedule_rule: 智能调度策略规则。ChinaMobile：中国移动。ChinaUnicom：中国联通。ChinaTelecom：中国电信。BGP：BGP多线。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] snat_entry_ids: SNAT规则ID列表。
        :param pulumi.Input[builtins.str] spec: NAT网关的规格。Small（默认）：小型。Medium：中型。Large：大型。Extra*Large*1：超大型-1。Extra*Large*2：超大型-2。
        :param pulumi.Input[builtins.str] status: NAT网关的状态。Available：可用。Creating：创建中。Pending：操作中。Deleting：删除中。
        :param pulumi.Input[builtins.str] subnet_id: NAT网关所在子网的ID。传入的子网，必须是VpcId传入的私有网络的子网。子网内至少有一个可用的私网IP。系统自动生成的NAT网关网卡将占用该子网一个私网IP。子网所在的可用区需要已部署NAT网关资源。子网所在可用区将作为NAT网关的主可用区，并自动关联备可用区。当主可用区发生故障时，NAT网关自动切换到备可用区。
        :param pulumi.Input[builtins.str] updated_time: NAT网关的最后操作时间。
        :param pulumi.Input[builtins.str] vpc_id: NAT网关所在私有网络的ID。
        :param pulumi.Input[builtins.str] zone_id: NAT网关所属主可用区的ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NgwState.__new__(_NgwState)

        __props__.__dict__["billing_type"] = billing_type
        __props__.__dict__["business_status"] = business_status
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["deleted_time"] = deleted_time
        __props__.__dict__["description"] = description
        __props__.__dict__["direct_mode"] = direct_mode
        __props__.__dict__["dnat_entry_ids"] = dnat_entry_ids
        __props__.__dict__["eip_addresses"] = eip_addresses
        __props__.__dict__["expired_time"] = expired_time
        __props__.__dict__["lock_reason"] = lock_reason
        __props__.__dict__["nat_gateway_id"] = nat_gateway_id
        __props__.__dict__["nat_gateway_name"] = nat_gateway_name
        __props__.__dict__["nat_ip_addresses"] = nat_ip_addresses
        __props__.__dict__["network_interface_id"] = network_interface_id
        __props__.__dict__["network_type"] = network_type
        __props__.__dict__["overdue_time"] = overdue_time
        __props__.__dict__["period"] = period
        __props__.__dict__["period_unit"] = period_unit
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["smart_schedule_enabled"] = smart_schedule_enabled
        __props__.__dict__["smart_schedule_rule"] = smart_schedule_rule
        __props__.__dict__["snat_entry_ids"] = snat_entry_ids
        __props__.__dict__["spec"] = spec
        __props__.__dict__["status"] = status
        __props__.__dict__["subnet_id"] = subnet_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["zone_id"] = zone_id
        return Ngw(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> pulumi.Output[builtins.int]:
        """
        NAT网关的计费方式。取值如下：1 ：包年包月。2（默认值）：按量计费-按规格计费。3：按量计费-按使用量计费。当NetworkType传入intranet时，本参数仅支持且必须传入3。
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关是否被锁定。空值：正常未被锁定。Normal：正常未被锁定。FinancialLocked：因欠费被锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> pulumi.Output[builtins.str]:
        """
        删除时间
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关的描述。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1 ～ 255个字符。不填默认空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="directMode")
    def direct_mode(self) -> pulumi.Output[builtins.bool]:
        """
        标识该nat是直通还是非直通。   - true（默认）：EIP直通nat网关。   - false：非EIP直通nat网关。
        """
        return pulumi.get(self, "direct_mode")

    @property
    @pulumi.getter(name="dnatEntryIds")
    def dnat_entry_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        DNAT规则ID列表。
        """
        return pulumi.get(self, "dnat_entry_ids")

    @property
    @pulumi.getter(name="eipAddresses")
    def eip_addresses(self) -> pulumi.Output[Sequence['outputs.NgwEipAddress']]:
        return pulumi.get(self, "eip_addresses")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> pulumi.Output[builtins.str]:
        """
        包年包月NAT网关到期时间。仅包年包月计费类型的NAT网关会返回此参数。
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> pulumi.Output[builtins.str]:
        """
        NAT被锁定的原因。financial：因欠费被锁定。security：因安全原因被锁定。
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @property
    @pulumi.getter(name="natGatewayName")
    def nat_gateway_name(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认是NAT网关实例的ID。
        """
        return pulumi.get(self, "nat_gateway_name")

    @property
    @pulumi.getter(name="natIpAddresses")
    def nat_ip_addresses(self) -> pulumi.Output[Sequence['outputs.NgwNatIpAddress']]:
        return pulumi.get(self, "nat_ip_addresses")

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关占用的网卡ID。
        """
        return pulumi.get(self, "network_interface_id")

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关类型。internet：公网NAT网关。intranet：私网NAT网关。
        """
        return pulumi.get(self, "network_type")

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> pulumi.Output[builtins.str]:
        """
        资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值。
        """
        return pulumi.get(self, "overdue_time")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[builtins.int]:
        """
        购买包年包月NAT网关的时长，默认1。当PeriodUnit传入Month，Period取值范围：1 ~ 9、12、24、36。当PeriodUnit传入Year，Period取值范围：1 ~ 3。
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> pulumi.Output[builtins.str]:
        """
        购买包年包月NAT网关时长的单位，默认Month。Month ：月。Year ：年。
        """
        return pulumi.get(self, "period_unit")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="smartScheduleEnabled")
    def smart_schedule_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启智能调度。
        """
        return pulumi.get(self, "smart_schedule_enabled")

    @property
    @pulumi.getter(name="smartScheduleRule")
    def smart_schedule_rule(self) -> pulumi.Output[builtins.str]:
        """
        智能调度策略规则。ChinaMobile：中国移动。ChinaUnicom：中国联通。ChinaTelecom：中国电信。BGP：BGP多线。
        """
        return pulumi.get(self, "smart_schedule_rule")

    @property
    @pulumi.getter(name="snatEntryIds")
    def snat_entry_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        SNAT规则ID列表。
        """
        return pulumi.get(self, "snat_entry_ids")

    @property
    @pulumi.getter
    def spec(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关的规格。Small（默认）：小型。Medium：中型。Large：大型。Extra*Large*1：超大型-1。Extra*Large*2：超大型-2。
        """
        return pulumi.get(self, "spec")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关的状态。Available：可用。Creating：创建中。Pending：操作中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关所在子网的ID。传入的子网，必须是VpcId传入的私有网络的子网。子网内至少有一个可用的私网IP。系统自动生成的NAT网关网卡将占用该子网一个私网IP。子网所在的可用区需要已部署NAT网关资源。子网所在可用区将作为NAT网关的主可用区，并自动关联备可用区。当主可用区发生故障时，NAT网关自动切换到备可用区。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.NgwTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关的最后操作时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关所在私有网络的ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关所属主可用区的ID。
        """
        return pulumi.get(self, "zone_id")

