# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetEnisResult',
    'AwaitableGetEnisResult',
    'get_enis',
    'get_enis_output',
]

@pulumi.output_type
class GetEnisResult:
    """
    A collection of values returned by getEnis.
    """
    def __init__(__self__, id=None, ids=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the data source.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        Set of Resource Identifiers.
        """
        return pulumi.get(self, "ids")


class AwaitableGetEnisResult(GetEnisResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnisResult(
            id=self.id,
            ids=self.ids)


def get_enis(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnisResult:
    """
    Plural Data Source schema for Byteplus::VPC::ENI
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getEnis:getEnis', __args__, opts=opts, typ=GetEnisResult).value

    return AwaitableGetEnisResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'))
def get_enis_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEnisResult]:
    """
    Plural Data Source schema for Byteplus::VPC::ENI
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getEnis:getEnis', __args__, opts=opts, typ=GetEnisResult)
    return __ret__.apply(lambda __response__: GetEnisResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids')))
