# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'NgwEipAddressArgs',
    'NgwEipAddressArgsDict',
    'NgwNatIpAddressArgs',
    'NgwNatIpAddressArgsDict',
    'NgwTagArgs',
    'NgwTagArgsDict',
]

MYPY = False

if not MYPY:
    class NgwEipAddressArgsDict(TypedDict):
        allocation_id: NotRequired[pulumi.Input[builtins.str]]
        """
        公网IP的ID。
        """
        eip_address: NotRequired[pulumi.Input[builtins.str]]
        """
        公网IP的地址。
        """
        using_status: NotRequired[pulumi.Input[builtins.str]]
        """
        公网IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
elif False:
    NgwEipAddressArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NgwEipAddressArgs:
    def __init__(__self__, *,
                 allocation_id: Optional[pulumi.Input[builtins.str]] = None,
                 eip_address: Optional[pulumi.Input[builtins.str]] = None,
                 using_status: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] allocation_id: 公网IP的ID。
        :param pulumi.Input[builtins.str] eip_address: 公网IP的地址。
        :param pulumi.Input[builtins.str] using_status: 公网IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        if allocation_id is not None:
            pulumi.set(__self__, "allocation_id", allocation_id)
        if eip_address is not None:
            pulumi.set(__self__, "eip_address", eip_address)
        if using_status is not None:
            pulumi.set(__self__, "using_status", using_status)

    @property
    @pulumi.getter(name="allocationId")
    def allocation_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        公网IP的ID。
        """
        return pulumi.get(self, "allocation_id")

    @allocation_id.setter
    def allocation_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allocation_id", value)

    @property
    @pulumi.getter(name="eipAddress")
    def eip_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        公网IP的地址。
        """
        return pulumi.get(self, "eip_address")

    @eip_address.setter
    def eip_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_address", value)

    @property
    @pulumi.getter(name="usingStatus")
    def using_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        公网IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        return pulumi.get(self, "using_status")

    @using_status.setter
    def using_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "using_status", value)


if not MYPY:
    class NgwNatIpAddressArgsDict(TypedDict):
        nat_ip_address: NotRequired[pulumi.Input[builtins.str]]
        """
        中转Ip地址。
        """
        nat_ip_id: NotRequired[pulumi.Input[builtins.str]]
        """
        中转Ip id。
        """
elif False:
    NgwNatIpAddressArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NgwNatIpAddressArgs:
    def __init__(__self__, *,
                 nat_ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] nat_ip_address: 中转Ip地址。
        :param pulumi.Input[builtins.str] nat_ip_id: 中转Ip id。
        """
        if nat_ip_address is not None:
            pulumi.set(__self__, "nat_ip_address", nat_ip_address)
        if nat_ip_id is not None:
            pulumi.set(__self__, "nat_ip_id", nat_ip_id)

    @property
    @pulumi.getter(name="natIpAddress")
    def nat_ip_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转Ip地址。
        """
        return pulumi.get(self, "nat_ip_address")

    @nat_ip_address.setter
    def nat_ip_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip_address", value)

    @property
    @pulumi.getter(name="natIpId")
    def nat_ip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转Ip id。
        """
        return pulumi.get(self, "nat_ip_id")

    @nat_ip_id.setter
    def nat_ip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip_id", value)


if not MYPY:
    class NgwTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        用户标签的标签键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        用户标签的标签值。
        """
elif False:
    NgwTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NgwTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 用户标签的标签键。
        :param pulumi.Input[builtins.str] value: 用户标签的标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


