# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstanceCapacityInfo',
    'InstanceTag',
    'GetInstanceCapacityInfoResult',
    'GetInstanceTagResult',
]

@pulumi.output_type
class InstanceCapacityInfo(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "totalTiB":
            suggest = "total_ti_b"
        elif key == "usedGiB":
            suggest = "used_gi_b"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceCapacityInfo. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceCapacityInfo.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceCapacityInfo.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 total_ti_b: Optional[builtins.int] = None,
                 used_gi_b: Optional[builtins.int] = None):
        """
        :param builtins.int total_ti_b: 文件系统总容量，单位为 TiB。注意：磁盘均衡耗时会根据集群容量、集群负载等因素有所不同，如 PiB 级以上的集群扩容通常需要天级别的磁盘均衡时间，磁盘均衡完成后扩容容量才会生效（并为扩容容量计费）。
        :param builtins.int used_gi_b: 已使用容量（GiB）。
        """
        if total_ti_b is not None:
            pulumi.set(__self__, "total_ti_b", total_ti_b)
        if used_gi_b is not None:
            pulumi.set(__self__, "used_gi_b", used_gi_b)

    @property
    @pulumi.getter(name="totalTiB")
    def total_ti_b(self) -> Optional[builtins.int]:
        """
        文件系统总容量，单位为 TiB。注意：磁盘均衡耗时会根据集群容量、集群负载等因素有所不同，如 PiB 级以上的集群扩容通常需要天级别的磁盘均衡时间，磁盘均衡完成后扩容容量才会生效（并为扩容容量计费）。
        """
        return pulumi.get(self, "total_ti_b")

    @property
    @pulumi.getter(name="usedGiB")
    def used_gi_b(self) -> Optional[builtins.int]:
        """
        已使用容量（GiB）。
        """
        return pulumi.get(self, "used_gi_b")


@pulumi.output_type
class InstanceTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 用户标签的标签键。
        :param builtins.str value: 用户标签的标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetInstanceCapacityInfoResult(dict):
    def __init__(__self__, *,
                 total_ti_b: builtins.int,
                 used_gi_b: builtins.int):
        """
        :param builtins.int total_ti_b: 文件系统总容量，单位为 TiB。注意：磁盘均衡耗时会根据集群容量、集群负载等因素有所不同，如 PiB 级以上的集群扩容通常需要天级别的磁盘均衡时间，磁盘均衡完成后扩容容量才会生效（并为扩容容量计费）。
        :param builtins.int used_gi_b: 已使用容量（GiB）。
        """
        pulumi.set(__self__, "total_ti_b", total_ti_b)
        pulumi.set(__self__, "used_gi_b", used_gi_b)

    @property
    @pulumi.getter(name="totalTiB")
    def total_ti_b(self) -> builtins.int:
        """
        文件系统总容量，单位为 TiB。注意：磁盘均衡耗时会根据集群容量、集群负载等因素有所不同，如 PiB 级以上的集群扩容通常需要天级别的磁盘均衡时间，磁盘均衡完成后扩容容量才会生效（并为扩容容量计费）。
        """
        return pulumi.get(self, "total_ti_b")

    @property
    @pulumi.getter(name="usedGiB")
    def used_gi_b(self) -> builtins.int:
        """
        已使用容量（GiB）。
        """
        return pulumi.get(self, "used_gi_b")


@pulumi.output_type
class GetInstanceTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 type: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 用户标签的标签键。
        :param builtins.str type: 标签类型，说明如下：Custom: 用户自定义标签。System: 系统标签。
        :param builtins.str value: 用户标签的标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        标签类型，说明如下：Custom: 用户自定义标签。System: 系统标签。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")


