# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetNatIpResult',
    'AwaitableGetNatIpResult',
    'get_nat_ip',
    'get_nat_ip_output',
]

@pulumi.output_type
class GetNatIpResult:
    """
    A collection of values returned by getNatIp.
    """
    def __init__(__self__, id=None, is_default=None, nat_gateway_id=None, nat_ip=None, nat_ip_description=None, nat_ip_id=None, nat_ip_name=None, status=None, using_status=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_default and not isinstance(is_default, bool):
            raise TypeError("Expected argument 'is_default' to be a bool")
        pulumi.set(__self__, "is_default", is_default)
        if nat_gateway_id and not isinstance(nat_gateway_id, str):
            raise TypeError("Expected argument 'nat_gateway_id' to be a str")
        pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if nat_ip and not isinstance(nat_ip, str):
            raise TypeError("Expected argument 'nat_ip' to be a str")
        pulumi.set(__self__, "nat_ip", nat_ip)
        if nat_ip_description and not isinstance(nat_ip_description, str):
            raise TypeError("Expected argument 'nat_ip_description' to be a str")
        pulumi.set(__self__, "nat_ip_description", nat_ip_description)
        if nat_ip_id and not isinstance(nat_ip_id, str):
            raise TypeError("Expected argument 'nat_ip_id' to be a str")
        pulumi.set(__self__, "nat_ip_id", nat_ip_id)
        if nat_ip_name and not isinstance(nat_ip_name, str):
            raise TypeError("Expected argument 'nat_ip_name' to be a str")
        pulumi.set(__self__, "nat_ip_name", nat_ip_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if using_status and not isinstance(using_status, str):
            raise TypeError("Expected argument 'using_status' to be a str")
        pulumi.set(__self__, "using_status", using_status)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> builtins.bool:
        """
        是否为默认中转IP。true：是。false：否。
        """
        return pulumi.get(self, "is_default")

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> builtins.str:
        """
        私网NAT网关ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @property
    @pulumi.getter(name="natIp")
    def nat_ip(self) -> builtins.str:
        """
        中转IP的地址。若不填，则系统自动从私网NAT网关所在子网随机分配一个空闲的IP地址。
        """
        return pulumi.get(self, "nat_ip")

    @property
    @pulumi.getter(name="natIpDescription")
    def nat_ip_description(self) -> builtins.str:
        """
        中转IP的描述。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "nat_ip_description")

    @property
    @pulumi.getter(name="natIpId")
    def nat_ip_id(self) -> builtins.str:
        """
        中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_id")

    @property
    @pulumi.getter(name="natIpName")
    def nat_ip_name(self) -> builtins.str:
        """
        中转IP的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。不填默认为中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        中转IP的状态。Creating：创建中。Available：可用。Deleting：删除中。Deleted：已删除。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="usingStatus")
    def using_status(self) -> builtins.str:
        """
        中转IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        return pulumi.get(self, "using_status")


class AwaitableGetNatIpResult(GetNatIpResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNatIpResult(
            id=self.id,
            is_default=self.is_default,
            nat_gateway_id=self.nat_gateway_id,
            nat_ip=self.nat_ip,
            nat_ip_description=self.nat_ip_description,
            nat_ip_id=self.nat_ip_id,
            nat_ip_name=self.nat_ip_name,
            status=self.status,
            using_status=self.using_status)


def get_nat_ip(id: Optional[builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNatIpResult:
    """
    Data Source schema for Byteplus::NatGateway::NatIp


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:natgateway/getNatIp:getNatIp', __args__, opts=opts, typ=GetNatIpResult).value

    return AwaitableGetNatIpResult(
        id=pulumi.get(__ret__, 'id'),
        is_default=pulumi.get(__ret__, 'is_default'),
        nat_gateway_id=pulumi.get(__ret__, 'nat_gateway_id'),
        nat_ip=pulumi.get(__ret__, 'nat_ip'),
        nat_ip_description=pulumi.get(__ret__, 'nat_ip_description'),
        nat_ip_id=pulumi.get(__ret__, 'nat_ip_id'),
        nat_ip_name=pulumi.get(__ret__, 'nat_ip_name'),
        status=pulumi.get(__ret__, 'status'),
        using_status=pulumi.get(__ret__, 'using_status'))
def get_nat_ip_output(id: Optional[pulumi.Input[builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNatIpResult]:
    """
    Data Source schema for Byteplus::NatGateway::NatIp


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:natgateway/getNatIp:getNatIp', __args__, opts=opts, typ=GetNatIpResult)
    return __ret__.apply(lambda __response__: GetNatIpResult(
        id=pulumi.get(__response__, 'id'),
        is_default=pulumi.get(__response__, 'is_default'),
        nat_gateway_id=pulumi.get(__response__, 'nat_gateway_id'),
        nat_ip=pulumi.get(__response__, 'nat_ip'),
        nat_ip_description=pulumi.get(__response__, 'nat_ip_description'),
        nat_ip_id=pulumi.get(__response__, 'nat_ip_id'),
        nat_ip_name=pulumi.get(__response__, 'nat_ip_name'),
        status=pulumi.get(__response__, 'status'),
        using_status=pulumi.get(__response__, 'using_status')))
