# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ClusterArgs', 'Cluster']

@pulumi.input_type
class ClusterArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[builtins.str],
                 cluster_config: Optional[pulumi.Input['ClusterClusterConfigArgs']] = None,
                 delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_version: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_version_create: Optional[pulumi.Input[builtins.str]] = None,
                 logging_config: Optional[pulumi.Input['ClusterLoggingConfigArgs']] = None,
                 monitoring_config: Optional[pulumi.Input['ClusterMonitoringConfigArgs']] = None,
                 pods_config: Optional[pulumi.Input['ClusterPodsConfigArgs']] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 services_config: Optional[pulumi.Input['ClusterServicesConfigArgs']] = None,
                 source_region: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterTagArgs']]]] = None):
        """
        The set of arguments for constructing a Cluster resource.
        :param pulumi.Input[builtins.str] name: 集群名称。同一个地域下，名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        :param pulumi.Input['ClusterClusterConfigArgs'] cluster_config: 集群控制面及部分节点的网络配置。
        :param pulumi.Input[builtins.bool] delete_protection_enabled: 集群删除保护，取值：false：（默认值）关闭删除保护。true：开启删除保护，不允许直接删除集群。
        :param pulumi.Input[builtins.str] description: 集群描述。长度限制为 300 个字符以内。
        :param pulumi.Input[builtins.str] kubernetes_version: 集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。（查询使用）
        :param pulumi.Input[builtins.str] kubernetes_version_create: 集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。(创建使用)
        :param pulumi.Input['ClusterLoggingConfigArgs'] logging_config: 集群的日志配置信息。
        :param pulumi.Input['ClusterMonitoringConfigArgs'] monitoring_config: 监控配置信息。
        :param pulumi.Input['ClusterPodsConfigArgs'] pods_config: Pod 的网络配置。
        :param pulumi.Input[builtins.str] project_name: 集群所属项目名称，一个集群只能归属于一个项目。只能包含英文字母、数字、下划线（_）、英文句点（.）和中划线（-）。长度限制在 64 个字符以内。默认值：default。
        :param pulumi.Input['ClusterServicesConfigArgs'] services_config: 服务的网络配置。
        :param pulumi.Input[builtins.str] source_region: 集群源地域。
        """
        pulumi.set(__self__, "name", name)
        if cluster_config is not None:
            pulumi.set(__self__, "cluster_config", cluster_config)
        if delete_protection_enabled is not None:
            pulumi.set(__self__, "delete_protection_enabled", delete_protection_enabled)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if kubernetes_version is not None:
            pulumi.set(__self__, "kubernetes_version", kubernetes_version)
        if kubernetes_version_create is not None:
            pulumi.set(__self__, "kubernetes_version_create", kubernetes_version_create)
        if logging_config is not None:
            pulumi.set(__self__, "logging_config", logging_config)
        if monitoring_config is not None:
            pulumi.set(__self__, "monitoring_config", monitoring_config)
        if pods_config is not None:
            pulumi.set(__self__, "pods_config", pods_config)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if services_config is not None:
            pulumi.set(__self__, "services_config", services_config)
        if source_region is not None:
            pulumi.set(__self__, "source_region", source_region)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        集群名称。同一个地域下，名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="clusterConfig")
    def cluster_config(self) -> Optional[pulumi.Input['ClusterClusterConfigArgs']]:
        """
        集群控制面及部分节点的网络配置。
        """
        return pulumi.get(self, "cluster_config")

    @cluster_config.setter
    def cluster_config(self, value: Optional[pulumi.Input['ClusterClusterConfigArgs']]):
        pulumi.set(self, "cluster_config", value)

    @property
    @pulumi.getter(name="deleteProtectionEnabled")
    def delete_protection_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        集群删除保护，取值：false：（默认值）关闭删除保护。true：开启删除保护，不允许直接删除集群。
        """
        return pulumi.get(self, "delete_protection_enabled")

    @delete_protection_enabled.setter
    def delete_protection_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "delete_protection_enabled", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群描述。长度限制为 300 个字符以内。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="kubernetesVersion")
    def kubernetes_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。（查询使用）
        """
        return pulumi.get(self, "kubernetes_version")

    @kubernetes_version.setter
    def kubernetes_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kubernetes_version", value)

    @property
    @pulumi.getter(name="kubernetesVersionCreate")
    def kubernetes_version_create(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。(创建使用)
        """
        return pulumi.get(self, "kubernetes_version_create")

    @kubernetes_version_create.setter
    def kubernetes_version_create(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kubernetes_version_create", value)

    @property
    @pulumi.getter(name="loggingConfig")
    def logging_config(self) -> Optional[pulumi.Input['ClusterLoggingConfigArgs']]:
        """
        集群的日志配置信息。
        """
        return pulumi.get(self, "logging_config")

    @logging_config.setter
    def logging_config(self, value: Optional[pulumi.Input['ClusterLoggingConfigArgs']]):
        pulumi.set(self, "logging_config", value)

    @property
    @pulumi.getter(name="monitoringConfig")
    def monitoring_config(self) -> Optional[pulumi.Input['ClusterMonitoringConfigArgs']]:
        """
        监控配置信息。
        """
        return pulumi.get(self, "monitoring_config")

    @monitoring_config.setter
    def monitoring_config(self, value: Optional[pulumi.Input['ClusterMonitoringConfigArgs']]):
        pulumi.set(self, "monitoring_config", value)

    @property
    @pulumi.getter(name="podsConfig")
    def pods_config(self) -> Optional[pulumi.Input['ClusterPodsConfigArgs']]:
        """
        Pod 的网络配置。
        """
        return pulumi.get(self, "pods_config")

    @pods_config.setter
    def pods_config(self, value: Optional[pulumi.Input['ClusterPodsConfigArgs']]):
        pulumi.set(self, "pods_config", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群所属项目名称，一个集群只能归属于一个项目。只能包含英文字母、数字、下划线（_）、英文句点（.）和中划线（-）。长度限制在 64 个字符以内。默认值：default。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="servicesConfig")
    def services_config(self) -> Optional[pulumi.Input['ClusterServicesConfigArgs']]:
        """
        服务的网络配置。
        """
        return pulumi.get(self, "services_config")

    @services_config.setter
    def services_config(self, value: Optional[pulumi.Input['ClusterServicesConfigArgs']]):
        pulumi.set(self, "services_config", value)

    @property
    @pulumi.getter(name="sourceRegion")
    def source_region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群源地域。
        """
        return pulumi.get(self, "source_region")

    @source_region.setter
    def source_region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_region", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ClusterState:
    def __init__(__self__, *,
                 cluster_config: Optional[pulumi.Input['ClusterClusterConfigArgs']] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_version: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_version_create: Optional[pulumi.Input[builtins.str]] = None,
                 logging_config: Optional[pulumi.Input['ClusterLoggingConfigArgs']] = None,
                 message: Optional[pulumi.Input[builtins.str]] = None,
                 monitoring_config: Optional[pulumi.Input['ClusterMonitoringConfigArgs']] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 node_statistics: Optional[pulumi.Input['ClusterNodeStatisticsArgs']] = None,
                 pods_config: Optional[pulumi.Input['ClusterPodsConfigArgs']] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 services_config: Optional[pulumi.Input['ClusterServicesConfigArgs']] = None,
                 source_region: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input['ClusterStatusArgs']] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterTagArgs']]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Cluster resources.
        :param pulumi.Input['ClusterClusterConfigArgs'] cluster_config: 集群控制面及部分节点的网络配置。
        :param pulumi.Input[builtins.str] cluster_id: 集群 ID。
        :param pulumi.Input[builtins.str] created_time: 集群创建时间。标准 RFC3339 格式的 UTC+0 时间。
        :param pulumi.Input[builtins.bool] delete_protection_enabled: 集群删除保护，取值：false：（默认值）关闭删除保护。true：开启删除保护，不允许直接删除集群。
        :param pulumi.Input[builtins.str] description: 集群描述。长度限制为 300 个字符以内。
        :param pulumi.Input[builtins.str] kubernetes_version: 集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。（查询使用）
        :param pulumi.Input[builtins.str] kubernetes_version_create: 集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。(创建使用)
        :param pulumi.Input['ClusterLoggingConfigArgs'] logging_config: 集群的日志配置信息。
        :param pulumi.Input[builtins.str] message: 集群状态描述。
        :param pulumi.Input['ClusterMonitoringConfigArgs'] monitoring_config: 监控配置信息。
        :param pulumi.Input[builtins.str] name: 集群名称。同一个地域下，名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        :param pulumi.Input['ClusterNodeStatisticsArgs'] node_statistics: 集群中各主状态下对应的节点数量统计。
        :param pulumi.Input['ClusterPodsConfigArgs'] pods_config: Pod 的网络配置。
        :param pulumi.Input[builtins.str] project_name: 集群所属项目名称，一个集群只能归属于一个项目。只能包含英文字母、数字、下划线（_）、英文句点（.）和中划线（-）。长度限制在 64 个字符以内。默认值：default。
        :param pulumi.Input['ClusterServicesConfigArgs'] services_config: 服务的网络配置。
        :param pulumi.Input[builtins.str] source_region: 集群源地域。
        :param pulumi.Input['ClusterStatusArgs'] status: 集群状态。
        :param pulumi.Input[builtins.str] type: 集群类型。
        :param pulumi.Input[builtins.str] updated_time: 集群最近一次更新的时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        if cluster_config is not None:
            pulumi.set(__self__, "cluster_config", cluster_config)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if delete_protection_enabled is not None:
            pulumi.set(__self__, "delete_protection_enabled", delete_protection_enabled)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if kubernetes_version is not None:
            pulumi.set(__self__, "kubernetes_version", kubernetes_version)
        if kubernetes_version_create is not None:
            pulumi.set(__self__, "kubernetes_version_create", kubernetes_version_create)
        if logging_config is not None:
            pulumi.set(__self__, "logging_config", logging_config)
        if message is not None:
            pulumi.set(__self__, "message", message)
        if monitoring_config is not None:
            pulumi.set(__self__, "monitoring_config", monitoring_config)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_statistics is not None:
            pulumi.set(__self__, "node_statistics", node_statistics)
        if pods_config is not None:
            pulumi.set(__self__, "pods_config", pods_config)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if services_config is not None:
            pulumi.set(__self__, "services_config", services_config)
        if source_region is not None:
            pulumi.set(__self__, "source_region", source_region)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="clusterConfig")
    def cluster_config(self) -> Optional[pulumi.Input['ClusterClusterConfigArgs']]:
        """
        集群控制面及部分节点的网络配置。
        """
        return pulumi.get(self, "cluster_config")

    @cluster_config.setter
    def cluster_config(self, value: Optional[pulumi.Input['ClusterClusterConfigArgs']]):
        pulumi.set(self, "cluster_config", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群 ID。
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群创建时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="deleteProtectionEnabled")
    def delete_protection_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        集群删除保护，取值：false：（默认值）关闭删除保护。true：开启删除保护，不允许直接删除集群。
        """
        return pulumi.get(self, "delete_protection_enabled")

    @delete_protection_enabled.setter
    def delete_protection_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "delete_protection_enabled", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群描述。长度限制为 300 个字符以内。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="kubernetesVersion")
    def kubernetes_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。（查询使用）
        """
        return pulumi.get(self, "kubernetes_version")

    @kubernetes_version.setter
    def kubernetes_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kubernetes_version", value)

    @property
    @pulumi.getter(name="kubernetesVersionCreate")
    def kubernetes_version_create(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。(创建使用)
        """
        return pulumi.get(self, "kubernetes_version_create")

    @kubernetes_version_create.setter
    def kubernetes_version_create(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kubernetes_version_create", value)

    @property
    @pulumi.getter(name="loggingConfig")
    def logging_config(self) -> Optional[pulumi.Input['ClusterLoggingConfigArgs']]:
        """
        集群的日志配置信息。
        """
        return pulumi.get(self, "logging_config")

    @logging_config.setter
    def logging_config(self, value: Optional[pulumi.Input['ClusterLoggingConfigArgs']]):
        pulumi.set(self, "logging_config", value)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群状态描述。
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter(name="monitoringConfig")
    def monitoring_config(self) -> Optional[pulumi.Input['ClusterMonitoringConfigArgs']]:
        """
        监控配置信息。
        """
        return pulumi.get(self, "monitoring_config")

    @monitoring_config.setter
    def monitoring_config(self, value: Optional[pulumi.Input['ClusterMonitoringConfigArgs']]):
        pulumi.set(self, "monitoring_config", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群名称。同一个地域下，名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nodeStatistics")
    def node_statistics(self) -> Optional[pulumi.Input['ClusterNodeStatisticsArgs']]:
        """
        集群中各主状态下对应的节点数量统计。
        """
        return pulumi.get(self, "node_statistics")

    @node_statistics.setter
    def node_statistics(self, value: Optional[pulumi.Input['ClusterNodeStatisticsArgs']]):
        pulumi.set(self, "node_statistics", value)

    @property
    @pulumi.getter(name="podsConfig")
    def pods_config(self) -> Optional[pulumi.Input['ClusterPodsConfigArgs']]:
        """
        Pod 的网络配置。
        """
        return pulumi.get(self, "pods_config")

    @pods_config.setter
    def pods_config(self, value: Optional[pulumi.Input['ClusterPodsConfigArgs']]):
        pulumi.set(self, "pods_config", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群所属项目名称，一个集群只能归属于一个项目。只能包含英文字母、数字、下划线（_）、英文句点（.）和中划线（-）。长度限制在 64 个字符以内。默认值：default。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="servicesConfig")
    def services_config(self) -> Optional[pulumi.Input['ClusterServicesConfigArgs']]:
        """
        服务的网络配置。
        """
        return pulumi.get(self, "services_config")

    @services_config.setter
    def services_config(self, value: Optional[pulumi.Input['ClusterServicesConfigArgs']]):
        pulumi.set(self, "services_config", value)

    @property
    @pulumi.getter(name="sourceRegion")
    def source_region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群源地域。
        """
        return pulumi.get(self, "source_region")

    @source_region.setter
    def source_region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_region", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input['ClusterStatusArgs']]:
        """
        集群状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input['ClusterStatusArgs']]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群类型。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群最近一次更新的时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:vke/cluster:Cluster")
class Cluster(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_config: Optional[pulumi.Input[Union['ClusterClusterConfigArgs', 'ClusterClusterConfigArgsDict']]] = None,
                 delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_version: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_version_create: Optional[pulumi.Input[builtins.str]] = None,
                 logging_config: Optional[pulumi.Input[Union['ClusterLoggingConfigArgs', 'ClusterLoggingConfigArgsDict']]] = None,
                 monitoring_config: Optional[pulumi.Input[Union['ClusterMonitoringConfigArgs', 'ClusterMonitoringConfigArgsDict']]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 pods_config: Optional[pulumi.Input[Union['ClusterPodsConfigArgs', 'ClusterPodsConfigArgsDict']]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 services_config: Optional[pulumi.Input[Union['ClusterServicesConfigArgs', 'ClusterServicesConfigArgsDict']]] = None,
                 source_region: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ClusterTagArgs', 'ClusterTagArgsDict']]]]] = None,
                 __props__=None):
        """
        容器服务通过深度融合新一代云原生技术，提供以容器为核心的高性能 Kubernetes 容器集群管理服务。在云端一键构建高可用 Kubernetes 集群，并实现容器化应用的可视化全生命周期管理，助力用户快速构建容器化应用。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vke/cluster:Cluster example "cluster_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ClusterClusterConfigArgs', 'ClusterClusterConfigArgsDict']] cluster_config: 集群控制面及部分节点的网络配置。
        :param pulumi.Input[builtins.bool] delete_protection_enabled: 集群删除保护，取值：false：（默认值）关闭删除保护。true：开启删除保护，不允许直接删除集群。
        :param pulumi.Input[builtins.str] description: 集群描述。长度限制为 300 个字符以内。
        :param pulumi.Input[builtins.str] kubernetes_version: 集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。（查询使用）
        :param pulumi.Input[builtins.str] kubernetes_version_create: 集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。(创建使用)
        :param pulumi.Input[Union['ClusterLoggingConfigArgs', 'ClusterLoggingConfigArgsDict']] logging_config: 集群的日志配置信息。
        :param pulumi.Input[Union['ClusterMonitoringConfigArgs', 'ClusterMonitoringConfigArgsDict']] monitoring_config: 监控配置信息。
        :param pulumi.Input[builtins.str] name: 集群名称。同一个地域下，名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        :param pulumi.Input[Union['ClusterPodsConfigArgs', 'ClusterPodsConfigArgsDict']] pods_config: Pod 的网络配置。
        :param pulumi.Input[builtins.str] project_name: 集群所属项目名称，一个集群只能归属于一个项目。只能包含英文字母、数字、下划线（_）、英文句点（.）和中划线（-）。长度限制在 64 个字符以内。默认值：default。
        :param pulumi.Input[Union['ClusterServicesConfigArgs', 'ClusterServicesConfigArgsDict']] services_config: 服务的网络配置。
        :param pulumi.Input[builtins.str] source_region: 集群源地域。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClusterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        容器服务通过深度融合新一代云原生技术，提供以容器为核心的高性能 Kubernetes 容器集群管理服务。在云端一键构建高可用 Kubernetes 集群，并实现容器化应用的可视化全生命周期管理，助力用户快速构建容器化应用。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vke/cluster:Cluster example "cluster_id"
        ```

        :param str resource_name: The name of the resource.
        :param ClusterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClusterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_config: Optional[pulumi.Input[Union['ClusterClusterConfigArgs', 'ClusterClusterConfigArgsDict']]] = None,
                 delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_version: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_version_create: Optional[pulumi.Input[builtins.str]] = None,
                 logging_config: Optional[pulumi.Input[Union['ClusterLoggingConfigArgs', 'ClusterLoggingConfigArgsDict']]] = None,
                 monitoring_config: Optional[pulumi.Input[Union['ClusterMonitoringConfigArgs', 'ClusterMonitoringConfigArgsDict']]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 pods_config: Optional[pulumi.Input[Union['ClusterPodsConfigArgs', 'ClusterPodsConfigArgsDict']]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 services_config: Optional[pulumi.Input[Union['ClusterServicesConfigArgs', 'ClusterServicesConfigArgsDict']]] = None,
                 source_region: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ClusterTagArgs', 'ClusterTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClusterArgs.__new__(ClusterArgs)

            __props__.__dict__["cluster_config"] = cluster_config
            __props__.__dict__["delete_protection_enabled"] = delete_protection_enabled
            __props__.__dict__["description"] = description
            __props__.__dict__["kubernetes_version"] = kubernetes_version
            __props__.__dict__["kubernetes_version_create"] = kubernetes_version_create
            __props__.__dict__["logging_config"] = logging_config
            __props__.__dict__["monitoring_config"] = monitoring_config
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["pods_config"] = pods_config
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["services_config"] = services_config
            __props__.__dict__["source_region"] = source_region
            __props__.__dict__["tags"] = tags
            __props__.__dict__["cluster_id"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["message"] = None
            __props__.__dict__["node_statistics"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["type"] = None
            __props__.__dict__["updated_time"] = None
        super(Cluster, __self__).__init__(
            'bytepluscc:vke/cluster:Cluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_config: Optional[pulumi.Input[Union['ClusterClusterConfigArgs', 'ClusterClusterConfigArgsDict']]] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            kubernetes_version: Optional[pulumi.Input[builtins.str]] = None,
            kubernetes_version_create: Optional[pulumi.Input[builtins.str]] = None,
            logging_config: Optional[pulumi.Input[Union['ClusterLoggingConfigArgs', 'ClusterLoggingConfigArgsDict']]] = None,
            message: Optional[pulumi.Input[builtins.str]] = None,
            monitoring_config: Optional[pulumi.Input[Union['ClusterMonitoringConfigArgs', 'ClusterMonitoringConfigArgsDict']]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            node_statistics: Optional[pulumi.Input[Union['ClusterNodeStatisticsArgs', 'ClusterNodeStatisticsArgsDict']]] = None,
            pods_config: Optional[pulumi.Input[Union['ClusterPodsConfigArgs', 'ClusterPodsConfigArgsDict']]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            services_config: Optional[pulumi.Input[Union['ClusterServicesConfigArgs', 'ClusterServicesConfigArgsDict']]] = None,
            source_region: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[Union['ClusterStatusArgs', 'ClusterStatusArgsDict']]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ClusterTagArgs', 'ClusterTagArgsDict']]]]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'Cluster':
        """
        Get an existing Cluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ClusterClusterConfigArgs', 'ClusterClusterConfigArgsDict']] cluster_config: 集群控制面及部分节点的网络配置。
        :param pulumi.Input[builtins.str] cluster_id: 集群 ID。
        :param pulumi.Input[builtins.str] created_time: 集群创建时间。标准 RFC3339 格式的 UTC+0 时间。
        :param pulumi.Input[builtins.bool] delete_protection_enabled: 集群删除保护，取值：false：（默认值）关闭删除保护。true：开启删除保护，不允许直接删除集群。
        :param pulumi.Input[builtins.str] description: 集群描述。长度限制为 300 个字符以内。
        :param pulumi.Input[builtins.str] kubernetes_version: 集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。（查询使用）
        :param pulumi.Input[builtins.str] kubernetes_version_create: 集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。(创建使用)
        :param pulumi.Input[Union['ClusterLoggingConfigArgs', 'ClusterLoggingConfigArgsDict']] logging_config: 集群的日志配置信息。
        :param pulumi.Input[builtins.str] message: 集群状态描述。
        :param pulumi.Input[Union['ClusterMonitoringConfigArgs', 'ClusterMonitoringConfigArgsDict']] monitoring_config: 监控配置信息。
        :param pulumi.Input[builtins.str] name: 集群名称。同一个地域下，名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        :param pulumi.Input[Union['ClusterNodeStatisticsArgs', 'ClusterNodeStatisticsArgsDict']] node_statistics: 集群中各主状态下对应的节点数量统计。
        :param pulumi.Input[Union['ClusterPodsConfigArgs', 'ClusterPodsConfigArgsDict']] pods_config: Pod 的网络配置。
        :param pulumi.Input[builtins.str] project_name: 集群所属项目名称，一个集群只能归属于一个项目。只能包含英文字母、数字、下划线（_）、英文句点（.）和中划线（-）。长度限制在 64 个字符以内。默认值：default。
        :param pulumi.Input[Union['ClusterServicesConfigArgs', 'ClusterServicesConfigArgsDict']] services_config: 服务的网络配置。
        :param pulumi.Input[builtins.str] source_region: 集群源地域。
        :param pulumi.Input[Union['ClusterStatusArgs', 'ClusterStatusArgsDict']] status: 集群状态。
        :param pulumi.Input[builtins.str] type: 集群类型。
        :param pulumi.Input[builtins.str] updated_time: 集群最近一次更新的时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClusterState.__new__(_ClusterState)

        __props__.__dict__["cluster_config"] = cluster_config
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["delete_protection_enabled"] = delete_protection_enabled
        __props__.__dict__["description"] = description
        __props__.__dict__["kubernetes_version"] = kubernetes_version
        __props__.__dict__["kubernetes_version_create"] = kubernetes_version_create
        __props__.__dict__["logging_config"] = logging_config
        __props__.__dict__["message"] = message
        __props__.__dict__["monitoring_config"] = monitoring_config
        __props__.__dict__["name"] = name
        __props__.__dict__["node_statistics"] = node_statistics
        __props__.__dict__["pods_config"] = pods_config
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["services_config"] = services_config
        __props__.__dict__["source_region"] = source_region
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["type"] = type
        __props__.__dict__["updated_time"] = updated_time
        return Cluster(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterConfig")
    def cluster_config(self) -> pulumi.Output['outputs.ClusterClusterConfig']:
        """
        集群控制面及部分节点的网络配置。
        """
        return pulumi.get(self, "cluster_config")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        集群 ID。
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        集群创建时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="deleteProtectionEnabled")
    def delete_protection_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        集群删除保护，取值：false：（默认值）关闭删除保护。true：开启删除保护，不允许直接删除集群。
        """
        return pulumi.get(self, "delete_protection_enabled")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        集群描述。长度限制为 300 个字符以内。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="kubernetesVersion")
    def kubernetes_version(self) -> pulumi.Output[builtins.str]:
        """
        集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。（查询使用）
        """
        return pulumi.get(self, "kubernetes_version")

    @property
    @pulumi.getter(name="kubernetesVersionCreate")
    def kubernetes_version_create(self) -> pulumi.Output[builtins.str]:
        """
        集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。(创建使用)
        """
        return pulumi.get(self, "kubernetes_version_create")

    @property
    @pulumi.getter(name="loggingConfig")
    def logging_config(self) -> pulumi.Output['outputs.ClusterLoggingConfig']:
        """
        集群的日志配置信息。
        """
        return pulumi.get(self, "logging_config")

    @property
    @pulumi.getter
    def message(self) -> pulumi.Output[builtins.str]:
        """
        集群状态描述。
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter(name="monitoringConfig")
    def monitoring_config(self) -> pulumi.Output['outputs.ClusterMonitoringConfig']:
        """
        监控配置信息。
        """
        return pulumi.get(self, "monitoring_config")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        集群名称。同一个地域下，名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nodeStatistics")
    def node_statistics(self) -> pulumi.Output['outputs.ClusterNodeStatistics']:
        """
        集群中各主状态下对应的节点数量统计。
        """
        return pulumi.get(self, "node_statistics")

    @property
    @pulumi.getter(name="podsConfig")
    def pods_config(self) -> pulumi.Output['outputs.ClusterPodsConfig']:
        """
        Pod 的网络配置。
        """
        return pulumi.get(self, "pods_config")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        集群所属项目名称，一个集群只能归属于一个项目。只能包含英文字母、数字、下划线（_）、英文句点（.）和中划线（-）。长度限制在 64 个字符以内。默认值：default。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="servicesConfig")
    def services_config(self) -> pulumi.Output['outputs.ClusterServicesConfig']:
        """
        服务的网络配置。
        """
        return pulumi.get(self, "services_config")

    @property
    @pulumi.getter(name="sourceRegion")
    def source_region(self) -> pulumi.Output[builtins.str]:
        """
        集群源地域。
        """
        return pulumi.get(self, "source_region")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output['outputs.ClusterStatus']:
        """
        集群状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.ClusterTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        集群类型。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        集群最近一次更新的时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "updated_time")

