# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .provider import *
from ._inputs import *

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_bytepluscc.alb as __alb
    alb = __alb
    import pulumi_bytepluscc.apig as __apig
    apig = __apig
    import pulumi_bytepluscc.autoscaling as __autoscaling
    autoscaling = __autoscaling
    import pulumi_bytepluscc.bmq as __bmq
    bmq = __bmq
    import pulumi_bytepluscc.cdn as __cdn
    cdn = __cdn
    import pulumi_bytepluscc.cen as __cen
    cen = __cen
    import pulumi_bytepluscc.clb as __clb
    clb = __clb
    import pulumi_bytepluscc.cloudidentity as __cloudidentity
    cloudidentity = __cloudidentity
    import pulumi_bytepluscc.config as __config
    config = __config
    import pulumi_bytepluscc.cr as __cr
    cr = __cr
    import pulumi_bytepluscc.dns as __dns
    dns = __dns
    import pulumi_bytepluscc.ecs as __ecs
    ecs = __ecs
    import pulumi_bytepluscc.escloud as __escloud
    escloud = __escloud
    import pulumi_bytepluscc.firewallcenter as __firewallcenter
    firewallcenter = __firewallcenter
    import pulumi_bytepluscc.hbase as __hbase
    hbase = __hbase
    import pulumi_bytepluscc.iam as __iam
    iam = __iam
    import pulumi_bytepluscc.kafka as __kafka
    kafka = __kafka
    import pulumi_bytepluscc.kms as __kms
    kms = __kms
    import pulumi_bytepluscc.natgateway as __natgateway
    natgateway = __natgateway
    import pulumi_bytepluscc.organization as __organization
    organization = __organization
    import pulumi_bytepluscc.privatelink as __privatelink
    privatelink = __privatelink
    import pulumi_bytepluscc.rdsmysql as __rdsmysql
    rdsmysql = __rdsmysql
    import pulumi_bytepluscc.redis as __redis
    redis = __redis
    import pulumi_bytepluscc.storageebs as __storageebs
    storageebs = __storageebs
    import pulumi_bytepluscc.vefaas as __vefaas
    vefaas = __vefaas
    import pulumi_bytepluscc.vepfs as __vepfs
    vepfs = __vepfs
    import pulumi_bytepluscc.vke as __vke
    vke = __vke
    import pulumi_bytepluscc.vpc as __vpc
    vpc = __vpc
else:
    alb = _utilities.lazy_import('pulumi_bytepluscc.alb')
    apig = _utilities.lazy_import('pulumi_bytepluscc.apig')
    autoscaling = _utilities.lazy_import('pulumi_bytepluscc.autoscaling')
    bmq = _utilities.lazy_import('pulumi_bytepluscc.bmq')
    cdn = _utilities.lazy_import('pulumi_bytepluscc.cdn')
    cen = _utilities.lazy_import('pulumi_bytepluscc.cen')
    clb = _utilities.lazy_import('pulumi_bytepluscc.clb')
    cloudidentity = _utilities.lazy_import('pulumi_bytepluscc.cloudidentity')
    config = _utilities.lazy_import('pulumi_bytepluscc.config')
    cr = _utilities.lazy_import('pulumi_bytepluscc.cr')
    dns = _utilities.lazy_import('pulumi_bytepluscc.dns')
    ecs = _utilities.lazy_import('pulumi_bytepluscc.ecs')
    escloud = _utilities.lazy_import('pulumi_bytepluscc.escloud')
    firewallcenter = _utilities.lazy_import('pulumi_bytepluscc.firewallcenter')
    hbase = _utilities.lazy_import('pulumi_bytepluscc.hbase')
    iam = _utilities.lazy_import('pulumi_bytepluscc.iam')
    kafka = _utilities.lazy_import('pulumi_bytepluscc.kafka')
    kms = _utilities.lazy_import('pulumi_bytepluscc.kms')
    natgateway = _utilities.lazy_import('pulumi_bytepluscc.natgateway')
    organization = _utilities.lazy_import('pulumi_bytepluscc.organization')
    privatelink = _utilities.lazy_import('pulumi_bytepluscc.privatelink')
    rdsmysql = _utilities.lazy_import('pulumi_bytepluscc.rdsmysql')
    redis = _utilities.lazy_import('pulumi_bytepluscc.redis')
    storageebs = _utilities.lazy_import('pulumi_bytepluscc.storageebs')
    vefaas = _utilities.lazy_import('pulumi_bytepluscc.vefaas')
    vepfs = _utilities.lazy_import('pulumi_bytepluscc.vepfs')
    vke = _utilities.lazy_import('pulumi_bytepluscc.vke')
    vpc = _utilities.lazy_import('pulumi_bytepluscc.vpc')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "bytepluscc",
  "mod": "alb/certificate",
  "fqn": "pulumi_bytepluscc.alb",
  "classes": {
   "bytepluscc:alb/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "alb/listener",
  "fqn": "pulumi_bytepluscc.alb",
  "classes": {
   "bytepluscc:alb/listener:Listener": "Listener"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "apig/customDomain",
  "fqn": "pulumi_bytepluscc.apig",
  "classes": {
   "bytepluscc:apig/customDomain:CustomDomain": "CustomDomain"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "apig/gateway",
  "fqn": "pulumi_bytepluscc.apig",
  "classes": {
   "bytepluscc:apig/gateway:Gateway": "Gateway"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "apig/gatewayService",
  "fqn": "pulumi_bytepluscc.apig",
  "classes": {
   "bytepluscc:apig/gatewayService:GatewayService": "GatewayService"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "apig/upstream",
  "fqn": "pulumi_bytepluscc.apig",
  "classes": {
   "bytepluscc:apig/upstream:Upstream": "Upstream"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "apig/upstreamSource",
  "fqn": "pulumi_bytepluscc.apig",
  "classes": {
   "bytepluscc:apig/upstreamSource:UpstreamSource": "UpstreamSource"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "autoscaling/scalingConfiguration",
  "fqn": "pulumi_bytepluscc.autoscaling",
  "classes": {
   "bytepluscc:autoscaling/scalingConfiguration:ScalingConfiguration": "ScalingConfiguration"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "autoscaling/scalingGroup",
  "fqn": "pulumi_bytepluscc.autoscaling",
  "classes": {
   "bytepluscc:autoscaling/scalingGroup:ScalingGroup": "ScalingGroup"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "bmq/instance",
  "fqn": "pulumi_bytepluscc.bmq",
  "classes": {
   "bytepluscc:bmq/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "cdn/shareConfig",
  "fqn": "pulumi_bytepluscc.cdn",
  "classes": {
   "bytepluscc:cdn/shareConfig:ShareConfig": "ShareConfig"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "cen/cen",
  "fqn": "pulumi_bytepluscc.cen",
  "classes": {
   "bytepluscc:cen/cen:Cen": "Cen"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "clb/listener",
  "fqn": "pulumi_bytepluscc.clb",
  "classes": {
   "bytepluscc:clb/listener:Listener": "Listener"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "clb/rule",
  "fqn": "pulumi_bytepluscc.clb",
  "classes": {
   "bytepluscc:clb/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "cloudidentity/user",
  "fqn": "pulumi_bytepluscc.cloudidentity",
  "classes": {
   "bytepluscc:cloudidentity/user:User": "User"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "cr/repository",
  "fqn": "pulumi_bytepluscc.cr",
  "classes": {
   "bytepluscc:cr/repository:Repository": "Repository"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "dns/zone",
  "fqn": "pulumi_bytepluscc.dns",
  "classes": {
   "bytepluscc:dns/zone:Zone": "Zone"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "ecs/image",
  "fqn": "pulumi_bytepluscc.ecs",
  "classes": {
   "bytepluscc:ecs/image:Image": "Image"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "ecs/instance",
  "fqn": "pulumi_bytepluscc.ecs",
  "classes": {
   "bytepluscc:ecs/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "escloud/instance",
  "fqn": "pulumi_bytepluscc.escloud",
  "classes": {
   "bytepluscc:escloud/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "firewallcenter/dnsControlPolicy",
  "fqn": "pulumi_bytepluscc.firewallcenter",
  "classes": {
   "bytepluscc:firewallcenter/dnsControlPolicy:DnsControlPolicy": "DnsControlPolicy"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "hbase/instance",
  "fqn": "pulumi_bytepluscc.hbase",
  "classes": {
   "bytepluscc:hbase/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "iam/policy",
  "fqn": "pulumi_bytepluscc.iam",
  "classes": {
   "bytepluscc:iam/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "iam/project",
  "fqn": "pulumi_bytepluscc.iam",
  "classes": {
   "bytepluscc:iam/project:Project": "Project"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "iam/role",
  "fqn": "pulumi_bytepluscc.iam",
  "classes": {
   "bytepluscc:iam/role:Role": "Role"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "iam/user",
  "fqn": "pulumi_bytepluscc.iam",
  "classes": {
   "bytepluscc:iam/user:User": "User"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "kafka/topic",
  "fqn": "pulumi_bytepluscc.kafka",
  "classes": {
   "bytepluscc:kafka/topic:Topic": "Topic"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "kms/key",
  "fqn": "pulumi_bytepluscc.kms",
  "classes": {
   "bytepluscc:kms/key:Key": "Key"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "natgateway/dnatentry",
  "fqn": "pulumi_bytepluscc.natgateway",
  "classes": {
   "bytepluscc:natgateway/dnatentry:Dnatentry": "Dnatentry"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "natgateway/natIp",
  "fqn": "pulumi_bytepluscc.natgateway",
  "classes": {
   "bytepluscc:natgateway/natIp:NatIp": "NatIp"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "natgateway/ngw",
  "fqn": "pulumi_bytepluscc.natgateway",
  "classes": {
   "bytepluscc:natgateway/ngw:Ngw": "Ngw"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "natgateway/snatentry",
  "fqn": "pulumi_bytepluscc.natgateway",
  "classes": {
   "bytepluscc:natgateway/snatentry:Snatentry": "Snatentry"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "organization/unit",
  "fqn": "pulumi_bytepluscc.organization",
  "classes": {
   "bytepluscc:organization/unit:Unit": "Unit"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "privatelink/endpointService",
  "fqn": "pulumi_bytepluscc.privatelink",
  "classes": {
   "bytepluscc:privatelink/endpointService:EndpointService": "EndpointService"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "rdsmysql/dbAccount",
  "fqn": "pulumi_bytepluscc.rdsmysql",
  "classes": {
   "bytepluscc:rdsmysql/dbAccount:DbAccount": "DbAccount"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "rdsmysql/instance",
  "fqn": "pulumi_bytepluscc.rdsmysql",
  "classes": {
   "bytepluscc:rdsmysql/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "redis/instance",
  "fqn": "pulumi_bytepluscc.redis",
  "classes": {
   "bytepluscc:redis/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "storageebs/snapshot",
  "fqn": "pulumi_bytepluscc.storageebs",
  "classes": {
   "bytepluscc:storageebs/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "storageebs/volume",
  "fqn": "pulumi_bytepluscc.storageebs",
  "classes": {
   "bytepluscc:storageebs/volume:Volume": "Volume"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vefaas/kafkaTrigger",
  "fqn": "pulumi_bytepluscc.vefaas",
  "classes": {
   "bytepluscc:vefaas/kafkaTrigger:KafkaTrigger": "KafkaTrigger"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vefaas/sandbox",
  "fqn": "pulumi_bytepluscc.vefaas",
  "classes": {
   "bytepluscc:vefaas/sandbox:Sandbox": "Sandbox"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vepfs/instance",
  "fqn": "pulumi_bytepluscc.vepfs",
  "classes": {
   "bytepluscc:vepfs/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vke/addon",
  "fqn": "pulumi_bytepluscc.vke",
  "classes": {
   "bytepluscc:vke/addon:Addon": "Addon"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vke/cluster",
  "fqn": "pulumi_bytepluscc.vke",
  "classes": {
   "bytepluscc:vke/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vke/nodePool",
  "fqn": "pulumi_bytepluscc.vke",
  "classes": {
   "bytepluscc:vke/nodePool:NodePool": "NodePool"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vke/permission",
  "fqn": "pulumi_bytepluscc.vke",
  "classes": {
   "bytepluscc:vke/permission:Permission": "Permission"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vpc/eni",
  "fqn": "pulumi_bytepluscc.vpc",
  "classes": {
   "bytepluscc:vpc/eni:Eni": "Eni"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vpc/securityGroup",
  "fqn": "pulumi_bytepluscc.vpc",
  "classes": {
   "bytepluscc:vpc/securityGroup:SecurityGroup": "SecurityGroup"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vpc/subnet",
  "fqn": "pulumi_bytepluscc.vpc",
  "classes": {
   "bytepluscc:vpc/subnet:Subnet": "Subnet"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vpc/vpc",
  "fqn": "pulumi_bytepluscc.vpc",
  "classes": {
   "bytepluscc:vpc/vpc:Vpc": "Vpc"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "bytepluscc",
  "token": "pulumi:providers:bytepluscc",
  "fqn": "pulumi_bytepluscc",
  "class": "Provider"
 }
]
"""
)
