# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['NatIpArgs', 'NatIp']

@pulumi.input_type
class NatIpArgs:
    def __init__(__self__, *,
                 nat_gateway_id: pulumi.Input[builtins.str],
                 nat_ip: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_description: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a NatIp resource.
        :param pulumi.Input[builtins.str] nat_gateway_id: 私网NAT网关ID。
        :param pulumi.Input[builtins.str] nat_ip: 中转IP的地址。若不填，则系统自动从私网NAT网关所在子网随机分配一个空闲的IP地址。
        :param pulumi.Input[builtins.str] nat_ip_description: 中转IP的描述。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] nat_ip_name: 中转IP的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。不填默认为中转IP的ID。
        """
        pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if nat_ip is not None:
            pulumi.set(__self__, "nat_ip", nat_ip)
        if nat_ip_description is not None:
            pulumi.set(__self__, "nat_ip_description", nat_ip_description)
        if nat_ip_name is not None:
            pulumi.set(__self__, "nat_ip_name", nat_ip_name)

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> pulumi.Input[builtins.str]:
        """
        私网NAT网关ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "nat_gateway_id", value)

    @property
    @pulumi.getter(name="natIp")
    def nat_ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的地址。若不填，则系统自动从私网NAT网关所在子网随机分配一个空闲的IP地址。
        """
        return pulumi.get(self, "nat_ip")

    @nat_ip.setter
    def nat_ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip", value)

    @property
    @pulumi.getter(name="natIpDescription")
    def nat_ip_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的描述。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "nat_ip_description")

    @nat_ip_description.setter
    def nat_ip_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip_description", value)

    @property
    @pulumi.getter(name="natIpName")
    def nat_ip_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。不填默认为中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_name")

    @nat_ip_name.setter
    def nat_ip_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip_name", value)


@pulumi.input_type
class _NatIpState:
    def __init__(__self__, *,
                 is_default: Optional[pulumi.Input[builtins.bool]] = None,
                 nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_description: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_id: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 using_status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering NatIp resources.
        :param pulumi.Input[builtins.bool] is_default: 是否为默认中转IP。true：是。false：否。
        :param pulumi.Input[builtins.str] nat_gateway_id: 私网NAT网关ID。
        :param pulumi.Input[builtins.str] nat_ip: 中转IP的地址。若不填，则系统自动从私网NAT网关所在子网随机分配一个空闲的IP地址。
        :param pulumi.Input[builtins.str] nat_ip_description: 中转IP的描述。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] nat_ip_id: 中转IP的ID。
        :param pulumi.Input[builtins.str] nat_ip_name: 中转IP的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。不填默认为中转IP的ID。
        :param pulumi.Input[builtins.str] status: 中转IP的状态。Creating：创建中。Available：可用。Deleting：删除中。Deleted：已删除。
        :param pulumi.Input[builtins.str] using_status: 中转IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if nat_gateway_id is not None:
            pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if nat_ip is not None:
            pulumi.set(__self__, "nat_ip", nat_ip)
        if nat_ip_description is not None:
            pulumi.set(__self__, "nat_ip_description", nat_ip_description)
        if nat_ip_id is not None:
            pulumi.set(__self__, "nat_ip_id", nat_ip_id)
        if nat_ip_name is not None:
            pulumi.set(__self__, "nat_ip_name", nat_ip_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if using_status is not None:
            pulumi.set(__self__, "using_status", using_status)

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否为默认中转IP。true：是。false：否。
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私网NAT网关ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_gateway_id", value)

    @property
    @pulumi.getter(name="natIp")
    def nat_ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的地址。若不填，则系统自动从私网NAT网关所在子网随机分配一个空闲的IP地址。
        """
        return pulumi.get(self, "nat_ip")

    @nat_ip.setter
    def nat_ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip", value)

    @property
    @pulumi.getter(name="natIpDescription")
    def nat_ip_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的描述。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "nat_ip_description")

    @nat_ip_description.setter
    def nat_ip_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip_description", value)

    @property
    @pulumi.getter(name="natIpId")
    def nat_ip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_id")

    @nat_ip_id.setter
    def nat_ip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip_id", value)

    @property
    @pulumi.getter(name="natIpName")
    def nat_ip_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。不填默认为中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_name")

    @nat_ip_name.setter
    def nat_ip_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的状态。Creating：创建中。Available：可用。Deleting：删除中。Deleted：已删除。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="usingStatus")
    def using_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        return pulumi.get(self, "using_status")

    @using_status.setter
    def using_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "using_status", value)


@pulumi.type_token("bytepluscc:natgateway/natIp:NatIp")
class NatIp(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_description: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        从私网NAT网关所属子网分配，用于IP地址转换。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        nat_gateway_nat_ip_demo = bytepluscc.natgateway.NatIp("NatGatewayNatIpDemo",
            nat_gateway_id="ngw-2hgk22kpfp5a874wjohxxxxx",
            nat_ip_description="NatGatewayNatIpDemo description",
            nat_ip_name="NatGatewayNatIpDemo",
            nat_ip="192.168.xxx.xx")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:natgateway/natIp:NatIp example "nat_ip_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] nat_gateway_id: 私网NAT网关ID。
        :param pulumi.Input[builtins.str] nat_ip: 中转IP的地址。若不填，则系统自动从私网NAT网关所在子网随机分配一个空闲的IP地址。
        :param pulumi.Input[builtins.str] nat_ip_description: 中转IP的描述。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] nat_ip_name: 中转IP的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。不填默认为中转IP的ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NatIpArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        从私网NAT网关所属子网分配，用于IP地址转换。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        nat_gateway_nat_ip_demo = bytepluscc.natgateway.NatIp("NatGatewayNatIpDemo",
            nat_gateway_id="ngw-2hgk22kpfp5a874wjohxxxxx",
            nat_ip_description="NatGatewayNatIpDemo description",
            nat_ip_name="NatGatewayNatIpDemo",
            nat_ip="192.168.xxx.xx")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:natgateway/natIp:NatIp example "nat_ip_id"
        ```

        :param str resource_name: The name of the resource.
        :param NatIpArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NatIpArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_description: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NatIpArgs.__new__(NatIpArgs)

            if nat_gateway_id is None and not opts.urn:
                raise TypeError("Missing required property 'nat_gateway_id'")
            __props__.__dict__["nat_gateway_id"] = nat_gateway_id
            __props__.__dict__["nat_ip"] = nat_ip
            __props__.__dict__["nat_ip_description"] = nat_ip_description
            __props__.__dict__["nat_ip_name"] = nat_ip_name
            __props__.__dict__["is_default"] = None
            __props__.__dict__["nat_ip_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["using_status"] = None
        super(NatIp, __self__).__init__(
            'bytepluscc:natgateway/natIp:NatIp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            is_default: Optional[pulumi.Input[builtins.bool]] = None,
            nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            nat_ip: Optional[pulumi.Input[builtins.str]] = None,
            nat_ip_description: Optional[pulumi.Input[builtins.str]] = None,
            nat_ip_id: Optional[pulumi.Input[builtins.str]] = None,
            nat_ip_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            using_status: Optional[pulumi.Input[builtins.str]] = None) -> 'NatIp':
        """
        Get an existing NatIp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] is_default: 是否为默认中转IP。true：是。false：否。
        :param pulumi.Input[builtins.str] nat_gateway_id: 私网NAT网关ID。
        :param pulumi.Input[builtins.str] nat_ip: 中转IP的地址。若不填，则系统自动从私网NAT网关所在子网随机分配一个空闲的IP地址。
        :param pulumi.Input[builtins.str] nat_ip_description: 中转IP的描述。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] nat_ip_id: 中转IP的ID。
        :param pulumi.Input[builtins.str] nat_ip_name: 中转IP的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。不填默认为中转IP的ID。
        :param pulumi.Input[builtins.str] status: 中转IP的状态。Creating：创建中。Available：可用。Deleting：删除中。Deleted：已删除。
        :param pulumi.Input[builtins.str] using_status: 中转IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NatIpState.__new__(_NatIpState)

        __props__.__dict__["is_default"] = is_default
        __props__.__dict__["nat_gateway_id"] = nat_gateway_id
        __props__.__dict__["nat_ip"] = nat_ip
        __props__.__dict__["nat_ip_description"] = nat_ip_description
        __props__.__dict__["nat_ip_id"] = nat_ip_id
        __props__.__dict__["nat_ip_name"] = nat_ip_name
        __props__.__dict__["status"] = status
        __props__.__dict__["using_status"] = using_status
        return NatIp(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> pulumi.Output[builtins.bool]:
        """
        是否为默认中转IP。true：是。false：否。
        """
        return pulumi.get(self, "is_default")

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        私网NAT网关ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @property
    @pulumi.getter(name="natIp")
    def nat_ip(self) -> pulumi.Output[builtins.str]:
        """
        中转IP的地址。若不填，则系统自动从私网NAT网关所在子网随机分配一个空闲的IP地址。
        """
        return pulumi.get(self, "nat_ip")

    @property
    @pulumi.getter(name="natIpDescription")
    def nat_ip_description(self) -> pulumi.Output[builtins.str]:
        """
        中转IP的描述。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "nat_ip_description")

    @property
    @pulumi.getter(name="natIpId")
    def nat_ip_id(self) -> pulumi.Output[builtins.str]:
        """
        中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_id")

    @property
    @pulumi.getter(name="natIpName")
    def nat_ip_name(self) -> pulumi.Output[builtins.str]:
        """
        中转IP的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。不填默认为中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        中转IP的状态。Creating：创建中。Available：可用。Deleting：删除中。Deleted：已删除。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="usingStatus")
    def using_status(self) -> pulumi.Output[builtins.str]:
        """
        中转IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        return pulumi.get(self, "using_status")

